#define _CFFI_

/* We try to define Py_LIMITED_API before including Python.h.

   Mess: we can only define it if Py_DEBUG, Py_TRACE_REFS and
   Py_REF_DEBUG are not defined.  This is a best-effort approximation:
   we can learn about Py_DEBUG from pyconfig.h, but it is unclear if
   the same works for the other two macros.  Py_DEBUG implies them,
   but not the other way around.

   The implementation is messy (issue #350): on Windows, with _MSC_VER,
   we have to define Py_LIMITED_API even before including pyconfig.h.
   In that case, we guess what pyconfig.h will do to the macros above,
   and check our guess after the #include.

   Note that on Windows, with CPython 3.x, you need >= 3.5 and virtualenv
   version >= 16.0.0.  With older versions of either, you don't get a
   copy of PYTHON3.DLL in the virtualenv.  We can't check the version of
   CPython *before* we even include pyconfig.h.  ffi.set_source() puts
   a ``#define _CFFI_NO_LIMITED_API'' at the start of this file if it is
   running on Windows < 3.5, as an attempt at fixing it, but that's
   arguably wrong because it may not be the target version of Python.
   Still better than nothing I guess.  As another workaround, you can
   remove the definition of Py_LIMITED_API here.

   See also 'py_limited_api' in cffi/setuptools_ext.py.
*/
#if !defined(_CFFI_USE_EMBEDDING) && !defined(Py_LIMITED_API)
#  ifdef _MSC_VER
#    if !defined(_DEBUG) && !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#    include <pyconfig.h>
     /* sanity-check: Py_LIMITED_API will cause crashes if any of these
        are also defined.  Normally, the Python file PC/pyconfig.h does not
        cause any of these to be defined, with the exception that _DEBUG
        causes Py_DEBUG.  Double-check that. */
#    ifdef Py_LIMITED_API
#      if defined(Py_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_DEBUG, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_TRACE_REFS)
#        error "pyconfig.h unexpectedly defines Py_TRACE_REFS, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_REF_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_REF_DEBUG, but Py_LIMITED_API is set"
#      endif
#    endif
#  else
#    include <pyconfig.h>
#    if !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#  endif
#endif

#include <Python.h>
#ifdef __cplusplus
extern "C" {
#endif
#include <stddef.h>

/* This part is from file 'cffi/parse_c_type.h'.  It is copied at the
   beginning of C sources generated by CFFI's ffi.set_source(). */

typedef void *_cffi_opcode_t;

#define _CFFI_OP(opcode, arg)   (_cffi_opcode_t)(opcode | (((uintptr_t)(arg)) << 8))
#define _CFFI_GETOP(cffi_opcode)    ((unsigned char)(uintptr_t)cffi_opcode)
#define _CFFI_GETARG(cffi_opcode)   (((intptr_t)cffi_opcode) >> 8)

#define _CFFI_OP_PRIMITIVE       1
#define _CFFI_OP_POINTER         3
#define _CFFI_OP_ARRAY           5
#define _CFFI_OP_OPEN_ARRAY      7
#define _CFFI_OP_STRUCT_UNION    9
#define _CFFI_OP_ENUM           11
#define _CFFI_OP_FUNCTION       13
#define _CFFI_OP_FUNCTION_END   15
#define _CFFI_OP_NOOP           17
#define _CFFI_OP_BITFIELD       19
#define _CFFI_OP_TYPENAME       21
#define _CFFI_OP_CPYTHON_BLTN_V 23   // varargs
#define _CFFI_OP_CPYTHON_BLTN_N 25   // noargs
#define _CFFI_OP_CPYTHON_BLTN_O 27   // O  (i.e. a single arg)
#define _CFFI_OP_CONSTANT       29
#define _CFFI_OP_CONSTANT_INT   31
#define _CFFI_OP_GLOBAL_VAR     33
#define _CFFI_OP_DLOPEN_FUNC    35
#define _CFFI_OP_DLOPEN_CONST   37
#define _CFFI_OP_GLOBAL_VAR_F   39
#define _CFFI_OP_EXTERN_PYTHON  41

#define _CFFI_PRIM_VOID          0
#define _CFFI_PRIM_BOOL          1
#define _CFFI_PRIM_CHAR          2
#define _CFFI_PRIM_SCHAR         3
#define _CFFI_PRIM_UCHAR         4
#define _CFFI_PRIM_SHORT         5
#define _CFFI_PRIM_USHORT        6
#define _CFFI_PRIM_INT           7
#define _CFFI_PRIM_UINT          8
#define _CFFI_PRIM_LONG          9
#define _CFFI_PRIM_ULONG        10
#define _CFFI_PRIM_LONGLONG     11
#define _CFFI_PRIM_ULONGLONG    12
#define _CFFI_PRIM_FLOAT        13
#define _CFFI_PRIM_DOUBLE       14
#define _CFFI_PRIM_LONGDOUBLE   15

#define _CFFI_PRIM_WCHAR        16
#define _CFFI_PRIM_INT8         17
#define _CFFI_PRIM_UINT8        18
#define _CFFI_PRIM_INT16        19
#define _CFFI_PRIM_UINT16       20
#define _CFFI_PRIM_INT32        21
#define _CFFI_PRIM_UINT32       22
#define _CFFI_PRIM_INT64        23
#define _CFFI_PRIM_UINT64       24
#define _CFFI_PRIM_INTPTR       25
#define _CFFI_PRIM_UINTPTR      26
#define _CFFI_PRIM_PTRDIFF      27
#define _CFFI_PRIM_SIZE         28
#define _CFFI_PRIM_SSIZE        29
#define _CFFI_PRIM_INT_LEAST8   30
#define _CFFI_PRIM_UINT_LEAST8  31
#define _CFFI_PRIM_INT_LEAST16  32
#define _CFFI_PRIM_UINT_LEAST16 33
#define _CFFI_PRIM_INT_LEAST32  34
#define _CFFI_PRIM_UINT_LEAST32 35
#define _CFFI_PRIM_INT_LEAST64  36
#define _CFFI_PRIM_UINT_LEAST64 37
#define _CFFI_PRIM_INT_FAST8    38
#define _CFFI_PRIM_UINT_FAST8   39
#define _CFFI_PRIM_INT_FAST16   40
#define _CFFI_PRIM_UINT_FAST16  41
#define _CFFI_PRIM_INT_FAST32   42
#define _CFFI_PRIM_UINT_FAST32  43
#define _CFFI_PRIM_INT_FAST64   44
#define _CFFI_PRIM_UINT_FAST64  45
#define _CFFI_PRIM_INTMAX       46
#define _CFFI_PRIM_UINTMAX      47
#define _CFFI_PRIM_FLOATCOMPLEX 48
#define _CFFI_PRIM_DOUBLECOMPLEX 49
#define _CFFI_PRIM_CHAR16       50
#define _CFFI_PRIM_CHAR32       51

#define _CFFI__NUM_PRIM         52
#define _CFFI__UNKNOWN_PRIM           (-1)
#define _CFFI__UNKNOWN_FLOAT_PRIM     (-2)
#define _CFFI__UNKNOWN_LONG_DOUBLE    (-3)

#define _CFFI__IO_FILE_STRUCT         (-1)


struct _cffi_global_s {
    const char *name;
    void *address;
    _cffi_opcode_t type_op;
    void *size_or_direct_fn;  // OP_GLOBAL_VAR: size, or 0 if unknown
                              // OP_CPYTHON_BLTN_*: addr of direct function
};

struct _cffi_getconst_s {
    unsigned long long value;
    const struct _cffi_type_context_s *ctx;
    int gindex;
};

struct _cffi_struct_union_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_STRUCT_UNION
    int flags;               // _CFFI_F_* flags below
    size_t size;
    int alignment;
    int first_field_index;   // -> _cffi_fields array
    int num_fields;
};
#define _CFFI_F_UNION         0x01   // is a union, not a struct
#define _CFFI_F_CHECK_FIELDS  0x02   // complain if fields are not in the
                                     // "standard layout" or if some are missing
#define _CFFI_F_PACKED        0x04   // for CHECK_FIELDS, assume a packed struct
#define _CFFI_F_EXTERNAL      0x08   // in some other ffi.include()
#define _CFFI_F_OPAQUE        0x10   // opaque

struct _cffi_field_s {
    const char *name;
    size_t field_offset;
    size_t field_size;
    _cffi_opcode_t field_type_op;
};

struct _cffi_enum_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_ENUM
    int type_prim;           // _CFFI_PRIM_xxx
    const char *enumerators; // comma-delimited string
};

struct _cffi_typename_s {
    const char *name;
    int type_index;   /* if opaque, points to a possibly artificial
                         OP_STRUCT which is itself opaque */
};

struct _cffi_type_context_s {
    _cffi_opcode_t *types;
    const struct _cffi_global_s *globals;
    const struct _cffi_field_s *fields;
    const struct _cffi_struct_union_s *struct_unions;
    const struct _cffi_enum_s *enums;
    const struct _cffi_typename_s *typenames;
    int num_globals;
    int num_struct_unions;
    int num_enums;
    int num_typenames;
    const char *const *includes;
    int num_types;
    int flags;      /* future extension */
};

struct _cffi_parse_info_s {
    const struct _cffi_type_context_s *ctx;
    _cffi_opcode_t *output;
    unsigned int output_size;
    size_t error_location;
    const char *error_message;
};

struct _cffi_externpy_s {
    const char *name;
    size_t size_of_result;
    void *reserved1, *reserved2;
};

#ifdef _CFFI_INTERNAL
static int parse_c_type(struct _cffi_parse_info_s *info, const char *input);
static int search_in_globals(const struct _cffi_type_context_s *ctx,
                             const char *search, size_t search_len);
static int search_in_struct_unions(const struct _cffi_type_context_s *ctx,
                                   const char *search, size_t search_len);
#endif

/* this block of #ifs should be kept exactly identical between
   c/_cffi_backend.c, cffi/vengine_cpy.py, cffi/vengine_gen.py
   and cffi/_cffi_include.h */
#if defined(_MSC_VER)
# include <malloc.h>   /* for alloca() */
# if _MSC_VER < 1600   /* MSVC < 2010 */
   typedef __int8 int8_t;
   typedef __int16 int16_t;
   typedef __int32 int32_t;
   typedef __int64 int64_t;
   typedef unsigned __int8 uint8_t;
   typedef unsigned __int16 uint16_t;
   typedef unsigned __int32 uint32_t;
   typedef unsigned __int64 uint64_t;
   typedef __int8 int_least8_t;
   typedef __int16 int_least16_t;
   typedef __int32 int_least32_t;
   typedef __int64 int_least64_t;
   typedef unsigned __int8 uint_least8_t;
   typedef unsigned __int16 uint_least16_t;
   typedef unsigned __int32 uint_least32_t;
   typedef unsigned __int64 uint_least64_t;
   typedef __int8 int_fast8_t;
   typedef __int16 int_fast16_t;
   typedef __int32 int_fast32_t;
   typedef __int64 int_fast64_t;
   typedef unsigned __int8 uint_fast8_t;
   typedef unsigned __int16 uint_fast16_t;
   typedef unsigned __int32 uint_fast32_t;
   typedef unsigned __int64 uint_fast64_t;
   typedef __int64 intmax_t;
   typedef unsigned __int64 uintmax_t;
# else
#  include <stdint.h>
# endif
# if _MSC_VER < 1800   /* MSVC < 2013 */
#  ifndef __cplusplus
    typedef unsigned char _Bool;
#  endif
# endif
# define _cffi_float_complex_t   _Fcomplex    /* include <complex.h> for it */
# define _cffi_double_complex_t  _Dcomplex    /* include <complex.h> for it */
#else
# include <stdint.h>
# if (defined (__SVR4) && defined (__sun)) || defined(_AIX) || defined(__hpux)
#  include <alloca.h>
# endif
# define _cffi_float_complex_t   float _Complex
# define _cffi_double_complex_t  double _Complex
#endif

#ifdef __GNUC__
# define _CFFI_UNUSED_FN  __attribute__((unused))
#else
# define _CFFI_UNUSED_FN  /* nothing */
#endif

#ifdef __cplusplus
# ifndef _Bool
   typedef bool _Bool;   /* semi-hackish: C++ has no _Bool; bool is builtin */
# endif
#endif

/**********  CPython-specific section  **********/
#ifndef PYPY_VERSION


#if PY_MAJOR_VERSION >= 3
# define PyInt_FromLong PyLong_FromLong
#endif

#define _cffi_from_c_double PyFloat_FromDouble
#define _cffi_from_c_float PyFloat_FromDouble
#define _cffi_from_c_long PyInt_FromLong
#define _cffi_from_c_ulong PyLong_FromUnsignedLong
#define _cffi_from_c_longlong PyLong_FromLongLong
#define _cffi_from_c_ulonglong PyLong_FromUnsignedLongLong
#define _cffi_from_c__Bool PyBool_FromLong

#define _cffi_to_c_double PyFloat_AsDouble
#define _cffi_to_c_float PyFloat_AsDouble

#define _cffi_from_c_int(x, type)                                        \
    (((type)-1) > 0 ? /* unsigned */                                     \
        (sizeof(type) < sizeof(long) ?                                   \
            PyInt_FromLong((long)x) :                                    \
         sizeof(type) == sizeof(long) ?                                  \
            PyLong_FromUnsignedLong((unsigned long)x) :                  \
            PyLong_FromUnsignedLongLong((unsigned long long)x)) :        \
        (sizeof(type) <= sizeof(long) ?                                  \
            PyInt_FromLong((long)x) :                                    \
            PyLong_FromLongLong((long long)x)))

#define _cffi_to_c_int(o, type)                                          \
    ((type)(                                                             \
     sizeof(type) == 1 ? (((type)-1) > 0 ? (type)_cffi_to_c_u8(o)        \
                                         : (type)_cffi_to_c_i8(o)) :     \
     sizeof(type) == 2 ? (((type)-1) > 0 ? (type)_cffi_to_c_u16(o)       \
                                         : (type)_cffi_to_c_i16(o)) :    \
     sizeof(type) == 4 ? (((type)-1) > 0 ? (type)_cffi_to_c_u32(o)       \
                                         : (type)_cffi_to_c_i32(o)) :    \
     sizeof(type) == 8 ? (((type)-1) > 0 ? (type)_cffi_to_c_u64(o)       \
                                         : (type)_cffi_to_c_i64(o)) :    \
     (Py_FatalError("unsupported size for type " #type), (type)0)))

#define _cffi_to_c_i8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[1])
#define _cffi_to_c_u8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[2])
#define _cffi_to_c_i16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[3])
#define _cffi_to_c_u16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[4])
#define _cffi_to_c_i32                                                   \
                 ((int(*)(PyObject *))_cffi_exports[5])
#define _cffi_to_c_u32                                                   \
                 ((unsigned int(*)(PyObject *))_cffi_exports[6])
#define _cffi_to_c_i64                                                   \
                 ((long long(*)(PyObject *))_cffi_exports[7])
#define _cffi_to_c_u64                                                   \
                 ((unsigned long long(*)(PyObject *))_cffi_exports[8])
#define _cffi_to_c_char                                                  \
                 ((int(*)(PyObject *))_cffi_exports[9])
#define _cffi_from_c_pointer                                             \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[10])
#define _cffi_to_c_pointer                                               \
    ((char *(*)(PyObject *, struct _cffi_ctypedescr *))_cffi_exports[11])
#define _cffi_get_struct_layout                                          \
    not used any more
#define _cffi_restore_errno                                              \
    ((void(*)(void))_cffi_exports[13])
#define _cffi_save_errno                                                 \
    ((void(*)(void))_cffi_exports[14])
#define _cffi_from_c_char                                                \
    ((PyObject *(*)(char))_cffi_exports[15])
#define _cffi_from_c_deref                                               \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[16])
#define _cffi_to_c                                                       \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[17])
#define _cffi_from_c_struct                                              \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[18])
#define _cffi_to_c_wchar_t                                               \
    ((_cffi_wchar_t(*)(PyObject *))_cffi_exports[19])
#define _cffi_from_c_wchar_t                                             \
    ((PyObject *(*)(_cffi_wchar_t))_cffi_exports[20])
#define _cffi_to_c_long_double                                           \
    ((long double(*)(PyObject *))_cffi_exports[21])
#define _cffi_to_c__Bool                                                 \
    ((_Bool(*)(PyObject *))_cffi_exports[22])
#define _cffi_prepare_pointer_call_argument                              \
    ((Py_ssize_t(*)(struct _cffi_ctypedescr *,                           \
                    PyObject *, char **))_cffi_exports[23])
#define _cffi_convert_array_from_object                                  \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[24])
#define _CFFI_CPIDX  25
#define _cffi_call_python                                                \
    ((void(*)(struct _cffi_externpy_s *, char *))_cffi_exports[_CFFI_CPIDX])
#define _cffi_to_c_wchar3216_t                                           \
    ((int(*)(PyObject *))_cffi_exports[26])
#define _cffi_from_c_wchar3216_t                                         \
    ((PyObject *(*)(int))_cffi_exports[27])
#define _CFFI_NUM_EXPORTS 28

struct _cffi_ctypedescr;

static void *_cffi_exports[_CFFI_NUM_EXPORTS];

#define _cffi_type(index)   (                           \
    assert((((uintptr_t)_cffi_types[index]) & 1) == 0), \
    (struct _cffi_ctypedescr *)_cffi_types[index])

static PyObject *_cffi_init(const char *module_name, Py_ssize_t version,
                            const struct _cffi_type_context_s *ctx)
{
    PyObject *module, *o_arg, *new_module;
    void *raw[] = {
        (void *)module_name,
        (void *)version,
        (void *)_cffi_exports,
        (void *)ctx,
    };

    module = PyImport_ImportModule("_cffi_backend");
    if (module == NULL)
        goto failure;

    o_arg = PyLong_FromVoidPtr((void *)raw);
    if (o_arg == NULL)
        goto failure;

    new_module = PyObject_CallMethod(
        module, (char *)"_init_cffi_1_0_external_module", (char *)"O", o_arg);

    Py_DECREF(o_arg);
    Py_DECREF(module);
    return new_module;

  failure:
    Py_XDECREF(module);
    return NULL;
}


#ifdef HAVE_WCHAR_H
typedef wchar_t _cffi_wchar_t;
#else
typedef uint16_t _cffi_wchar_t;   /* same random pick as _cffi_backend.c */
#endif

_CFFI_UNUSED_FN static uint16_t _cffi_to_c_char16_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return (uint16_t)_cffi_to_c_wchar_t(o);
    else
        return (uint16_t)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char16_t(uint16_t x)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

_CFFI_UNUSED_FN static int _cffi_to_c_char32_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return (int)_cffi_to_c_wchar_t(o);
    else
        return (int)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char32_t(unsigned int x)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

union _cffi_union_alignment_u {
    unsigned char m_char;
    unsigned short m_short;
    unsigned int m_int;
    unsigned long m_long;
    unsigned long long m_longlong;
    float m_float;
    double m_double;
    long double m_longdouble;
};

struct _cffi_freeme_s {
    struct _cffi_freeme_s *next;
    union _cffi_union_alignment_u alignment;
};

_CFFI_UNUSED_FN static int
_cffi_convert_array_argument(struct _cffi_ctypedescr *ctptr, PyObject *arg,
                             char **output_data, Py_ssize_t datasize,
                             struct _cffi_freeme_s **freeme)
{
    char *p;
    if (datasize < 0)
        return -1;

    p = *output_data;
    if (p == NULL) {
        struct _cffi_freeme_s *fp = (struct _cffi_freeme_s *)PyObject_Malloc(
            offsetof(struct _cffi_freeme_s, alignment) + (size_t)datasize);
        if (fp == NULL)
            return -1;
        fp->next = *freeme;
        *freeme = fp;
        p = *output_data = (char *)&fp->alignment;
    }
    memset((void *)p, 0, (size_t)datasize);
    return _cffi_convert_array_from_object(p, ctptr, arg);
}

_CFFI_UNUSED_FN static void
_cffi_free_array_arguments(struct _cffi_freeme_s *freeme)
{
    do {
        void *p = (void *)freeme;
        freeme = freeme->next;
        PyObject_Free(p);
    } while (freeme != NULL);
}

/**********  end CPython-specific section  **********/
#else
_CFFI_UNUSED_FN
static void (*_cffi_call_python_org)(struct _cffi_externpy_s *, char *);
# define _cffi_call_python  _cffi_call_python_org
#endif


#define _cffi_array_len(array)   (sizeof(array) / sizeof((array)[0]))

#define _cffi_prim_int(size, sign)                                      \
    ((size) == 1 ? ((sign) ? _CFFI_PRIM_INT8  : _CFFI_PRIM_UINT8)  :    \
     (size) == 2 ? ((sign) ? _CFFI_PRIM_INT16 : _CFFI_PRIM_UINT16) :    \
     (size) == 4 ? ((sign) ? _CFFI_PRIM_INT32 : _CFFI_PRIM_UINT32) :    \
     (size) == 8 ? ((sign) ? _CFFI_PRIM_INT64 : _CFFI_PRIM_UINT64) :    \
     _CFFI__UNKNOWN_PRIM)

#define _cffi_prim_float(size)                                          \
    ((size) == sizeof(float) ? _CFFI_PRIM_FLOAT :                       \
     (size) == sizeof(double) ? _CFFI_PRIM_DOUBLE :                     \
     (size) == sizeof(long double) ? _CFFI__UNKNOWN_LONG_DOUBLE :       \
     _CFFI__UNKNOWN_FLOAT_PRIM)

#define _cffi_check_int(got, got_nonpos, expected)      \
    ((got_nonpos) == (expected <= 0) &&                 \
     (got) == (unsigned long long)expected)

#ifdef MS_WIN32
# define _cffi_stdcall  __stdcall
#else
# define _cffi_stdcall  /* nothing */
#endif

#ifdef __cplusplus
}
#endif

/************************************************************/

/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

#include "proton/version.h"
#include "proton/types.h"
#include "proton/object.h"
#include "proton/error.h"
#include "proton/condition.h"
#include "proton/connection.h"
#include "proton/session.h"
#include "proton/link.h"
#include "proton/terminus.h"
#include "proton/delivery.h"
#include "proton/disposition.h"
#include "proton/transport.h"
#include "proton/event.h"
#include "proton/message.h"
#include "proton/sasl.h"
#include "proton/ssl.h"
#include "proton/codec.h"
#include "proton/connection_driver.h"
#include "proton/cid.h"

static void pn_pyref_incref(void *object);
static void pn_pyref_decref(void *object);

static int pn_pyref_refcount(void *object) {
    return 1;
}

pn_connection_t *pn_cast_pn_connection(void *x) { return (pn_connection_t *) x; }
pn_session_t *pn_cast_pn_session(void *x) { return (pn_session_t *) x; }
pn_link_t *pn_cast_pn_link(void *x) { return (pn_link_t *) x; }
pn_delivery_t *pn_cast_pn_delivery(void *x) { return (pn_delivery_t *) x; }
pn_transport_t *pn_cast_pn_transport(void *x) { return (pn_transport_t *) x; }

static pn_class_t* PN_PYREF;
PN_HANDLE(PN_PYCTX);

static pn_class_t* pn_create_pyref() {
    return pn_class_create("pn_pyref", NULL, NULL, pn_pyref_incref, pn_pyref_decref, pn_pyref_refcount);
}

pn_event_t *pn_collector_put_py(pn_collector_t *collector, void *context, pn_event_type_t type) {
    return pn_collector_put(collector, PN_PYREF, context, type);
}

void pn_record_def_py(pn_record_t *record) {
    pn_record_def(record, PN_PYCTX, PN_PYREF);
}

void *pn_record_get_py(pn_record_t *record) {
    return pn_record_get(record, PN_PYCTX);
}

void pn_record_set_py(pn_record_t *record, void *value) {
    pn_record_set(record, PN_PYCTX, value);
}

ssize_t pn_message_encode_py(pn_message_t *msg, char *bytes, size_t size) {
    int err = pn_message_encode(msg, bytes, &size);
    if (err == 0) return size;
    else return err;
}

ssize_t pn_data_format_py(pn_data_t *data, char *bytes, size_t size) {
    int err = pn_data_format(data, bytes, &size);
    if (err == 0) return size;
    else return err;
}

int pn_ssl_get_peer_hostname_py(pn_ssl_t *ssl, char *hostname, size_t size) {
    return pn_ssl_get_peer_hostname(ssl, hostname, &size);
}

const char *pn_event_class_name_py(pn_event_t *event) {
    const pn_class_t *class = pn_event_class(event);
    return class ? pn_class_name(class) : 0;
}

void init() {
    PN_PYREF = pn_create_pyref();
}




/************************************************************/

static void *_cffi_types[] = {
/*  0 */ _CFFI_OP(_CFFI_OP_FUNCTION, 99), // _Bool()(pn_collector_t *)
/*  1 */ _CFFI_OP(_CFFI_OP_POINTER, 757), // pn_collector_t *
/*  2 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  3 */ _CFFI_OP(_CFFI_OP_FUNCTION, 99), // _Bool()(pn_condition_t *)
/*  4 */ _CFFI_OP(_CFFI_OP_POINTER, 758), // pn_condition_t *
/*  5 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  6 */ _CFFI_OP(_CFFI_OP_FUNCTION, 99), // _Bool()(pn_data_t *)
/*  7 */ _CFFI_OP(_CFFI_OP_POINTER, 760), // pn_data_t *
/*  8 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  9 */ _CFFI_OP(_CFFI_OP_FUNCTION, 99), // _Bool()(pn_data_t *, char const *)
/* 10 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 11 */ _CFFI_OP(_CFFI_OP_POINTER, 754), // char const *
/* 12 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 13 */ _CFFI_OP(_CFFI_OP_FUNCTION, 99), // _Bool()(pn_delivery_t *)
/* 14 */ _CFFI_OP(_CFFI_OP_POINTER, 761), // pn_delivery_t *
/* 15 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 16 */ _CFFI_OP(_CFFI_OP_FUNCTION, 99), // _Bool()(pn_disposition_t *)
/* 17 */ _CFFI_OP(_CFFI_OP_POINTER, 762), // pn_disposition_t *
/* 18 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 19 */ _CFFI_OP(_CFFI_OP_FUNCTION, 99), // _Bool()(pn_link_t *)
/* 20 */ _CFFI_OP(_CFFI_OP_POINTER, 765), // pn_link_t *
/* 21 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 22 */ _CFFI_OP(_CFFI_OP_FUNCTION, 99), // _Bool()(pn_message_t *)
/* 23 */ _CFFI_OP(_CFFI_OP_POINTER, 766), // pn_message_t *
/* 24 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 25 */ _CFFI_OP(_CFFI_OP_FUNCTION, 99), // _Bool()(pn_sasl_t *)
/* 26 */ _CFFI_OP(_CFFI_OP_POINTER, 768), // pn_sasl_t *
/* 27 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 28 */ _CFFI_OP(_CFFI_OP_FUNCTION, 99), // _Bool()(pn_ssl_t *, char *, size_t)
/* 29 */ _CFFI_OP(_CFFI_OP_POINTER, 772), // pn_ssl_t *
/* 30 */ _CFFI_OP(_CFFI_OP_POINTER, 754), // char *
/* 31 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28), // size_t
/* 32 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 33 */ _CFFI_OP(_CFFI_OP_FUNCTION, 99), // _Bool()(pn_terminus_t *)
/* 34 */ _CFFI_OP(_CFFI_OP_POINTER, 773), // pn_terminus_t *
/* 35 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 36 */ _CFFI_OP(_CFFI_OP_FUNCTION, 99), // _Bool()(pn_transport_t *)
/* 37 */ _CFFI_OP(_CFFI_OP_POINTER, 774), // pn_transport_t *
/* 38 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 39 */ _CFFI_OP(_CFFI_OP_FUNCTION, 99), // _Bool()(void)
/* 40 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 41 */ _CFFI_OP(_CFFI_OP_FUNCTION, 30), // char *()(void *)
/* 42 */ _CFFI_OP(_CFFI_OP_POINTER, 778), // void *
/* 43 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 44 */ _CFFI_OP(_CFFI_OP_FUNCTION, 11), // char const *()(pn_condition_t *)
/* 45 */ _CFFI_OP(_CFFI_OP_NOOP, 4),
/* 46 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 47 */ _CFFI_OP(_CFFI_OP_FUNCTION, 11), // char const *()(pn_connection_t *)
/* 48 */ _CFFI_OP(_CFFI_OP_POINTER, 759), // pn_connection_t *
/* 49 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 50 */ _CFFI_OP(_CFFI_OP_FUNCTION, 11), // char const *()(pn_error_t *)
/* 51 */ _CFFI_OP(_CFFI_OP_POINTER, 763), // pn_error_t *
/* 52 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 53 */ _CFFI_OP(_CFFI_OP_FUNCTION, 11), // char const *()(pn_event_t *)
/* 54 */ _CFFI_OP(_CFFI_OP_POINTER, 764), // pn_event_t *
/* 55 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 56 */ _CFFI_OP(_CFFI_OP_FUNCTION, 11), // char const *()(pn_event_type_t)
/* 57 */ _CFFI_OP(_CFFI_OP_ENUM, 2), // pn_event_type_t
/* 58 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 59 */ _CFFI_OP(_CFFI_OP_FUNCTION, 11), // char const *()(pn_link_t *)
/* 60 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 61 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 62 */ _CFFI_OP(_CFFI_OP_FUNCTION, 11), // char const *()(pn_message_t *)
/* 63 */ _CFFI_OP(_CFFI_OP_NOOP, 23),
/* 64 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 65 */ _CFFI_OP(_CFFI_OP_FUNCTION, 11), // char const *()(pn_sasl_t *)
/* 66 */ _CFFI_OP(_CFFI_OP_NOOP, 26),
/* 67 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 68 */ _CFFI_OP(_CFFI_OP_FUNCTION, 11), // char const *()(pn_ssl_t *)
/* 69 */ _CFFI_OP(_CFFI_OP_NOOP, 29),
/* 70 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 71 */ _CFFI_OP(_CFFI_OP_FUNCTION, 11), // char const *()(pn_ssl_t *, pn_ssl_cert_subject_subfield)
/* 72 */ _CFFI_OP(_CFFI_OP_NOOP, 29),
/* 73 */ _CFFI_OP(_CFFI_OP_ENUM, 7), // pn_ssl_cert_subject_subfield
/* 74 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 75 */ _CFFI_OP(_CFFI_OP_FUNCTION, 11), // char const *()(pn_terminus_t *)
/* 76 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 77 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 78 */ _CFFI_OP(_CFFI_OP_FUNCTION, 11), // char const *()(pn_transport_t *)
/* 79 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 80 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 81 */ _CFFI_OP(_CFFI_OP_FUNCTION, 108), // double()(pn_data_t *)
/* 82 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 83 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 84 */ _CFFI_OP(_CFFI_OP_FUNCTION, 112), // float()(pn_data_t *)
/* 85 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 86 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 87 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_condition_t *, char const *)
/* 88 */ _CFFI_OP(_CFFI_OP_NOOP, 4),
/* 89 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 90 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 91 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_connection_t *)
/* 92 */ _CFFI_OP(_CFFI_OP_NOOP, 48),
/* 93 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 94 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_data_t *)
/* 95 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 96 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 97 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_data_t *, _Bool)
/* 98 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 99 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 1), // _Bool
/* 100 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 101 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_data_t *, _Bool, pn_type_t)
/* 102 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 103 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 1),
/* 104 */ _CFFI_OP(_CFFI_OP_ENUM, 13), // pn_type_t
/* 105 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 106 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_data_t *, double)
/* 107 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 108 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14), // double
/* 109 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 110 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_data_t *, float)
/* 111 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 112 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 13), // float
/* 113 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 114 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_data_t *, int16_t)
/* 115 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 116 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 19), // int16_t
/* 117 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 118 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_data_t *, int32_t)
/* 119 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 120 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 21), // int32_t
/* 121 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 122 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_data_t *, int64_t)
/* 123 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 124 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 23), // int64_t
/* 125 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 126 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_data_t *, int8_t)
/* 127 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 128 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 17), // int8_t
/* 129 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 130 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_data_t *, pn_bytes_t)
/* 131 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 132 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 4), // pn_bytes_t
/* 133 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 134 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_data_t *, pn_data_t *)
/* 135 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 136 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 137 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 138 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_data_t *, pn_decimal128_t)
/* 139 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 140 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 2), // pn_decimal128_t
/* 141 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 142 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_data_t *, pn_uuid_t)
/* 143 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 144 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 3), // pn_uuid_t
/* 145 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 146 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_data_t *, uint16_t)
/* 147 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 148 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 20), // uint16_t
/* 149 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 150 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_data_t *, uint32_t)
/* 151 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 152 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 22), // uint32_t
/* 153 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 154 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_data_t *, uint64_t)
/* 155 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 156 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 24), // uint64_t
/* 157 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 158 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_data_t *, uint8_t)
/* 159 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 160 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 18), // uint8_t
/* 161 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 162 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_error_t *)
/* 163 */ _CFFI_OP(_CFFI_OP_NOOP, 51),
/* 164 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 165 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_link_t *)
/* 166 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 167 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 168 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_message_t *, _Bool)
/* 169 */ _CFFI_OP(_CFFI_OP_NOOP, 23),
/* 170 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 1),
/* 171 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 172 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_message_t *, char const *)
/* 173 */ _CFFI_OP(_CFFI_OP_NOOP, 23),
/* 174 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 175 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 176 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_message_t *, char const *, size_t)
/* 177 */ _CFFI_OP(_CFFI_OP_NOOP, 23),
/* 178 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 179 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 180 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 181 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_message_t *, int64_t)
/* 182 */ _CFFI_OP(_CFFI_OP_NOOP, 23),
/* 183 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 23),
/* 184 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 185 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_message_t *, pn_atom_t)
/* 186 */ _CFFI_OP(_CFFI_OP_NOOP, 23),
/* 187 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 1), // pn_atom_t
/* 188 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 189 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_message_t *, pn_bytes_t)
/* 190 */ _CFFI_OP(_CFFI_OP_NOOP, 23),
/* 191 */ _CFFI_OP(_CFFI_OP_NOOP, 132),
/* 192 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 193 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_message_t *, uint32_t)
/* 194 */ _CFFI_OP(_CFFI_OP_NOOP, 23),
/* 195 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 22),
/* 196 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 197 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_message_t *, uint8_t)
/* 198 */ _CFFI_OP(_CFFI_OP_NOOP, 23),
/* 199 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 18),
/* 200 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 201 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_session_t *)
/* 202 */ _CFFI_OP(_CFFI_OP_POINTER, 769), // pn_session_t *
/* 203 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 204 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_ssl_domain_t *)
/* 205 */ _CFFI_OP(_CFFI_OP_POINTER, 770), // pn_ssl_domain_t *
/* 206 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 207 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_ssl_domain_t *, char const *)
/* 208 */ _CFFI_OP(_CFFI_OP_NOOP, 205),
/* 209 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 210 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 211 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_ssl_domain_t *, char const *, char const *, char const *)
/* 212 */ _CFFI_OP(_CFFI_OP_NOOP, 205),
/* 213 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 214 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 215 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 216 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 217 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_ssl_domain_t *, pn_ssl_verify_mode_t, char const *)
/* 218 */ _CFFI_OP(_CFFI_OP_NOOP, 205),
/* 219 */ _CFFI_OP(_CFFI_OP_ENUM, 11), // pn_ssl_verify_mode_t
/* 220 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 221 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 222 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_ssl_t *, char *, size_t)
/* 223 */ _CFFI_OP(_CFFI_OP_NOOP, 29),
/* 224 */ _CFFI_OP(_CFFI_OP_NOOP, 30),
/* 225 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 226 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 227 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_ssl_t *, char *, size_t, pn_ssl_hash_alg)
/* 228 */ _CFFI_OP(_CFFI_OP_NOOP, 29),
/* 229 */ _CFFI_OP(_CFFI_OP_NOOP, 30),
/* 230 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 231 */ _CFFI_OP(_CFFI_OP_ENUM, 8), // pn_ssl_hash_alg
/* 232 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 233 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_ssl_t *, char const *)
/* 234 */ _CFFI_OP(_CFFI_OP_NOOP, 29),
/* 235 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 236 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 237 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_ssl_t *, pn_ssl_domain_t *, char const *)
/* 238 */ _CFFI_OP(_CFFI_OP_NOOP, 29),
/* 239 */ _CFFI_OP(_CFFI_OP_NOOP, 205),
/* 240 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 241 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 242 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_terminus_t *, _Bool)
/* 243 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 244 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 1),
/* 245 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 246 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_terminus_t *, char const *)
/* 247 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 248 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 249 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 250 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_terminus_t *, pn_distribution_mode_t)
/* 251 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 252 */ _CFFI_OP(_CFFI_OP_ENUM, 0), // pn_distribution_mode_t
/* 253 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 254 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_terminus_t *, pn_durability_t)
/* 255 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 256 */ _CFFI_OP(_CFFI_OP_ENUM, 1), // pn_durability_t
/* 257 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 258 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_terminus_t *, pn_expiry_policy_t)
/* 259 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 260 */ _CFFI_OP(_CFFI_OP_ENUM, 3), // pn_expiry_policy_t
/* 261 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 262 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_terminus_t *, pn_terminus_t *)
/* 263 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 264 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 265 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 266 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_terminus_t *, pn_terminus_type_t)
/* 267 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 268 */ _CFFI_OP(_CFFI_OP_ENUM, 12), // pn_terminus_type_t
/* 269 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 270 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_terminus_t *, uint32_t)
/* 271 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 272 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 22),
/* 273 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 274 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_transport_t *)
/* 275 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 276 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 277 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_transport_t *, pn_connection_t *)
/* 278 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 279 */ _CFFI_OP(_CFFI_OP_NOOP, 48),
/* 280 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 281 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(pn_transport_t *, uint16_t)
/* 282 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 283 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 20),
/* 284 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 285 */ _CFFI_OP(_CFFI_OP_FUNCTION, 427), // int()(void *)
/* 286 */ _CFFI_OP(_CFFI_OP_NOOP, 42),
/* 287 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 288 */ _CFFI_OP(_CFFI_OP_FUNCTION, 116), // int16_t()(pn_data_t *)
/* 289 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 290 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 291 */ _CFFI_OP(_CFFI_OP_FUNCTION, 120), // int32_t()(pn_data_t *)
/* 292 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 293 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 294 */ _CFFI_OP(_CFFI_OP_FUNCTION, 124), // int64_t()(pn_data_t *)
/* 295 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 296 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 297 */ _CFFI_OP(_CFFI_OP_FUNCTION, 124), // int64_t()(pn_message_t *)
/* 298 */ _CFFI_OP(_CFFI_OP_NOOP, 23),
/* 299 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 300 */ _CFFI_OP(_CFFI_OP_FUNCTION, 124), // int64_t()(pn_transport_t *, int64_t)
/* 301 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 302 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 23),
/* 303 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 304 */ _CFFI_OP(_CFFI_OP_FUNCTION, 128), // int8_t()(pn_data_t *)
/* 305 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 306 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 307 */ _CFFI_OP(_CFFI_OP_FUNCTION, 187), // pn_atom_t()(pn_message_t *)
/* 308 */ _CFFI_OP(_CFFI_OP_NOOP, 23),
/* 309 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 310 */ _CFFI_OP(_CFFI_OP_FUNCTION, 132), // pn_bytes_t()(pn_data_t *)
/* 311 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 312 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 313 */ _CFFI_OP(_CFFI_OP_FUNCTION, 132), // pn_bytes_t()(pn_delivery_t *)
/* 314 */ _CFFI_OP(_CFFI_OP_NOOP, 14),
/* 315 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 316 */ _CFFI_OP(_CFFI_OP_FUNCTION, 132), // pn_bytes_t()(pn_message_t *)
/* 317 */ _CFFI_OP(_CFFI_OP_NOOP, 23),
/* 318 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 319 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // pn_collector_t *()(void)
/* 320 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 321 */ _CFFI_OP(_CFFI_OP_FUNCTION, 4), // pn_condition_t *()(pn_connection_t *)
/* 322 */ _CFFI_OP(_CFFI_OP_NOOP, 48),
/* 323 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 324 */ _CFFI_OP(_CFFI_OP_FUNCTION, 4), // pn_condition_t *()(pn_disposition_t *)
/* 325 */ _CFFI_OP(_CFFI_OP_NOOP, 17),
/* 326 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 327 */ _CFFI_OP(_CFFI_OP_FUNCTION, 4), // pn_condition_t *()(pn_link_t *)
/* 328 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 329 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 330 */ _CFFI_OP(_CFFI_OP_FUNCTION, 4), // pn_condition_t *()(pn_session_t *)
/* 331 */ _CFFI_OP(_CFFI_OP_NOOP, 202),
/* 332 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 333 */ _CFFI_OP(_CFFI_OP_FUNCTION, 4), // pn_condition_t *()(pn_transport_t *)
/* 334 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 335 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 336 */ _CFFI_OP(_CFFI_OP_FUNCTION, 48), // pn_connection_t *()(pn_event_t *)
/* 337 */ _CFFI_OP(_CFFI_OP_NOOP, 54),
/* 338 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 339 */ _CFFI_OP(_CFFI_OP_FUNCTION, 48), // pn_connection_t *()(pn_session_t *)
/* 340 */ _CFFI_OP(_CFFI_OP_NOOP, 202),
/* 341 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 342 */ _CFFI_OP(_CFFI_OP_FUNCTION, 48), // pn_connection_t *()(pn_transport_t *)
/* 343 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 344 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 345 */ _CFFI_OP(_CFFI_OP_FUNCTION, 48), // pn_connection_t *()(void *)
/* 346 */ _CFFI_OP(_CFFI_OP_NOOP, 42),
/* 347 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 348 */ _CFFI_OP(_CFFI_OP_FUNCTION, 48), // pn_connection_t *()(void)
/* 349 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 350 */ _CFFI_OP(_CFFI_OP_FUNCTION, 7), // pn_data_t *()(pn_condition_t *)
/* 351 */ _CFFI_OP(_CFFI_OP_NOOP, 4),
/* 352 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 353 */ _CFFI_OP(_CFFI_OP_FUNCTION, 7), // pn_data_t *()(pn_connection_t *)
/* 354 */ _CFFI_OP(_CFFI_OP_NOOP, 48),
/* 355 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 356 */ _CFFI_OP(_CFFI_OP_FUNCTION, 7), // pn_data_t *()(pn_disposition_t *)
/* 357 */ _CFFI_OP(_CFFI_OP_NOOP, 17),
/* 358 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 359 */ _CFFI_OP(_CFFI_OP_FUNCTION, 7), // pn_data_t *()(pn_link_t *)
/* 360 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 361 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 362 */ _CFFI_OP(_CFFI_OP_FUNCTION, 7), // pn_data_t *()(pn_message_t *)
/* 363 */ _CFFI_OP(_CFFI_OP_NOOP, 23),
/* 364 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 365 */ _CFFI_OP(_CFFI_OP_FUNCTION, 7), // pn_data_t *()(pn_terminus_t *)
/* 366 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 367 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 368 */ _CFFI_OP(_CFFI_OP_FUNCTION, 7), // pn_data_t *()(size_t)
/* 369 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 370 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 371 */ _CFFI_OP(_CFFI_OP_FUNCTION, 140), // pn_decimal128_t()(pn_data_t *)
/* 372 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 373 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 374 */ _CFFI_OP(_CFFI_OP_FUNCTION, 14), // pn_delivery_t *()(pn_event_t *)
/* 375 */ _CFFI_OP(_CFFI_OP_NOOP, 54),
/* 376 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 377 */ _CFFI_OP(_CFFI_OP_FUNCTION, 14), // pn_delivery_t *()(pn_link_t *)
/* 378 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 379 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 380 */ _CFFI_OP(_CFFI_OP_FUNCTION, 14), // pn_delivery_t *()(pn_link_t *, pn_bytes_t)
/* 381 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 382 */ _CFFI_OP(_CFFI_OP_NOOP, 132),
/* 383 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 384 */ _CFFI_OP(_CFFI_OP_FUNCTION, 14), // pn_delivery_t *()(void *)
/* 385 */ _CFFI_OP(_CFFI_OP_NOOP, 42),
/* 386 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 387 */ _CFFI_OP(_CFFI_OP_FUNCTION, 17), // pn_disposition_t *()(pn_delivery_t *)
/* 388 */ _CFFI_OP(_CFFI_OP_NOOP, 14),
/* 389 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 390 */ _CFFI_OP(_CFFI_OP_FUNCTION, 252), // pn_distribution_mode_t()(pn_terminus_t const *)
/* 391 */ _CFFI_OP(_CFFI_OP_POINTER, 773), // pn_terminus_t const *
/* 392 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 393 */ _CFFI_OP(_CFFI_OP_FUNCTION, 256), // pn_durability_t()(pn_terminus_t *)
/* 394 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 395 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 396 */ _CFFI_OP(_CFFI_OP_FUNCTION, 51), // pn_error_t *()(pn_connection_t *)
/* 397 */ _CFFI_OP(_CFFI_OP_NOOP, 48),
/* 398 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 399 */ _CFFI_OP(_CFFI_OP_FUNCTION, 51), // pn_error_t *()(pn_data_t *)
/* 400 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 401 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 402 */ _CFFI_OP(_CFFI_OP_FUNCTION, 51), // pn_error_t *()(pn_link_t *)
/* 403 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 404 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 405 */ _CFFI_OP(_CFFI_OP_FUNCTION, 51), // pn_error_t *()(pn_message_t *)
/* 406 */ _CFFI_OP(_CFFI_OP_NOOP, 23),
/* 407 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 408 */ _CFFI_OP(_CFFI_OP_FUNCTION, 51), // pn_error_t *()(pn_transport_t *)
/* 409 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 410 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 411 */ _CFFI_OP(_CFFI_OP_FUNCTION, 54), // pn_event_t *()(pn_collector_t *)
/* 412 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 413 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 414 */ _CFFI_OP(_CFFI_OP_FUNCTION, 54), // pn_event_t *()(pn_collector_t *, void *, pn_event_type_t)
/* 415 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 416 */ _CFFI_OP(_CFFI_OP_NOOP, 42),
/* 417 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 418 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 419 */ _CFFI_OP(_CFFI_OP_FUNCTION, 57), // pn_event_type_t()(pn_event_t *)
/* 420 */ _CFFI_OP(_CFFI_OP_NOOP, 54),
/* 421 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 422 */ _CFFI_OP(_CFFI_OP_FUNCTION, 260), // pn_expiry_policy_t()(pn_terminus_t *)
/* 423 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 424 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 425 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // pn_link_t *()(pn_connection_t *, int)
/* 426 */ _CFFI_OP(_CFFI_OP_NOOP, 48),
/* 427 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7), // int
/* 428 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 429 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // pn_link_t *()(pn_delivery_t *)
/* 430 */ _CFFI_OP(_CFFI_OP_NOOP, 14),
/* 431 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 432 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // pn_link_t *()(pn_event_t *)
/* 433 */ _CFFI_OP(_CFFI_OP_NOOP, 54),
/* 434 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 435 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // pn_link_t *()(pn_link_t *, int)
/* 436 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 437 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 438 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 439 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // pn_link_t *()(pn_session_t *, char const *)
/* 440 */ _CFFI_OP(_CFFI_OP_NOOP, 202),
/* 441 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 442 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 443 */ _CFFI_OP(_CFFI_OP_FUNCTION, 20), // pn_link_t *()(void *)
/* 444 */ _CFFI_OP(_CFFI_OP_NOOP, 42),
/* 445 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 446 */ _CFFI_OP(_CFFI_OP_FUNCTION, 23), // pn_message_t *()(void)
/* 447 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 448 */ _CFFI_OP(_CFFI_OP_FUNCTION, 680), // pn_rcv_settle_mode_t()(pn_link_t *)
/* 449 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 450 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 451 */ _CFFI_OP(_CFFI_OP_FUNCTION, 623), // pn_record_t *()(pn_connection_t *)
/* 452 */ _CFFI_OP(_CFFI_OP_NOOP, 48),
/* 453 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 454 */ _CFFI_OP(_CFFI_OP_FUNCTION, 623), // pn_record_t *()(pn_delivery_t *)
/* 455 */ _CFFI_OP(_CFFI_OP_NOOP, 14),
/* 456 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 457 */ _CFFI_OP(_CFFI_OP_FUNCTION, 623), // pn_record_t *()(pn_link_t *)
/* 458 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 459 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 460 */ _CFFI_OP(_CFFI_OP_FUNCTION, 623), // pn_record_t *()(pn_session_t *)
/* 461 */ _CFFI_OP(_CFFI_OP_NOOP, 202),
/* 462 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 463 */ _CFFI_OP(_CFFI_OP_FUNCTION, 623), // pn_record_t *()(pn_transport_t *)
/* 464 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 465 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 466 */ _CFFI_OP(_CFFI_OP_FUNCTION, 710), // pn_sasl_outcome_t()(pn_sasl_t *)
/* 467 */ _CFFI_OP(_CFFI_OP_NOOP, 26),
/* 468 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 469 */ _CFFI_OP(_CFFI_OP_FUNCTION, 26), // pn_sasl_t *()(pn_transport_t *)
/* 470 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 471 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 472 */ _CFFI_OP(_CFFI_OP_FUNCTION, 202), // pn_session_t *()(pn_connection_t *)
/* 473 */ _CFFI_OP(_CFFI_OP_NOOP, 48),
/* 474 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 475 */ _CFFI_OP(_CFFI_OP_FUNCTION, 202), // pn_session_t *()(pn_connection_t *, int)
/* 476 */ _CFFI_OP(_CFFI_OP_NOOP, 48),
/* 477 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 478 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 479 */ _CFFI_OP(_CFFI_OP_FUNCTION, 202), // pn_session_t *()(pn_event_t *)
/* 480 */ _CFFI_OP(_CFFI_OP_NOOP, 54),
/* 481 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 482 */ _CFFI_OP(_CFFI_OP_FUNCTION, 202), // pn_session_t *()(pn_link_t *)
/* 483 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 484 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 485 */ _CFFI_OP(_CFFI_OP_FUNCTION, 202), // pn_session_t *()(pn_session_t *, int)
/* 486 */ _CFFI_OP(_CFFI_OP_NOOP, 202),
/* 487 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 488 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 489 */ _CFFI_OP(_CFFI_OP_FUNCTION, 202), // pn_session_t *()(void *)
/* 490 */ _CFFI_OP(_CFFI_OP_NOOP, 42),
/* 491 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 492 */ _CFFI_OP(_CFFI_OP_FUNCTION, 684), // pn_snd_settle_mode_t()(pn_link_t *)
/* 493 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 494 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 495 */ _CFFI_OP(_CFFI_OP_FUNCTION, 205), // pn_ssl_domain_t *()(pn_ssl_mode_t)
/* 496 */ _CFFI_OP(_CFFI_OP_ENUM, 9), // pn_ssl_mode_t
/* 497 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 498 */ _CFFI_OP(_CFFI_OP_FUNCTION, 771), // pn_ssl_resume_status_t()(pn_ssl_t *)
/* 499 */ _CFFI_OP(_CFFI_OP_NOOP, 29),
/* 500 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 501 */ _CFFI_OP(_CFFI_OP_FUNCTION, 29), // pn_ssl_t *()(pn_transport_t *)
/* 502 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 503 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 504 */ _CFFI_OP(_CFFI_OP_FUNCTION, 34), // pn_terminus_t *()(pn_link_t *)
/* 505 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 506 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 507 */ _CFFI_OP(_CFFI_OP_FUNCTION, 268), // pn_terminus_type_t()(pn_terminus_t *)
/* 508 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 509 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 510 */ _CFFI_OP(_CFFI_OP_FUNCTION, 37), // pn_transport_t *()(pn_connection_t *)
/* 511 */ _CFFI_OP(_CFFI_OP_NOOP, 48),
/* 512 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 513 */ _CFFI_OP(_CFFI_OP_FUNCTION, 37), // pn_transport_t *()(pn_event_t *)
/* 514 */ _CFFI_OP(_CFFI_OP_NOOP, 54),
/* 515 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 516 */ _CFFI_OP(_CFFI_OP_FUNCTION, 37), // pn_transport_t *()(void *)
/* 517 */ _CFFI_OP(_CFFI_OP_NOOP, 42),
/* 518 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 519 */ _CFFI_OP(_CFFI_OP_FUNCTION, 37), // pn_transport_t *()(void)
/* 520 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 521 */ _CFFI_OP(_CFFI_OP_FUNCTION, 104), // pn_type_t()(pn_data_t *)
/* 522 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 523 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 524 */ _CFFI_OP(_CFFI_OP_FUNCTION, 144), // pn_uuid_t()(pn_data_t *)
/* 525 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 526 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 527 */ _CFFI_OP(_CFFI_OP_FUNCTION, 31), // size_t()(pn_data_t *)
/* 528 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 529 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 530 */ _CFFI_OP(_CFFI_OP_FUNCTION, 31), // size_t()(pn_delivery_t *)
/* 531 */ _CFFI_OP(_CFFI_OP_NOOP, 14),
/* 532 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 533 */ _CFFI_OP(_CFFI_OP_FUNCTION, 31), // size_t()(pn_session_t *)
/* 534 */ _CFFI_OP(_CFFI_OP_NOOP, 202),
/* 535 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 536 */ _CFFI_OP(_CFFI_OP_FUNCTION, 775), // ssize_t()(pn_data_t *)
/* 537 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 538 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 539 */ _CFFI_OP(_CFFI_OP_FUNCTION, 775), // ssize_t()(pn_data_t *, char *, size_t)
/* 540 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 541 */ _CFFI_OP(_CFFI_OP_NOOP, 30),
/* 542 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 543 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 544 */ _CFFI_OP(_CFFI_OP_FUNCTION, 775), // ssize_t()(pn_data_t *, char const *, size_t)
/* 545 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 546 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 547 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 548 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 549 */ _CFFI_OP(_CFFI_OP_FUNCTION, 775), // ssize_t()(pn_link_t *, char *, size_t)
/* 550 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 551 */ _CFFI_OP(_CFFI_OP_NOOP, 30),
/* 552 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 553 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 554 */ _CFFI_OP(_CFFI_OP_FUNCTION, 775), // ssize_t()(pn_link_t *, char const *, size_t)
/* 555 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 556 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 557 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 558 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 559 */ _CFFI_OP(_CFFI_OP_FUNCTION, 775), // ssize_t()(pn_message_t *, char *, size_t)
/* 560 */ _CFFI_OP(_CFFI_OP_NOOP, 23),
/* 561 */ _CFFI_OP(_CFFI_OP_NOOP, 30),
/* 562 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 563 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 564 */ _CFFI_OP(_CFFI_OP_FUNCTION, 775), // ssize_t()(pn_transport_t *)
/* 565 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 566 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 567 */ _CFFI_OP(_CFFI_OP_FUNCTION, 775), // ssize_t()(pn_transport_t *, char *, size_t)
/* 568 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 569 */ _CFFI_OP(_CFFI_OP_NOOP, 30),
/* 570 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 571 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 572 */ _CFFI_OP(_CFFI_OP_FUNCTION, 775), // ssize_t()(pn_transport_t *, char const *, size_t)
/* 573 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 574 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 575 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 576 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 577 */ _CFFI_OP(_CFFI_OP_FUNCTION, 148), // uint16_t()(pn_data_t *)
/* 578 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 579 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 580 */ _CFFI_OP(_CFFI_OP_FUNCTION, 148), // uint16_t()(pn_transport_t *)
/* 581 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 582 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 583 */ _CFFI_OP(_CFFI_OP_FUNCTION, 152), // uint32_t()(pn_data_t *)
/* 584 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 585 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 586 */ _CFFI_OP(_CFFI_OP_FUNCTION, 152), // uint32_t()(pn_disposition_t *)
/* 587 */ _CFFI_OP(_CFFI_OP_NOOP, 17),
/* 588 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 589 */ _CFFI_OP(_CFFI_OP_FUNCTION, 152), // uint32_t()(pn_message_t *)
/* 590 */ _CFFI_OP(_CFFI_OP_NOOP, 23),
/* 591 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 592 */ _CFFI_OP(_CFFI_OP_FUNCTION, 152), // uint32_t()(pn_terminus_t *)
/* 593 */ _CFFI_OP(_CFFI_OP_NOOP, 34),
/* 594 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 595 */ _CFFI_OP(_CFFI_OP_FUNCTION, 152), // uint32_t()(pn_transport_t *)
/* 596 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 597 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 598 */ _CFFI_OP(_CFFI_OP_FUNCTION, 156), // uint64_t()(pn_data_t *)
/* 599 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 600 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 601 */ _CFFI_OP(_CFFI_OP_FUNCTION, 156), // uint64_t()(pn_delivery_t *)
/* 602 */ _CFFI_OP(_CFFI_OP_NOOP, 14),
/* 603 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 604 */ _CFFI_OP(_CFFI_OP_FUNCTION, 156), // uint64_t()(pn_disposition_t *)
/* 605 */ _CFFI_OP(_CFFI_OP_NOOP, 17),
/* 606 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 607 */ _CFFI_OP(_CFFI_OP_FUNCTION, 156), // uint64_t()(pn_link_t *)
/* 608 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 609 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 610 */ _CFFI_OP(_CFFI_OP_FUNCTION, 156), // uint64_t()(pn_transport_t const *)
/* 611 */ _CFFI_OP(_CFFI_OP_POINTER, 774), // pn_transport_t const *
/* 612 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 613 */ _CFFI_OP(_CFFI_OP_FUNCTION, 160), // uint8_t()(pn_data_t *)
/* 614 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 615 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 616 */ _CFFI_OP(_CFFI_OP_FUNCTION, 160), // uint8_t()(pn_message_t *)
/* 617 */ _CFFI_OP(_CFFI_OP_NOOP, 23),
/* 618 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 619 */ _CFFI_OP(_CFFI_OP_FUNCTION, 42), // void *()(pn_event_t *)
/* 620 */ _CFFI_OP(_CFFI_OP_NOOP, 54),
/* 621 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 622 */ _CFFI_OP(_CFFI_OP_FUNCTION, 42), // void *()(pn_record_t *)
/* 623 */ _CFFI_OP(_CFFI_OP_POINTER, 767), // pn_record_t *
/* 624 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 625 */ _CFFI_OP(_CFFI_OP_FUNCTION, 42), // void *()(void *)
/* 626 */ _CFFI_OP(_CFFI_OP_NOOP, 42),
/* 627 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 628 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_collector_t *)
/* 629 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 630 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 631 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_condition_t *)
/* 632 */ _CFFI_OP(_CFFI_OP_NOOP, 4),
/* 633 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 634 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_connection_t *)
/* 635 */ _CFFI_OP(_CFFI_OP_NOOP, 48),
/* 636 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 637 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_connection_t *, char const *)
/* 638 */ _CFFI_OP(_CFFI_OP_NOOP, 48),
/* 639 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 640 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 641 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_connection_t *, pn_collector_t *)
/* 642 */ _CFFI_OP(_CFFI_OP_NOOP, 48),
/* 643 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 644 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 645 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_data_t *)
/* 646 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 647 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 648 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_delivery_t *)
/* 649 */ _CFFI_OP(_CFFI_OP_NOOP, 14),
/* 650 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 651 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_delivery_t *, uint64_t)
/* 652 */ _CFFI_OP(_CFFI_OP_NOOP, 14),
/* 653 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 24),
/* 654 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 655 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_disposition_t *, _Bool)
/* 656 */ _CFFI_OP(_CFFI_OP_NOOP, 17),
/* 657 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 1),
/* 658 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 659 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_disposition_t *, uint32_t)
/* 660 */ _CFFI_OP(_CFFI_OP_NOOP, 17),
/* 661 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 22),
/* 662 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 663 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_disposition_t *, uint64_t)
/* 664 */ _CFFI_OP(_CFFI_OP_NOOP, 17),
/* 665 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 24),
/* 666 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 667 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_link_t *)
/* 668 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 669 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 670 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_link_t *, _Bool)
/* 671 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 672 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 1),
/* 673 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 674 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_link_t *, int)
/* 675 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 676 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 677 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 678 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_link_t *, pn_rcv_settle_mode_t)
/* 679 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 680 */ _CFFI_OP(_CFFI_OP_ENUM, 4), // pn_rcv_settle_mode_t
/* 681 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 682 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_link_t *, pn_snd_settle_mode_t)
/* 683 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 684 */ _CFFI_OP(_CFFI_OP_ENUM, 6), // pn_snd_settle_mode_t
/* 685 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 686 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_link_t *, uint64_t)
/* 687 */ _CFFI_OP(_CFFI_OP_NOOP, 20),
/* 688 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 24),
/* 689 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 690 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_message_t *)
/* 691 */ _CFFI_OP(_CFFI_OP_NOOP, 23),
/* 692 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 693 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_record_t *)
/* 694 */ _CFFI_OP(_CFFI_OP_NOOP, 623),
/* 695 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 696 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_record_t *, void *)
/* 697 */ _CFFI_OP(_CFFI_OP_NOOP, 623),
/* 698 */ _CFFI_OP(_CFFI_OP_NOOP, 42),
/* 699 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 700 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_sasl_t *, _Bool)
/* 701 */ _CFFI_OP(_CFFI_OP_NOOP, 26),
/* 702 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 1),
/* 703 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 704 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_sasl_t *, char const *)
/* 705 */ _CFFI_OP(_CFFI_OP_NOOP, 26),
/* 706 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 707 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 708 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_sasl_t *, pn_sasl_outcome_t)
/* 709 */ _CFFI_OP(_CFFI_OP_NOOP, 26),
/* 710 */ _CFFI_OP(_CFFI_OP_ENUM, 5), // pn_sasl_outcome_t
/* 711 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 712 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_session_t *)
/* 713 */ _CFFI_OP(_CFFI_OP_NOOP, 202),
/* 714 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 715 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_session_t *, size_t)
/* 716 */ _CFFI_OP(_CFFI_OP_NOOP, 202),
/* 717 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 718 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 719 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_ssl_domain_t *)
/* 720 */ _CFFI_OP(_CFFI_OP_NOOP, 205),
/* 721 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 722 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_transport_t *)
/* 723 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 724 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 725 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_transport_t *, _Bool)
/* 726 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 727 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 1),
/* 728 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 729 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_transport_t *, char const *)
/* 730 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 731 */ _CFFI_OP(_CFFI_OP_NOOP, 11),
/* 732 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 733 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_transport_t *, int)
/* 734 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 735 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 736 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 737 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_transport_t *, size_t)
/* 738 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 739 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 740 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 741 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_transport_t *, uint32_t)
/* 742 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 743 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 22),
/* 744 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 745 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(pn_transport_t *, void(*)(pn_transport_t *, char const *))
/* 746 */ _CFFI_OP(_CFFI_OP_NOOP, 37),
/* 747 */ _CFFI_OP(_CFFI_OP_POINTER, 729), // void(*)(pn_transport_t *, char const *)
/* 748 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 749 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(void *)
/* 750 */ _CFFI_OP(_CFFI_OP_NOOP, 42),
/* 751 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 752 */ _CFFI_OP(_CFFI_OP_FUNCTION, 778), // void()(void)
/* 753 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 754 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 2), // char
/* 755 */ _CFFI_OP(_CFFI_OP_ARRAY, 754), // char[16]
/* 756 */ (_cffi_opcode_t)(16),
/* 757 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 5), // pn_collector_t
/* 758 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 6), // pn_condition_t
/* 759 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 7), // pn_connection_t
/* 760 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 8), // pn_data_t
/* 761 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 9), // pn_delivery_t
/* 762 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 10), // pn_disposition_t
/* 763 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 11), // pn_error_t
/* 764 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 12), // pn_event_t
/* 765 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 13), // pn_link_t
/* 766 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 14), // pn_message_t
/* 767 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 15), // pn_record_t
/* 768 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 16), // pn_sasl_t
/* 769 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 17), // pn_session_t
/* 770 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 18), // pn_ssl_domain_t
/* 771 */ _CFFI_OP(_CFFI_OP_ENUM, 10), // pn_ssl_resume_status_t
/* 772 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 19), // pn_ssl_t
/* 773 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 20), // pn_terminus_t
/* 774 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 21), // pn_transport_t
/* 775 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 29), // ssize_t
/* 776 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 0), // union $1
/* 777 */ _CFFI_OP(_CFFI_OP_POINTER, 749), // void(*)(void *)
/* 778 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 0), // void
};

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_pn_atom_t(pn_atom_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { pn_type_t *tmp = &p->type; (void)tmp; }
  /* cannot generate 'union $1' in field 'u': unknown type name */
}
struct _cffi_align_typedef_pn_atom_t { char x; pn_atom_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_pn_decimal128_t(pn_decimal128_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char(*tmp)[16] = &p->bytes; (void)tmp; }
}
struct _cffi_align_typedef_pn_decimal128_t { char x; pn_decimal128_t y; };

static int _cffi_const_PN_DIST_MODE_UNSPECIFIED(unsigned long long *o)
{
  int n = (PN_DIST_MODE_UNSPECIFIED) <= 0;
  *o = (unsigned long long)((PN_DIST_MODE_UNSPECIFIED) | 0);  /* check that PN_DIST_MODE_UNSPECIFIED is an integer */
  return n;
}

static int _cffi_const_PN_DIST_MODE_COPY(unsigned long long *o)
{
  int n = (PN_DIST_MODE_COPY) <= 0;
  *o = (unsigned long long)((PN_DIST_MODE_COPY) | 0);  /* check that PN_DIST_MODE_COPY is an integer */
  return n;
}

static int _cffi_const_PN_DIST_MODE_MOVE(unsigned long long *o)
{
  int n = (PN_DIST_MODE_MOVE) <= 0;
  *o = (unsigned long long)((PN_DIST_MODE_MOVE) | 0);  /* check that PN_DIST_MODE_MOVE is an integer */
  return n;
}

static int _cffi_const_PN_NONDURABLE(unsigned long long *o)
{
  int n = (PN_NONDURABLE) <= 0;
  *o = (unsigned long long)((PN_NONDURABLE) | 0);  /* check that PN_NONDURABLE is an integer */
  return n;
}

static int _cffi_const_PN_CONFIGURATION(unsigned long long *o)
{
  int n = (PN_CONFIGURATION) <= 0;
  *o = (unsigned long long)((PN_CONFIGURATION) | 0);  /* check that PN_CONFIGURATION is an integer */
  return n;
}

static int _cffi_const_PN_DELIVERIES(unsigned long long *o)
{
  int n = (PN_DELIVERIES) <= 0;
  *o = (unsigned long long)((PN_DELIVERIES) | 0);  /* check that PN_DELIVERIES is an integer */
  return n;
}

static int _cffi_const_PN_EVENT_NONE(unsigned long long *o)
{
  int n = (PN_EVENT_NONE) <= 0;
  *o = (unsigned long long)((PN_EVENT_NONE) | 0);  /* check that PN_EVENT_NONE is an integer */
  return n;
}

static int _cffi_const_PN_REACTOR_INIT(unsigned long long *o)
{
  int n = (PN_REACTOR_INIT) <= 0;
  *o = (unsigned long long)((PN_REACTOR_INIT) | 0);  /* check that PN_REACTOR_INIT is an integer */
  return n;
}

static int _cffi_const_PN_REACTOR_QUIESCED(unsigned long long *o)
{
  int n = (PN_REACTOR_QUIESCED) <= 0;
  *o = (unsigned long long)((PN_REACTOR_QUIESCED) | 0);  /* check that PN_REACTOR_QUIESCED is an integer */
  return n;
}

static int _cffi_const_PN_REACTOR_FINAL(unsigned long long *o)
{
  int n = (PN_REACTOR_FINAL) <= 0;
  *o = (unsigned long long)((PN_REACTOR_FINAL) | 0);  /* check that PN_REACTOR_FINAL is an integer */
  return n;
}

static int _cffi_const_PN_TIMER_TASK(unsigned long long *o)
{
  int n = (PN_TIMER_TASK) <= 0;
  *o = (unsigned long long)((PN_TIMER_TASK) | 0);  /* check that PN_TIMER_TASK is an integer */
  return n;
}

static int _cffi_const_PN_CONNECTION_INIT(unsigned long long *o)
{
  int n = (PN_CONNECTION_INIT) <= 0;
  *o = (unsigned long long)((PN_CONNECTION_INIT) | 0);  /* check that PN_CONNECTION_INIT is an integer */
  return n;
}

static int _cffi_const_PN_CONNECTION_BOUND(unsigned long long *o)
{
  int n = (PN_CONNECTION_BOUND) <= 0;
  *o = (unsigned long long)((PN_CONNECTION_BOUND) | 0);  /* check that PN_CONNECTION_BOUND is an integer */
  return n;
}

static int _cffi_const_PN_CONNECTION_UNBOUND(unsigned long long *o)
{
  int n = (PN_CONNECTION_UNBOUND) <= 0;
  *o = (unsigned long long)((PN_CONNECTION_UNBOUND) | 0);  /* check that PN_CONNECTION_UNBOUND is an integer */
  return n;
}

static int _cffi_const_PN_CONNECTION_LOCAL_OPEN(unsigned long long *o)
{
  int n = (PN_CONNECTION_LOCAL_OPEN) <= 0;
  *o = (unsigned long long)((PN_CONNECTION_LOCAL_OPEN) | 0);  /* check that PN_CONNECTION_LOCAL_OPEN is an integer */
  return n;
}

static int _cffi_const_PN_CONNECTION_REMOTE_OPEN(unsigned long long *o)
{
  int n = (PN_CONNECTION_REMOTE_OPEN) <= 0;
  *o = (unsigned long long)((PN_CONNECTION_REMOTE_OPEN) | 0);  /* check that PN_CONNECTION_REMOTE_OPEN is an integer */
  return n;
}

static int _cffi_const_PN_CONNECTION_LOCAL_CLOSE(unsigned long long *o)
{
  int n = (PN_CONNECTION_LOCAL_CLOSE) <= 0;
  *o = (unsigned long long)((PN_CONNECTION_LOCAL_CLOSE) | 0);  /* check that PN_CONNECTION_LOCAL_CLOSE is an integer */
  return n;
}

static int _cffi_const_PN_CONNECTION_REMOTE_CLOSE(unsigned long long *o)
{
  int n = (PN_CONNECTION_REMOTE_CLOSE) <= 0;
  *o = (unsigned long long)((PN_CONNECTION_REMOTE_CLOSE) | 0);  /* check that PN_CONNECTION_REMOTE_CLOSE is an integer */
  return n;
}

static int _cffi_const_PN_CONNECTION_FINAL(unsigned long long *o)
{
  int n = (PN_CONNECTION_FINAL) <= 0;
  *o = (unsigned long long)((PN_CONNECTION_FINAL) | 0);  /* check that PN_CONNECTION_FINAL is an integer */
  return n;
}

static int _cffi_const_PN_SESSION_INIT(unsigned long long *o)
{
  int n = (PN_SESSION_INIT) <= 0;
  *o = (unsigned long long)((PN_SESSION_INIT) | 0);  /* check that PN_SESSION_INIT is an integer */
  return n;
}

static int _cffi_const_PN_SESSION_LOCAL_OPEN(unsigned long long *o)
{
  int n = (PN_SESSION_LOCAL_OPEN) <= 0;
  *o = (unsigned long long)((PN_SESSION_LOCAL_OPEN) | 0);  /* check that PN_SESSION_LOCAL_OPEN is an integer */
  return n;
}

static int _cffi_const_PN_SESSION_REMOTE_OPEN(unsigned long long *o)
{
  int n = (PN_SESSION_REMOTE_OPEN) <= 0;
  *o = (unsigned long long)((PN_SESSION_REMOTE_OPEN) | 0);  /* check that PN_SESSION_REMOTE_OPEN is an integer */
  return n;
}

static int _cffi_const_PN_SESSION_LOCAL_CLOSE(unsigned long long *o)
{
  int n = (PN_SESSION_LOCAL_CLOSE) <= 0;
  *o = (unsigned long long)((PN_SESSION_LOCAL_CLOSE) | 0);  /* check that PN_SESSION_LOCAL_CLOSE is an integer */
  return n;
}

static int _cffi_const_PN_SESSION_REMOTE_CLOSE(unsigned long long *o)
{
  int n = (PN_SESSION_REMOTE_CLOSE) <= 0;
  *o = (unsigned long long)((PN_SESSION_REMOTE_CLOSE) | 0);  /* check that PN_SESSION_REMOTE_CLOSE is an integer */
  return n;
}

static int _cffi_const_PN_SESSION_FINAL(unsigned long long *o)
{
  int n = (PN_SESSION_FINAL) <= 0;
  *o = (unsigned long long)((PN_SESSION_FINAL) | 0);  /* check that PN_SESSION_FINAL is an integer */
  return n;
}

static int _cffi_const_PN_LINK_INIT(unsigned long long *o)
{
  int n = (PN_LINK_INIT) <= 0;
  *o = (unsigned long long)((PN_LINK_INIT) | 0);  /* check that PN_LINK_INIT is an integer */
  return n;
}

static int _cffi_const_PN_LINK_LOCAL_OPEN(unsigned long long *o)
{
  int n = (PN_LINK_LOCAL_OPEN) <= 0;
  *o = (unsigned long long)((PN_LINK_LOCAL_OPEN) | 0);  /* check that PN_LINK_LOCAL_OPEN is an integer */
  return n;
}

static int _cffi_const_PN_LINK_REMOTE_OPEN(unsigned long long *o)
{
  int n = (PN_LINK_REMOTE_OPEN) <= 0;
  *o = (unsigned long long)((PN_LINK_REMOTE_OPEN) | 0);  /* check that PN_LINK_REMOTE_OPEN is an integer */
  return n;
}

static int _cffi_const_PN_LINK_LOCAL_CLOSE(unsigned long long *o)
{
  int n = (PN_LINK_LOCAL_CLOSE) <= 0;
  *o = (unsigned long long)((PN_LINK_LOCAL_CLOSE) | 0);  /* check that PN_LINK_LOCAL_CLOSE is an integer */
  return n;
}

static int _cffi_const_PN_LINK_REMOTE_CLOSE(unsigned long long *o)
{
  int n = (PN_LINK_REMOTE_CLOSE) <= 0;
  *o = (unsigned long long)((PN_LINK_REMOTE_CLOSE) | 0);  /* check that PN_LINK_REMOTE_CLOSE is an integer */
  return n;
}

static int _cffi_const_PN_LINK_LOCAL_DETACH(unsigned long long *o)
{
  int n = (PN_LINK_LOCAL_DETACH) <= 0;
  *o = (unsigned long long)((PN_LINK_LOCAL_DETACH) | 0);  /* check that PN_LINK_LOCAL_DETACH is an integer */
  return n;
}

static int _cffi_const_PN_LINK_REMOTE_DETACH(unsigned long long *o)
{
  int n = (PN_LINK_REMOTE_DETACH) <= 0;
  *o = (unsigned long long)((PN_LINK_REMOTE_DETACH) | 0);  /* check that PN_LINK_REMOTE_DETACH is an integer */
  return n;
}

static int _cffi_const_PN_LINK_FLOW(unsigned long long *o)
{
  int n = (PN_LINK_FLOW) <= 0;
  *o = (unsigned long long)((PN_LINK_FLOW) | 0);  /* check that PN_LINK_FLOW is an integer */
  return n;
}

static int _cffi_const_PN_LINK_FINAL(unsigned long long *o)
{
  int n = (PN_LINK_FINAL) <= 0;
  *o = (unsigned long long)((PN_LINK_FINAL) | 0);  /* check that PN_LINK_FINAL is an integer */
  return n;
}

static int _cffi_const_PN_DELIVERY(unsigned long long *o)
{
  int n = (PN_DELIVERY) <= 0;
  *o = (unsigned long long)((PN_DELIVERY) | 0);  /* check that PN_DELIVERY is an integer */
  return n;
}

static int _cffi_const_PN_TRANSPORT(unsigned long long *o)
{
  int n = (PN_TRANSPORT) <= 0;
  *o = (unsigned long long)((PN_TRANSPORT) | 0);  /* check that PN_TRANSPORT is an integer */
  return n;
}

static int _cffi_const_PN_TRANSPORT_AUTHENTICATED(unsigned long long *o)
{
  int n = (PN_TRANSPORT_AUTHENTICATED) <= 0;
  *o = (unsigned long long)((PN_TRANSPORT_AUTHENTICATED) | 0);  /* check that PN_TRANSPORT_AUTHENTICATED is an integer */
  return n;
}

static int _cffi_const_PN_TRANSPORT_ERROR(unsigned long long *o)
{
  int n = (PN_TRANSPORT_ERROR) <= 0;
  *o = (unsigned long long)((PN_TRANSPORT_ERROR) | 0);  /* check that PN_TRANSPORT_ERROR is an integer */
  return n;
}

static int _cffi_const_PN_TRANSPORT_HEAD_CLOSED(unsigned long long *o)
{
  int n = (PN_TRANSPORT_HEAD_CLOSED) <= 0;
  *o = (unsigned long long)((PN_TRANSPORT_HEAD_CLOSED) | 0);  /* check that PN_TRANSPORT_HEAD_CLOSED is an integer */
  return n;
}

static int _cffi_const_PN_TRANSPORT_TAIL_CLOSED(unsigned long long *o)
{
  int n = (PN_TRANSPORT_TAIL_CLOSED) <= 0;
  *o = (unsigned long long)((PN_TRANSPORT_TAIL_CLOSED) | 0);  /* check that PN_TRANSPORT_TAIL_CLOSED is an integer */
  return n;
}

static int _cffi_const_PN_TRANSPORT_CLOSED(unsigned long long *o)
{
  int n = (PN_TRANSPORT_CLOSED) <= 0;
  *o = (unsigned long long)((PN_TRANSPORT_CLOSED) | 0);  /* check that PN_TRANSPORT_CLOSED is an integer */
  return n;
}

static int _cffi_const_PN_SELECTABLE_INIT(unsigned long long *o)
{
  int n = (PN_SELECTABLE_INIT) <= 0;
  *o = (unsigned long long)((PN_SELECTABLE_INIT) | 0);  /* check that PN_SELECTABLE_INIT is an integer */
  return n;
}

static int _cffi_const_PN_SELECTABLE_UPDATED(unsigned long long *o)
{
  int n = (PN_SELECTABLE_UPDATED) <= 0;
  *o = (unsigned long long)((PN_SELECTABLE_UPDATED) | 0);  /* check that PN_SELECTABLE_UPDATED is an integer */
  return n;
}

static int _cffi_const_PN_SELECTABLE_READABLE(unsigned long long *o)
{
  int n = (PN_SELECTABLE_READABLE) <= 0;
  *o = (unsigned long long)((PN_SELECTABLE_READABLE) | 0);  /* check that PN_SELECTABLE_READABLE is an integer */
  return n;
}

static int _cffi_const_PN_SELECTABLE_WRITABLE(unsigned long long *o)
{
  int n = (PN_SELECTABLE_WRITABLE) <= 0;
  *o = (unsigned long long)((PN_SELECTABLE_WRITABLE) | 0);  /* check that PN_SELECTABLE_WRITABLE is an integer */
  return n;
}

static int _cffi_const_PN_SELECTABLE_ERROR(unsigned long long *o)
{
  int n = (PN_SELECTABLE_ERROR) <= 0;
  *o = (unsigned long long)((PN_SELECTABLE_ERROR) | 0);  /* check that PN_SELECTABLE_ERROR is an integer */
  return n;
}

static int _cffi_const_PN_SELECTABLE_EXPIRED(unsigned long long *o)
{
  int n = (PN_SELECTABLE_EXPIRED) <= 0;
  *o = (unsigned long long)((PN_SELECTABLE_EXPIRED) | 0);  /* check that PN_SELECTABLE_EXPIRED is an integer */
  return n;
}

static int _cffi_const_PN_SELECTABLE_FINAL(unsigned long long *o)
{
  int n = (PN_SELECTABLE_FINAL) <= 0;
  *o = (unsigned long long)((PN_SELECTABLE_FINAL) | 0);  /* check that PN_SELECTABLE_FINAL is an integer */
  return n;
}

static int _cffi_const_PN_CONNECTION_WAKE(unsigned long long *o)
{
  int n = (PN_CONNECTION_WAKE) <= 0;
  *o = (unsigned long long)((PN_CONNECTION_WAKE) | 0);  /* check that PN_CONNECTION_WAKE is an integer */
  return n;
}

static int _cffi_const_PN_LISTENER_ACCEPT(unsigned long long *o)
{
  int n = (PN_LISTENER_ACCEPT) <= 0;
  *o = (unsigned long long)((PN_LISTENER_ACCEPT) | 0);  /* check that PN_LISTENER_ACCEPT is an integer */
  return n;
}

static int _cffi_const_PN_LISTENER_CLOSE(unsigned long long *o)
{
  int n = (PN_LISTENER_CLOSE) <= 0;
  *o = (unsigned long long)((PN_LISTENER_CLOSE) | 0);  /* check that PN_LISTENER_CLOSE is an integer */
  return n;
}

static int _cffi_const_PN_PROACTOR_INTERRUPT(unsigned long long *o)
{
  int n = (PN_PROACTOR_INTERRUPT) <= 0;
  *o = (unsigned long long)((PN_PROACTOR_INTERRUPT) | 0);  /* check that PN_PROACTOR_INTERRUPT is an integer */
  return n;
}

static int _cffi_const_PN_PROACTOR_TIMEOUT(unsigned long long *o)
{
  int n = (PN_PROACTOR_TIMEOUT) <= 0;
  *o = (unsigned long long)((PN_PROACTOR_TIMEOUT) | 0);  /* check that PN_PROACTOR_TIMEOUT is an integer */
  return n;
}

static int _cffi_const_PN_PROACTOR_INACTIVE(unsigned long long *o)
{
  int n = (PN_PROACTOR_INACTIVE) <= 0;
  *o = (unsigned long long)((PN_PROACTOR_INACTIVE) | 0);  /* check that PN_PROACTOR_INACTIVE is an integer */
  return n;
}

static int _cffi_const_PN_LISTENER_OPEN(unsigned long long *o)
{
  int n = (PN_LISTENER_OPEN) <= 0;
  *o = (unsigned long long)((PN_LISTENER_OPEN) | 0);  /* check that PN_LISTENER_OPEN is an integer */
  return n;
}

static int _cffi_const_PN_RAW_CONNECTION_CONNECTED(unsigned long long *o)
{
  int n = (PN_RAW_CONNECTION_CONNECTED) <= 0;
  *o = (unsigned long long)((PN_RAW_CONNECTION_CONNECTED) | 0);  /* check that PN_RAW_CONNECTION_CONNECTED is an integer */
  return n;
}

static int _cffi_const_PN_RAW_CONNECTION_CLOSED_READ(unsigned long long *o)
{
  int n = (PN_RAW_CONNECTION_CLOSED_READ) <= 0;
  *o = (unsigned long long)((PN_RAW_CONNECTION_CLOSED_READ) | 0);  /* check that PN_RAW_CONNECTION_CLOSED_READ is an integer */
  return n;
}

static int _cffi_const_PN_RAW_CONNECTION_CLOSED_WRITE(unsigned long long *o)
{
  int n = (PN_RAW_CONNECTION_CLOSED_WRITE) <= 0;
  *o = (unsigned long long)((PN_RAW_CONNECTION_CLOSED_WRITE) | 0);  /* check that PN_RAW_CONNECTION_CLOSED_WRITE is an integer */
  return n;
}

static int _cffi_const_PN_RAW_CONNECTION_DISCONNECTED(unsigned long long *o)
{
  int n = (PN_RAW_CONNECTION_DISCONNECTED) <= 0;
  *o = (unsigned long long)((PN_RAW_CONNECTION_DISCONNECTED) | 0);  /* check that PN_RAW_CONNECTION_DISCONNECTED is an integer */
  return n;
}

static int _cffi_const_PN_RAW_CONNECTION_NEED_READ_BUFFERS(unsigned long long *o)
{
  int n = (PN_RAW_CONNECTION_NEED_READ_BUFFERS) <= 0;
  *o = (unsigned long long)((PN_RAW_CONNECTION_NEED_READ_BUFFERS) | 0);  /* check that PN_RAW_CONNECTION_NEED_READ_BUFFERS is an integer */
  return n;
}

static int _cffi_const_PN_RAW_CONNECTION_NEED_WRITE_BUFFERS(unsigned long long *o)
{
  int n = (PN_RAW_CONNECTION_NEED_WRITE_BUFFERS) <= 0;
  *o = (unsigned long long)((PN_RAW_CONNECTION_NEED_WRITE_BUFFERS) | 0);  /* check that PN_RAW_CONNECTION_NEED_WRITE_BUFFERS is an integer */
  return n;
}

static int _cffi_const_PN_RAW_CONNECTION_READ(unsigned long long *o)
{
  int n = (PN_RAW_CONNECTION_READ) <= 0;
  *o = (unsigned long long)((PN_RAW_CONNECTION_READ) | 0);  /* check that PN_RAW_CONNECTION_READ is an integer */
  return n;
}

static int _cffi_const_PN_RAW_CONNECTION_WRITTEN(unsigned long long *o)
{
  int n = (PN_RAW_CONNECTION_WRITTEN) <= 0;
  *o = (unsigned long long)((PN_RAW_CONNECTION_WRITTEN) | 0);  /* check that PN_RAW_CONNECTION_WRITTEN is an integer */
  return n;
}

static int _cffi_const_PN_RAW_CONNECTION_WAKE(unsigned long long *o)
{
  int n = (PN_RAW_CONNECTION_WAKE) <= 0;
  *o = (unsigned long long)((PN_RAW_CONNECTION_WAKE) | 0);  /* check that PN_RAW_CONNECTION_WAKE is an integer */
  return n;
}

static int _cffi_const_PN_RAW_CONNECTION_DRAIN_BUFFERS(unsigned long long *o)
{
  int n = (PN_RAW_CONNECTION_DRAIN_BUFFERS) <= 0;
  *o = (unsigned long long)((PN_RAW_CONNECTION_DRAIN_BUFFERS) | 0);  /* check that PN_RAW_CONNECTION_DRAIN_BUFFERS is an integer */
  return n;
}

static int _cffi_const_PN_EXPIRE_WITH_LINK(unsigned long long *o)
{
  int n = (PN_EXPIRE_WITH_LINK) <= 0;
  *o = (unsigned long long)((PN_EXPIRE_WITH_LINK) | 0);  /* check that PN_EXPIRE_WITH_LINK is an integer */
  return n;
}

static int _cffi_const_PN_EXPIRE_WITH_SESSION(unsigned long long *o)
{
  int n = (PN_EXPIRE_WITH_SESSION) <= 0;
  *o = (unsigned long long)((PN_EXPIRE_WITH_SESSION) | 0);  /* check that PN_EXPIRE_WITH_SESSION is an integer */
  return n;
}

static int _cffi_const_PN_EXPIRE_WITH_CONNECTION(unsigned long long *o)
{
  int n = (PN_EXPIRE_WITH_CONNECTION) <= 0;
  *o = (unsigned long long)((PN_EXPIRE_WITH_CONNECTION) | 0);  /* check that PN_EXPIRE_WITH_CONNECTION is an integer */
  return n;
}

static int _cffi_const_PN_EXPIRE_NEVER(unsigned long long *o)
{
  int n = (PN_EXPIRE_NEVER) <= 0;
  *o = (unsigned long long)((PN_EXPIRE_NEVER) | 0);  /* check that PN_EXPIRE_NEVER is an integer */
  return n;
}

static int _cffi_const_PN_RCV_FIRST(unsigned long long *o)
{
  int n = (PN_RCV_FIRST) <= 0;
  *o = (unsigned long long)((PN_RCV_FIRST) | 0);  /* check that PN_RCV_FIRST is an integer */
  return n;
}

static int _cffi_const_PN_RCV_SECOND(unsigned long long *o)
{
  int n = (PN_RCV_SECOND) <= 0;
  *o = (unsigned long long)((PN_RCV_SECOND) | 0);  /* check that PN_RCV_SECOND is an integer */
  return n;
}

static int _cffi_const_PN_SASL_NONE(unsigned long long *o)
{
  int n = (PN_SASL_NONE) <= 0;
  *o = (unsigned long long)((PN_SASL_NONE) | 0);  /* check that PN_SASL_NONE is an integer */
  return n;
}

static int _cffi_const_PN_SASL_OK(unsigned long long *o)
{
  int n = (PN_SASL_OK) <= 0;
  *o = (unsigned long long)((PN_SASL_OK) | 0);  /* check that PN_SASL_OK is an integer */
  return n;
}

static int _cffi_const_PN_SASL_AUTH(unsigned long long *o)
{
  int n = (PN_SASL_AUTH) <= 0;
  *o = (unsigned long long)((PN_SASL_AUTH) | 0);  /* check that PN_SASL_AUTH is an integer */
  return n;
}

static int _cffi_const_PN_SASL_SYS(unsigned long long *o)
{
  int n = (PN_SASL_SYS) <= 0;
  *o = (unsigned long long)((PN_SASL_SYS) | 0);  /* check that PN_SASL_SYS is an integer */
  return n;
}

static int _cffi_const_PN_SASL_PERM(unsigned long long *o)
{
  int n = (PN_SASL_PERM) <= 0;
  *o = (unsigned long long)((PN_SASL_PERM) | 0);  /* check that PN_SASL_PERM is an integer */
  return n;
}

static int _cffi_const_PN_SASL_TEMP(unsigned long long *o)
{
  int n = (PN_SASL_TEMP) <= 0;
  *o = (unsigned long long)((PN_SASL_TEMP) | 0);  /* check that PN_SASL_TEMP is an integer */
  return n;
}

static int _cffi_const_PN_SND_UNSETTLED(unsigned long long *o)
{
  int n = (PN_SND_UNSETTLED) <= 0;
  *o = (unsigned long long)((PN_SND_UNSETTLED) | 0);  /* check that PN_SND_UNSETTLED is an integer */
  return n;
}

static int _cffi_const_PN_SND_SETTLED(unsigned long long *o)
{
  int n = (PN_SND_SETTLED) <= 0;
  *o = (unsigned long long)((PN_SND_SETTLED) | 0);  /* check that PN_SND_SETTLED is an integer */
  return n;
}

static int _cffi_const_PN_SND_MIXED(unsigned long long *o)
{
  int n = (PN_SND_MIXED) <= 0;
  *o = (unsigned long long)((PN_SND_MIXED) | 0);  /* check that PN_SND_MIXED is an integer */
  return n;
}

static int _cffi_const_PN_SSL_CERT_SUBJECT_COUNTRY_NAME(unsigned long long *o)
{
  int n = (PN_SSL_CERT_SUBJECT_COUNTRY_NAME) <= 0;
  *o = (unsigned long long)((PN_SSL_CERT_SUBJECT_COUNTRY_NAME) | 0);  /* check that PN_SSL_CERT_SUBJECT_COUNTRY_NAME is an integer */
  return n;
}

static int _cffi_const_PN_SSL_CERT_SUBJECT_STATE_OR_PROVINCE(unsigned long long *o)
{
  int n = (PN_SSL_CERT_SUBJECT_STATE_OR_PROVINCE) <= 0;
  *o = (unsigned long long)((PN_SSL_CERT_SUBJECT_STATE_OR_PROVINCE) | 0);  /* check that PN_SSL_CERT_SUBJECT_STATE_OR_PROVINCE is an integer */
  return n;
}

static int _cffi_const_PN_SSL_CERT_SUBJECT_CITY_OR_LOCALITY(unsigned long long *o)
{
  int n = (PN_SSL_CERT_SUBJECT_CITY_OR_LOCALITY) <= 0;
  *o = (unsigned long long)((PN_SSL_CERT_SUBJECT_CITY_OR_LOCALITY) | 0);  /* check that PN_SSL_CERT_SUBJECT_CITY_OR_LOCALITY is an integer */
  return n;
}

static int _cffi_const_PN_SSL_CERT_SUBJECT_ORGANIZATION_NAME(unsigned long long *o)
{
  int n = (PN_SSL_CERT_SUBJECT_ORGANIZATION_NAME) <= 0;
  *o = (unsigned long long)((PN_SSL_CERT_SUBJECT_ORGANIZATION_NAME) | 0);  /* check that PN_SSL_CERT_SUBJECT_ORGANIZATION_NAME is an integer */
  return n;
}

static int _cffi_const_PN_SSL_CERT_SUBJECT_ORGANIZATION_UNIT(unsigned long long *o)
{
  int n = (PN_SSL_CERT_SUBJECT_ORGANIZATION_UNIT) <= 0;
  *o = (unsigned long long)((PN_SSL_CERT_SUBJECT_ORGANIZATION_UNIT) | 0);  /* check that PN_SSL_CERT_SUBJECT_ORGANIZATION_UNIT is an integer */
  return n;
}

static int _cffi_const_PN_SSL_CERT_SUBJECT_COMMON_NAME(unsigned long long *o)
{
  int n = (PN_SSL_CERT_SUBJECT_COMMON_NAME) <= 0;
  *o = (unsigned long long)((PN_SSL_CERT_SUBJECT_COMMON_NAME) | 0);  /* check that PN_SSL_CERT_SUBJECT_COMMON_NAME is an integer */
  return n;
}

static int _cffi_const_PN_SSL_SHA1(unsigned long long *o)
{
  int n = (PN_SSL_SHA1) <= 0;
  *o = (unsigned long long)((PN_SSL_SHA1) | 0);  /* check that PN_SSL_SHA1 is an integer */
  return n;
}

static int _cffi_const_PN_SSL_SHA256(unsigned long long *o)
{
  int n = (PN_SSL_SHA256) <= 0;
  *o = (unsigned long long)((PN_SSL_SHA256) | 0);  /* check that PN_SSL_SHA256 is an integer */
  return n;
}

static int _cffi_const_PN_SSL_SHA512(unsigned long long *o)
{
  int n = (PN_SSL_SHA512) <= 0;
  *o = (unsigned long long)((PN_SSL_SHA512) | 0);  /* check that PN_SSL_SHA512 is an integer */
  return n;
}

static int _cffi_const_PN_SSL_MD5(unsigned long long *o)
{
  int n = (PN_SSL_MD5) <= 0;
  *o = (unsigned long long)((PN_SSL_MD5) | 0);  /* check that PN_SSL_MD5 is an integer */
  return n;
}

static int _cffi_const_PN_SSL_MODE_CLIENT(unsigned long long *o)
{
  int n = (PN_SSL_MODE_CLIENT) <= 0;
  *o = (unsigned long long)((PN_SSL_MODE_CLIENT) | 0);  /* check that PN_SSL_MODE_CLIENT is an integer */
  return n;
}

static int _cffi_const_PN_SSL_MODE_SERVER(unsigned long long *o)
{
  int n = (PN_SSL_MODE_SERVER) <= 0;
  *o = (unsigned long long)((PN_SSL_MODE_SERVER) | 0);  /* check that PN_SSL_MODE_SERVER is an integer */
  return n;
}

static int _cffi_const_PN_SSL_RESUME_UNKNOWN(unsigned long long *o)
{
  int n = (PN_SSL_RESUME_UNKNOWN) <= 0;
  *o = (unsigned long long)((PN_SSL_RESUME_UNKNOWN) | 0);  /* check that PN_SSL_RESUME_UNKNOWN is an integer */
  return n;
}

static int _cffi_const_PN_SSL_RESUME_NEW(unsigned long long *o)
{
  int n = (PN_SSL_RESUME_NEW) <= 0;
  *o = (unsigned long long)((PN_SSL_RESUME_NEW) | 0);  /* check that PN_SSL_RESUME_NEW is an integer */
  return n;
}

static int _cffi_const_PN_SSL_RESUME_REUSED(unsigned long long *o)
{
  int n = (PN_SSL_RESUME_REUSED) <= 0;
  *o = (unsigned long long)((PN_SSL_RESUME_REUSED) | 0);  /* check that PN_SSL_RESUME_REUSED is an integer */
  return n;
}

static int _cffi_const_PN_SSL_VERIFY_NULL(unsigned long long *o)
{
  int n = (PN_SSL_VERIFY_NULL) <= 0;
  *o = (unsigned long long)((PN_SSL_VERIFY_NULL) | 0);  /* check that PN_SSL_VERIFY_NULL is an integer */
  return n;
}

static int _cffi_const_PN_SSL_VERIFY_PEER(unsigned long long *o)
{
  int n = (PN_SSL_VERIFY_PEER) <= 0;
  *o = (unsigned long long)((PN_SSL_VERIFY_PEER) | 0);  /* check that PN_SSL_VERIFY_PEER is an integer */
  return n;
}

static int _cffi_const_PN_SSL_ANONYMOUS_PEER(unsigned long long *o)
{
  int n = (PN_SSL_ANONYMOUS_PEER) <= 0;
  *o = (unsigned long long)((PN_SSL_ANONYMOUS_PEER) | 0);  /* check that PN_SSL_ANONYMOUS_PEER is an integer */
  return n;
}

static int _cffi_const_PN_SSL_VERIFY_PEER_NAME(unsigned long long *o)
{
  int n = (PN_SSL_VERIFY_PEER_NAME) <= 0;
  *o = (unsigned long long)((PN_SSL_VERIFY_PEER_NAME) | 0);  /* check that PN_SSL_VERIFY_PEER_NAME is an integer */
  return n;
}

static int _cffi_const_PN_UNSPECIFIED(unsigned long long *o)
{
  int n = (PN_UNSPECIFIED) <= 0;
  *o = (unsigned long long)((PN_UNSPECIFIED) | 0);  /* check that PN_UNSPECIFIED is an integer */
  return n;
}

static int _cffi_const_PN_SOURCE(unsigned long long *o)
{
  int n = (PN_SOURCE) <= 0;
  *o = (unsigned long long)((PN_SOURCE) | 0);  /* check that PN_SOURCE is an integer */
  return n;
}

static int _cffi_const_PN_TARGET(unsigned long long *o)
{
  int n = (PN_TARGET) <= 0;
  *o = (unsigned long long)((PN_TARGET) | 0);  /* check that PN_TARGET is an integer */
  return n;
}

static int _cffi_const_PN_COORDINATOR(unsigned long long *o)
{
  int n = (PN_COORDINATOR) <= 0;
  *o = (unsigned long long)((PN_COORDINATOR) | 0);  /* check that PN_COORDINATOR is an integer */
  return n;
}

static int _cffi_const_PN_NULL(unsigned long long *o)
{
  int n = (PN_NULL) <= 0;
  *o = (unsigned long long)((PN_NULL) | 0);  /* check that PN_NULL is an integer */
  return n;
}

static int _cffi_const_PN_BOOL(unsigned long long *o)
{
  int n = (PN_BOOL) <= 0;
  *o = (unsigned long long)((PN_BOOL) | 0);  /* check that PN_BOOL is an integer */
  return n;
}

static int _cffi_const_PN_UBYTE(unsigned long long *o)
{
  int n = (PN_UBYTE) <= 0;
  *o = (unsigned long long)((PN_UBYTE) | 0);  /* check that PN_UBYTE is an integer */
  return n;
}

static int _cffi_const_PN_BYTE(unsigned long long *o)
{
  int n = (PN_BYTE) <= 0;
  *o = (unsigned long long)((PN_BYTE) | 0);  /* check that PN_BYTE is an integer */
  return n;
}

static int _cffi_const_PN_USHORT(unsigned long long *o)
{
  int n = (PN_USHORT) <= 0;
  *o = (unsigned long long)((PN_USHORT) | 0);  /* check that PN_USHORT is an integer */
  return n;
}

static int _cffi_const_PN_SHORT(unsigned long long *o)
{
  int n = (PN_SHORT) <= 0;
  *o = (unsigned long long)((PN_SHORT) | 0);  /* check that PN_SHORT is an integer */
  return n;
}

static int _cffi_const_PN_UINT(unsigned long long *o)
{
  int n = (PN_UINT) <= 0;
  *o = (unsigned long long)((PN_UINT) | 0);  /* check that PN_UINT is an integer */
  return n;
}

static int _cffi_const_PN_INT(unsigned long long *o)
{
  int n = (PN_INT) <= 0;
  *o = (unsigned long long)((PN_INT) | 0);  /* check that PN_INT is an integer */
  return n;
}

static int _cffi_const_PN_CHAR(unsigned long long *o)
{
  int n = (PN_CHAR) <= 0;
  *o = (unsigned long long)((PN_CHAR) | 0);  /* check that PN_CHAR is an integer */
  return n;
}

static int _cffi_const_PN_ULONG(unsigned long long *o)
{
  int n = (PN_ULONG) <= 0;
  *o = (unsigned long long)((PN_ULONG) | 0);  /* check that PN_ULONG is an integer */
  return n;
}

static int _cffi_const_PN_LONG(unsigned long long *o)
{
  int n = (PN_LONG) <= 0;
  *o = (unsigned long long)((PN_LONG) | 0);  /* check that PN_LONG is an integer */
  return n;
}

static int _cffi_const_PN_TIMESTAMP(unsigned long long *o)
{
  int n = (PN_TIMESTAMP) <= 0;
  *o = (unsigned long long)((PN_TIMESTAMP) | 0);  /* check that PN_TIMESTAMP is an integer */
  return n;
}

static int _cffi_const_PN_FLOAT(unsigned long long *o)
{
  int n = (PN_FLOAT) <= 0;
  *o = (unsigned long long)((PN_FLOAT) | 0);  /* check that PN_FLOAT is an integer */
  return n;
}

static int _cffi_const_PN_DOUBLE(unsigned long long *o)
{
  int n = (PN_DOUBLE) <= 0;
  *o = (unsigned long long)((PN_DOUBLE) | 0);  /* check that PN_DOUBLE is an integer */
  return n;
}

static int _cffi_const_PN_DECIMAL32(unsigned long long *o)
{
  int n = (PN_DECIMAL32) <= 0;
  *o = (unsigned long long)((PN_DECIMAL32) | 0);  /* check that PN_DECIMAL32 is an integer */
  return n;
}

static int _cffi_const_PN_DECIMAL64(unsigned long long *o)
{
  int n = (PN_DECIMAL64) <= 0;
  *o = (unsigned long long)((PN_DECIMAL64) | 0);  /* check that PN_DECIMAL64 is an integer */
  return n;
}

static int _cffi_const_PN_DECIMAL128(unsigned long long *o)
{
  int n = (PN_DECIMAL128) <= 0;
  *o = (unsigned long long)((PN_DECIMAL128) | 0);  /* check that PN_DECIMAL128 is an integer */
  return n;
}

static int _cffi_const_PN_UUID(unsigned long long *o)
{
  int n = (PN_UUID) <= 0;
  *o = (unsigned long long)((PN_UUID) | 0);  /* check that PN_UUID is an integer */
  return n;
}

static int _cffi_const_PN_BINARY(unsigned long long *o)
{
  int n = (PN_BINARY) <= 0;
  *o = (unsigned long long)((PN_BINARY) | 0);  /* check that PN_BINARY is an integer */
  return n;
}

static int _cffi_const_PN_STRING(unsigned long long *o)
{
  int n = (PN_STRING) <= 0;
  *o = (unsigned long long)((PN_STRING) | 0);  /* check that PN_STRING is an integer */
  return n;
}

static int _cffi_const_PN_SYMBOL(unsigned long long *o)
{
  int n = (PN_SYMBOL) <= 0;
  *o = (unsigned long long)((PN_SYMBOL) | 0);  /* check that PN_SYMBOL is an integer */
  return n;
}

static int _cffi_const_PN_DESCRIBED(unsigned long long *o)
{
  int n = (PN_DESCRIBED) <= 0;
  *o = (unsigned long long)((PN_DESCRIBED) | 0);  /* check that PN_DESCRIBED is an integer */
  return n;
}

static int _cffi_const_PN_ARRAY(unsigned long long *o)
{
  int n = (PN_ARRAY) <= 0;
  *o = (unsigned long long)((PN_ARRAY) | 0);  /* check that PN_ARRAY is an integer */
  return n;
}

static int _cffi_const_PN_LIST(unsigned long long *o)
{
  int n = (PN_LIST) <= 0;
  *o = (unsigned long long)((PN_LIST) | 0);  /* check that PN_LIST is an integer */
  return n;
}

static int _cffi_const_PN_MAP(unsigned long long *o)
{
  int n = (PN_MAP) <= 0;
  *o = (unsigned long long)((PN_MAP) | 0);  /* check that PN_MAP is an integer */
  return n;
}

static int _cffi_const_PN_INVALID(unsigned long long *o)
{
  int n = (PN_INVALID) <= 0;
  *o = (unsigned long long)((PN_INVALID) | 0);  /* check that PN_INVALID is an integer */
  return n;
}

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_pn_uuid_t(pn_uuid_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char(*tmp)[16] = &p->bytes; (void)tmp; }
}
struct _cffi_align_typedef_pn_uuid_t { char x; pn_uuid_t y; };

static struct _cffi_externpy_s _cffi_externpy__pn_pyref_decref =
  { "cproton_ffi.pn_pyref_decref", 0, 0, 0 };

static void pn_pyref_decref(void * a0)
{
  char a[8];
  char *p = a;
  *(void * *)(p + 0) = a0;
  _cffi_call_python(&_cffi_externpy__pn_pyref_decref, p);
}

static struct _cffi_externpy_s _cffi_externpy__pn_pyref_incref =
  { "cproton_ffi.pn_pyref_incref", 0, 0, 0 };

static void pn_pyref_incref(void * a0)
{
  char a[8];
  char *p = a;
  *(void * *)(p + 0) = a0;
  _cffi_call_python(&_cffi_externpy__pn_pyref_incref, p);
}

static struct _cffi_externpy_s _cffi_externpy__pn_pytracer =
  { "cproton_ffi.pn_pytracer", 0, 0, 0 };

static void pn_pytracer(pn_transport_t * a0, char const * a1)
{
  char a[16];
  char *p = a;
  *(pn_transport_t * *)(p + 0) = a0;
  *(char const * *)(p + 8) = a1;
  _cffi_call_python(&_cffi_externpy__pn_pytracer, p);
}

static void _cffi_d_free(void * x0)
{
  free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_free(PyObject *self, PyObject *arg0)
{
  void * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(42), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(42), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_free _cffi_d_free
#endif

static void _cffi_d_init(void)
{
  init();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_init(PyObject *self, PyObject *noarg)
{

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { init(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_init _cffi_d_init
#endif

static pn_connection_t * _cffi_d_pn_cast_pn_connection(void * x0)
{
  return pn_cast_pn_connection(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_cast_pn_connection(PyObject *self, PyObject *arg0)
{
  void * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_connection_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(42), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(42), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_cast_pn_connection(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(48));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_cast_pn_connection _cffi_d_pn_cast_pn_connection
#endif

static pn_delivery_t * _cffi_d_pn_cast_pn_delivery(void * x0)
{
  return pn_cast_pn_delivery(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_cast_pn_delivery(PyObject *self, PyObject *arg0)
{
  void * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_delivery_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(42), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(42), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_cast_pn_delivery(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(14));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_cast_pn_delivery _cffi_d_pn_cast_pn_delivery
#endif

static pn_link_t * _cffi_d_pn_cast_pn_link(void * x0)
{
  return pn_cast_pn_link(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_cast_pn_link(PyObject *self, PyObject *arg0)
{
  void * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_link_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(42), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(42), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_cast_pn_link(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(20));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_cast_pn_link _cffi_d_pn_cast_pn_link
#endif

static pn_session_t * _cffi_d_pn_cast_pn_session(void * x0)
{
  return pn_cast_pn_session(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_cast_pn_session(PyObject *self, PyObject *arg0)
{
  void * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_session_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(42), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(42), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_cast_pn_session(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(202));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_cast_pn_session _cffi_d_pn_cast_pn_session
#endif

static pn_transport_t * _cffi_d_pn_cast_pn_transport(void * x0)
{
  return pn_cast_pn_transport(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_cast_pn_transport(PyObject *self, PyObject *arg0)
{
  void * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_transport_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(42), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(42), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_cast_pn_transport(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(37));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_cast_pn_transport _cffi_d_pn_cast_pn_transport
#endif

static pn_collector_t * _cffi_d_pn_collector(void)
{
  return pn_collector();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_collector(PyObject *self, PyObject *noarg)
{
  pn_collector_t * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_collector(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(1));
  return pyresult;
}
#else
#  define _cffi_f_pn_collector _cffi_d_pn_collector
#endif

static void _cffi_d_pn_collector_free(pn_collector_t * x0)
{
  pn_collector_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_collector_free(PyObject *self, PyObject *arg0)
{
  pn_collector_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_collector_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_collector_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_collector_free _cffi_d_pn_collector_free
#endif

static _Bool _cffi_d_pn_collector_more(pn_collector_t * x0)
{
  return pn_collector_more(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_collector_more(PyObject *self, PyObject *arg0)
{
  pn_collector_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_collector_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_collector_more(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_collector_more _cffi_d_pn_collector_more
#endif

static pn_event_t * _cffi_d_pn_collector_peek(pn_collector_t * x0)
{
  return pn_collector_peek(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_collector_peek(PyObject *self, PyObject *arg0)
{
  pn_collector_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_event_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_collector_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_collector_peek(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(54));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_collector_peek _cffi_d_pn_collector_peek
#endif

static _Bool _cffi_d_pn_collector_pop(pn_collector_t * x0)
{
  return pn_collector_pop(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_collector_pop(PyObject *self, PyObject *arg0)
{
  pn_collector_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_collector_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_collector_pop(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_collector_pop _cffi_d_pn_collector_pop
#endif

static pn_event_t * _cffi_d_pn_collector_put_py(pn_collector_t * x0, void * x1, pn_event_type_t x2)
{
  return pn_collector_put_py(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_collector_put_py(PyObject *self, PyObject *args)
{
  pn_collector_t * x0;
  void * x1;
  pn_event_type_t x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_event_t * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "pn_collector_put_py", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_collector_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(42), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(42), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x2, _cffi_type(57), arg2) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_collector_put_py(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(54));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_collector_put_py _cffi_d_pn_collector_put_py
#endif

static void _cffi_d_pn_collector_release(pn_collector_t * x0)
{
  pn_collector_release(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_collector_release(PyObject *self, PyObject *arg0)
{
  pn_collector_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_collector_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_collector_release(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_collector_release _cffi_d_pn_collector_release
#endif

static void _cffi_d_pn_condition_clear(pn_condition_t * x0)
{
  pn_condition_clear(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_condition_clear(PyObject *self, PyObject *arg0)
{
  pn_condition_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_condition_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(4), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_condition_clear(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_condition_clear _cffi_d_pn_condition_clear
#endif

static char const * _cffi_d_pn_condition_get_description(pn_condition_t * x0)
{
  return pn_condition_get_description(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_condition_get_description(PyObject *self, PyObject *arg0)
{
  pn_condition_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_condition_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(4), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_condition_get_description(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_condition_get_description _cffi_d_pn_condition_get_description
#endif

static char const * _cffi_d_pn_condition_get_name(pn_condition_t * x0)
{
  return pn_condition_get_name(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_condition_get_name(PyObject *self, PyObject *arg0)
{
  pn_condition_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_condition_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(4), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_condition_get_name(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_condition_get_name _cffi_d_pn_condition_get_name
#endif

static pn_data_t * _cffi_d_pn_condition_info(pn_condition_t * x0)
{
  return pn_condition_info(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_condition_info(PyObject *self, PyObject *arg0)
{
  pn_condition_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_data_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_condition_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(4), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_condition_info(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(7));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_condition_info _cffi_d_pn_condition_info
#endif

static _Bool _cffi_d_pn_condition_is_set(pn_condition_t * x0)
{
  return pn_condition_is_set(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_condition_is_set(PyObject *self, PyObject *arg0)
{
  pn_condition_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_condition_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(4), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_condition_is_set(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_condition_is_set _cffi_d_pn_condition_is_set
#endif

static int _cffi_d_pn_condition_set_description(pn_condition_t * x0, char const * x1)
{
  return pn_condition_set_description(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_condition_set_description(PyObject *self, PyObject *args)
{
  pn_condition_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_condition_set_description", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_condition_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(4), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_condition_set_description(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_condition_set_description _cffi_d_pn_condition_set_description
#endif

static int _cffi_d_pn_condition_set_name(pn_condition_t * x0, char const * x1)
{
  return pn_condition_set_name(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_condition_set_name(PyObject *self, PyObject *args)
{
  pn_condition_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_condition_set_name", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_condition_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(4), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_condition_set_name(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_condition_set_name _cffi_d_pn_condition_set_name
#endif

static pn_connection_t * _cffi_d_pn_connection(void)
{
  return pn_connection();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_connection(PyObject *self, PyObject *noarg)
{
  pn_connection_t * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_connection(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(48));
  return pyresult;
}
#else
#  define _cffi_f_pn_connection _cffi_d_pn_connection
#endif

static pn_record_t * _cffi_d_pn_connection_attachments(pn_connection_t * x0)
{
  return pn_connection_attachments(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_connection_attachments(PyObject *self, PyObject *arg0)
{
  pn_connection_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_record_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_connection_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_connection_attachments(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(623));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_connection_attachments _cffi_d_pn_connection_attachments
#endif

static void _cffi_d_pn_connection_close(pn_connection_t * x0)
{
  pn_connection_close(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_connection_close(PyObject *self, PyObject *arg0)
{
  pn_connection_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_connection_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_connection_close(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_connection_close _cffi_d_pn_connection_close
#endif

static void _cffi_d_pn_connection_collect(pn_connection_t * x0, pn_collector_t * x1)
{
  pn_connection_collect(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_connection_collect(PyObject *self, PyObject *args)
{
  pn_connection_t * x0;
  pn_collector_t * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_connection_collect", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_connection_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (pn_collector_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_connection_collect(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_connection_collect _cffi_d_pn_connection_collect
#endif

static pn_condition_t * _cffi_d_pn_connection_condition(pn_connection_t * x0)
{
  return pn_connection_condition(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_connection_condition(PyObject *self, PyObject *arg0)
{
  pn_connection_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_condition_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_connection_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_connection_condition(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(4));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_connection_condition _cffi_d_pn_connection_condition
#endif

static pn_data_t * _cffi_d_pn_connection_desired_capabilities(pn_connection_t * x0)
{
  return pn_connection_desired_capabilities(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_connection_desired_capabilities(PyObject *self, PyObject *arg0)
{
  pn_connection_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_data_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_connection_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_connection_desired_capabilities(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(7));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_connection_desired_capabilities _cffi_d_pn_connection_desired_capabilities
#endif

static pn_error_t * _cffi_d_pn_connection_error(pn_connection_t * x0)
{
  return pn_connection_error(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_connection_error(PyObject *self, PyObject *arg0)
{
  pn_connection_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_error_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_connection_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_connection_error(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(51));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_connection_error _cffi_d_pn_connection_error
#endif

static char const * _cffi_d_pn_connection_get_authorization(pn_connection_t * x0)
{
  return pn_connection_get_authorization(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_connection_get_authorization(PyObject *self, PyObject *arg0)
{
  pn_connection_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_connection_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_connection_get_authorization(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_connection_get_authorization _cffi_d_pn_connection_get_authorization
#endif

static char const * _cffi_d_pn_connection_get_container(pn_connection_t * x0)
{
  return pn_connection_get_container(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_connection_get_container(PyObject *self, PyObject *arg0)
{
  pn_connection_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_connection_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_connection_get_container(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_connection_get_container _cffi_d_pn_connection_get_container
#endif

static char const * _cffi_d_pn_connection_get_hostname(pn_connection_t * x0)
{
  return pn_connection_get_hostname(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_connection_get_hostname(PyObject *self, PyObject *arg0)
{
  pn_connection_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_connection_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_connection_get_hostname(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_connection_get_hostname _cffi_d_pn_connection_get_hostname
#endif

static char const * _cffi_d_pn_connection_get_user(pn_connection_t * x0)
{
  return pn_connection_get_user(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_connection_get_user(PyObject *self, PyObject *arg0)
{
  pn_connection_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_connection_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_connection_get_user(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_connection_get_user _cffi_d_pn_connection_get_user
#endif

static pn_data_t * _cffi_d_pn_connection_offered_capabilities(pn_connection_t * x0)
{
  return pn_connection_offered_capabilities(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_connection_offered_capabilities(PyObject *self, PyObject *arg0)
{
  pn_connection_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_data_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_connection_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_connection_offered_capabilities(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(7));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_connection_offered_capabilities _cffi_d_pn_connection_offered_capabilities
#endif

static void _cffi_d_pn_connection_open(pn_connection_t * x0)
{
  pn_connection_open(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_connection_open(PyObject *self, PyObject *arg0)
{
  pn_connection_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_connection_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_connection_open(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_connection_open _cffi_d_pn_connection_open
#endif

static pn_data_t * _cffi_d_pn_connection_properties(pn_connection_t * x0)
{
  return pn_connection_properties(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_connection_properties(PyObject *self, PyObject *arg0)
{
  pn_connection_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_data_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_connection_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_connection_properties(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(7));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_connection_properties _cffi_d_pn_connection_properties
#endif

static void _cffi_d_pn_connection_release(pn_connection_t * x0)
{
  pn_connection_release(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_connection_release(PyObject *self, PyObject *arg0)
{
  pn_connection_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_connection_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_connection_release(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_connection_release _cffi_d_pn_connection_release
#endif

static pn_condition_t * _cffi_d_pn_connection_remote_condition(pn_connection_t * x0)
{
  return pn_connection_remote_condition(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_connection_remote_condition(PyObject *self, PyObject *arg0)
{
  pn_connection_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_condition_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_connection_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_connection_remote_condition(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(4));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_connection_remote_condition _cffi_d_pn_connection_remote_condition
#endif

static char const * _cffi_d_pn_connection_remote_container(pn_connection_t * x0)
{
  return pn_connection_remote_container(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_connection_remote_container(PyObject *self, PyObject *arg0)
{
  pn_connection_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_connection_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_connection_remote_container(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_connection_remote_container _cffi_d_pn_connection_remote_container
#endif

static pn_data_t * _cffi_d_pn_connection_remote_desired_capabilities(pn_connection_t * x0)
{
  return pn_connection_remote_desired_capabilities(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_connection_remote_desired_capabilities(PyObject *self, PyObject *arg0)
{
  pn_connection_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_data_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_connection_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_connection_remote_desired_capabilities(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(7));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_connection_remote_desired_capabilities _cffi_d_pn_connection_remote_desired_capabilities
#endif

static char const * _cffi_d_pn_connection_remote_hostname(pn_connection_t * x0)
{
  return pn_connection_remote_hostname(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_connection_remote_hostname(PyObject *self, PyObject *arg0)
{
  pn_connection_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_connection_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_connection_remote_hostname(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_connection_remote_hostname _cffi_d_pn_connection_remote_hostname
#endif

static pn_data_t * _cffi_d_pn_connection_remote_offered_capabilities(pn_connection_t * x0)
{
  return pn_connection_remote_offered_capabilities(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_connection_remote_offered_capabilities(PyObject *self, PyObject *arg0)
{
  pn_connection_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_data_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_connection_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_connection_remote_offered_capabilities(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(7));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_connection_remote_offered_capabilities _cffi_d_pn_connection_remote_offered_capabilities
#endif

static pn_data_t * _cffi_d_pn_connection_remote_properties(pn_connection_t * x0)
{
  return pn_connection_remote_properties(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_connection_remote_properties(PyObject *self, PyObject *arg0)
{
  pn_connection_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_data_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_connection_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_connection_remote_properties(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(7));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_connection_remote_properties _cffi_d_pn_connection_remote_properties
#endif

static void _cffi_d_pn_connection_set_authorization(pn_connection_t * x0, char const * x1)
{
  pn_connection_set_authorization(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_connection_set_authorization(PyObject *self, PyObject *args)
{
  pn_connection_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_connection_set_authorization", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_connection_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_connection_set_authorization(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_connection_set_authorization _cffi_d_pn_connection_set_authorization
#endif

static void _cffi_d_pn_connection_set_container(pn_connection_t * x0, char const * x1)
{
  pn_connection_set_container(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_connection_set_container(PyObject *self, PyObject *args)
{
  pn_connection_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_connection_set_container", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_connection_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_connection_set_container(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_connection_set_container _cffi_d_pn_connection_set_container
#endif

static void _cffi_d_pn_connection_set_hostname(pn_connection_t * x0, char const * x1)
{
  pn_connection_set_hostname(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_connection_set_hostname(PyObject *self, PyObject *args)
{
  pn_connection_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_connection_set_hostname", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_connection_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_connection_set_hostname(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_connection_set_hostname _cffi_d_pn_connection_set_hostname
#endif

static void _cffi_d_pn_connection_set_password(pn_connection_t * x0, char const * x1)
{
  pn_connection_set_password(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_connection_set_password(PyObject *self, PyObject *args)
{
  pn_connection_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_connection_set_password", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_connection_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_connection_set_password(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_connection_set_password _cffi_d_pn_connection_set_password
#endif

static void _cffi_d_pn_connection_set_user(pn_connection_t * x0, char const * x1)
{
  pn_connection_set_user(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_connection_set_user(PyObject *self, PyObject *args)
{
  pn_connection_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_connection_set_user", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_connection_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_connection_set_user(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_connection_set_user _cffi_d_pn_connection_set_user
#endif

static int _cffi_d_pn_connection_state(pn_connection_t * x0)
{
  return pn_connection_state(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_connection_state(PyObject *self, PyObject *arg0)
{
  pn_connection_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_connection_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_connection_state(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_connection_state _cffi_d_pn_connection_state
#endif

static pn_transport_t * _cffi_d_pn_connection_transport(pn_connection_t * x0)
{
  return pn_connection_transport(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_connection_transport(PyObject *self, PyObject *arg0)
{
  pn_connection_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_transport_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_connection_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_connection_transport(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(37));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_connection_transport _cffi_d_pn_connection_transport
#endif

static pn_data_t * _cffi_d_pn_data(size_t x0)
{
  return pn_data(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data(PyObject *self, PyObject *arg0)
{
  size_t x0;
  pn_data_t * result;
  PyObject *pyresult;

  x0 = _cffi_to_c_int(arg0, size_t);
  if (x0 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(7));
  return pyresult;
}
#else
#  define _cffi_f_pn_data _cffi_d_pn_data
#endif

static void _cffi_d_pn_data_clear(pn_data_t * x0)
{
  pn_data_clear(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_clear(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_data_clear(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_data_clear _cffi_d_pn_data_clear
#endif

static int _cffi_d_pn_data_copy(pn_data_t * x0, pn_data_t * x1)
{
  return pn_data_copy(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_copy(PyObject *self, PyObject *args)
{
  pn_data_t * x0;
  pn_data_t * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_data_copy", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_copy(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_copy _cffi_d_pn_data_copy
#endif

static ssize_t _cffi_d_pn_data_decode(pn_data_t * x0, char const * x1, size_t x2)
{
  return pn_data_decode(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_decode(PyObject *self, PyObject *args)
{
  pn_data_t * x0;
  char const * x1;
  size_t x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  ssize_t result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "pn_data_decode", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, size_t);
  if (x2 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_decode(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, ssize_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_decode _cffi_d_pn_data_decode
#endif

static void _cffi_d_pn_data_dump(pn_data_t * x0)
{
  pn_data_dump(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_dump(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_data_dump(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_data_dump _cffi_d_pn_data_dump
#endif

static ssize_t _cffi_d_pn_data_encode(pn_data_t * x0, char * x1, size_t x2)
{
  return pn_data_encode(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_encode(PyObject *self, PyObject *args)
{
  pn_data_t * x0;
  char * x1;
  size_t x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  ssize_t result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "pn_data_encode", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(30), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(30), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, size_t);
  if (x2 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_encode(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, ssize_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_encode _cffi_d_pn_data_encode
#endif

static ssize_t _cffi_d_pn_data_encoded_size(pn_data_t * x0)
{
  return pn_data_encoded_size(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_encoded_size(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  ssize_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_encoded_size(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, ssize_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_encoded_size _cffi_d_pn_data_encoded_size
#endif

static _Bool _cffi_d_pn_data_enter(pn_data_t * x0)
{
  return pn_data_enter(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_enter(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_enter(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_enter _cffi_d_pn_data_enter
#endif

static pn_error_t * _cffi_d_pn_data_error(pn_data_t * x0)
{
  return pn_data_error(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_error(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_error_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_error(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(51));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_error _cffi_d_pn_data_error
#endif

static _Bool _cffi_d_pn_data_exit(pn_data_t * x0)
{
  return pn_data_exit(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_exit(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_exit(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_exit _cffi_d_pn_data_exit
#endif

static ssize_t _cffi_d_pn_data_format_py(pn_data_t * x0, char * x1, size_t x2)
{
  return pn_data_format_py(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_format_py(PyObject *self, PyObject *args)
{
  pn_data_t * x0;
  char * x1;
  size_t x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  ssize_t result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "pn_data_format_py", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(30), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(30), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, size_t);
  if (x2 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_format_py(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, ssize_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_format_py _cffi_d_pn_data_format_py
#endif

static void _cffi_d_pn_data_free(pn_data_t * x0)
{
  pn_data_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_free(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_data_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_data_free _cffi_d_pn_data_free
#endif

static size_t _cffi_d_pn_data_get_array(pn_data_t * x0)
{
  return pn_data_get_array(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_get_array(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  size_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_get_array(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, size_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_get_array _cffi_d_pn_data_get_array
#endif

static pn_type_t _cffi_d_pn_data_get_array_type(pn_data_t * x0)
{
  return pn_data_get_array_type(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_get_array_type(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_type_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_get_array_type(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_get_array_type _cffi_d_pn_data_get_array_type
#endif

static pn_bytes_t _cffi_d_pn_data_get_binary(pn_data_t * x0)
{
  return pn_data_get_binary(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_get_binary(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_bytes_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_get_binary(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(132));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_pn_data_get_binary(pn_bytes_t *result, pn_data_t * x0)
{
  { *result = pn_data_get_binary(x0); }
}
#endif

static _Bool _cffi_d_pn_data_get_bool(pn_data_t * x0)
{
  return pn_data_get_bool(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_get_bool(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_get_bool(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_get_bool _cffi_d_pn_data_get_bool
#endif

static int8_t _cffi_d_pn_data_get_byte(pn_data_t * x0)
{
  return pn_data_get_byte(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_get_byte(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int8_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_get_byte(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int8_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_get_byte _cffi_d_pn_data_get_byte
#endif

static uint32_t _cffi_d_pn_data_get_char(pn_data_t * x0)
{
  return pn_data_get_char(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_get_char(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint32_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_get_char(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint32_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_get_char _cffi_d_pn_data_get_char
#endif

static pn_decimal128_t _cffi_d_pn_data_get_decimal128(pn_data_t * x0)
{
  return pn_data_get_decimal128(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_get_decimal128(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_decimal128_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_get_decimal128(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(140));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_pn_data_get_decimal128(pn_decimal128_t *result, pn_data_t * x0)
{
  { *result = pn_data_get_decimal128(x0); }
}
#endif

static uint32_t _cffi_d_pn_data_get_decimal32(pn_data_t * x0)
{
  return pn_data_get_decimal32(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_get_decimal32(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint32_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_get_decimal32(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint32_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_get_decimal32 _cffi_d_pn_data_get_decimal32
#endif

static uint64_t _cffi_d_pn_data_get_decimal64(pn_data_t * x0)
{
  return pn_data_get_decimal64(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_get_decimal64(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint64_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_get_decimal64(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint64_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_get_decimal64 _cffi_d_pn_data_get_decimal64
#endif

static double _cffi_d_pn_data_get_double(pn_data_t * x0)
{
  return pn_data_get_double(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_get_double(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  double result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_get_double(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_double(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_get_double _cffi_d_pn_data_get_double
#endif

static float _cffi_d_pn_data_get_float(pn_data_t * x0)
{
  return pn_data_get_float(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_get_float(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  float result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_get_float(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_float(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_get_float _cffi_d_pn_data_get_float
#endif

static int32_t _cffi_d_pn_data_get_int(pn_data_t * x0)
{
  return pn_data_get_int(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_get_int(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int32_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_get_int(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int32_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_get_int _cffi_d_pn_data_get_int
#endif

static size_t _cffi_d_pn_data_get_list(pn_data_t * x0)
{
  return pn_data_get_list(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_get_list(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  size_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_get_list(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, size_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_get_list _cffi_d_pn_data_get_list
#endif

static int64_t _cffi_d_pn_data_get_long(pn_data_t * x0)
{
  return pn_data_get_long(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_get_long(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int64_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_get_long(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int64_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_get_long _cffi_d_pn_data_get_long
#endif

static size_t _cffi_d_pn_data_get_map(pn_data_t * x0)
{
  return pn_data_get_map(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_get_map(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  size_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_get_map(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, size_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_get_map _cffi_d_pn_data_get_map
#endif

static int16_t _cffi_d_pn_data_get_short(pn_data_t * x0)
{
  return pn_data_get_short(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_get_short(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int16_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_get_short(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int16_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_get_short _cffi_d_pn_data_get_short
#endif

static pn_bytes_t _cffi_d_pn_data_get_string(pn_data_t * x0)
{
  return pn_data_get_string(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_get_string(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_bytes_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_get_string(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(132));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_pn_data_get_string(pn_bytes_t *result, pn_data_t * x0)
{
  { *result = pn_data_get_string(x0); }
}
#endif

static pn_bytes_t _cffi_d_pn_data_get_symbol(pn_data_t * x0)
{
  return pn_data_get_symbol(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_get_symbol(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_bytes_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_get_symbol(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(132));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_pn_data_get_symbol(pn_bytes_t *result, pn_data_t * x0)
{
  { *result = pn_data_get_symbol(x0); }
}
#endif

static int64_t _cffi_d_pn_data_get_timestamp(pn_data_t * x0)
{
  return pn_data_get_timestamp(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_get_timestamp(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int64_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_get_timestamp(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int64_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_get_timestamp _cffi_d_pn_data_get_timestamp
#endif

static uint8_t _cffi_d_pn_data_get_ubyte(pn_data_t * x0)
{
  return pn_data_get_ubyte(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_get_ubyte(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint8_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_get_ubyte(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint8_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_get_ubyte _cffi_d_pn_data_get_ubyte
#endif

static uint32_t _cffi_d_pn_data_get_uint(pn_data_t * x0)
{
  return pn_data_get_uint(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_get_uint(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint32_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_get_uint(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint32_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_get_uint _cffi_d_pn_data_get_uint
#endif

static uint64_t _cffi_d_pn_data_get_ulong(pn_data_t * x0)
{
  return pn_data_get_ulong(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_get_ulong(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint64_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_get_ulong(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint64_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_get_ulong _cffi_d_pn_data_get_ulong
#endif

static uint16_t _cffi_d_pn_data_get_ushort(pn_data_t * x0)
{
  return pn_data_get_ushort(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_get_ushort(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint16_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_get_ushort(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint16_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_get_ushort _cffi_d_pn_data_get_ushort
#endif

static pn_uuid_t _cffi_d_pn_data_get_uuid(pn_data_t * x0)
{
  return pn_data_get_uuid(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_get_uuid(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_uuid_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_get_uuid(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(144));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_pn_data_get_uuid(pn_uuid_t *result, pn_data_t * x0)
{
  { *result = pn_data_get_uuid(x0); }
}
#endif

static _Bool _cffi_d_pn_data_is_array_described(pn_data_t * x0)
{
  return pn_data_is_array_described(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_is_array_described(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_is_array_described(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_is_array_described _cffi_d_pn_data_is_array_described
#endif

static _Bool _cffi_d_pn_data_is_described(pn_data_t * x0)
{
  return pn_data_is_described(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_is_described(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_is_described(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_is_described _cffi_d_pn_data_is_described
#endif

static _Bool _cffi_d_pn_data_is_null(pn_data_t * x0)
{
  return pn_data_is_null(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_is_null(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_is_null(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_is_null _cffi_d_pn_data_is_null
#endif

static _Bool _cffi_d_pn_data_lookup(pn_data_t * x0, char const * x1)
{
  return pn_data_lookup(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_lookup(PyObject *self, PyObject *args)
{
  pn_data_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_data_lookup", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_lookup(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_lookup _cffi_d_pn_data_lookup
#endif

static void _cffi_d_pn_data_narrow(pn_data_t * x0)
{
  pn_data_narrow(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_narrow(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_data_narrow(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_data_narrow _cffi_d_pn_data_narrow
#endif

static _Bool _cffi_d_pn_data_next(pn_data_t * x0)
{
  return pn_data_next(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_next(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_next(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_next _cffi_d_pn_data_next
#endif

static _Bool _cffi_d_pn_data_prev(pn_data_t * x0)
{
  return pn_data_prev(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_prev(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_prev(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_prev _cffi_d_pn_data_prev
#endif

static int _cffi_d_pn_data_put_array(pn_data_t * x0, _Bool x1, pn_type_t x2)
{
  return pn_data_put_array(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_put_array(PyObject *self, PyObject *args)
{
  pn_data_t * x0;
  _Bool x1;
  pn_type_t x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "pn_data_put_array", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (_Bool)_cffi_to_c__Bool(arg1);
  if (x1 == (_Bool)-1 && PyErr_Occurred())
    return NULL;

  if (_cffi_to_c((char *)&x2, _cffi_type(104), arg2) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_put_array(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_put_array _cffi_d_pn_data_put_array
#endif

static int _cffi_d_pn_data_put_binary(pn_data_t * x0, pn_bytes_t x1)
{
  return pn_data_put_binary(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_put_binary(PyObject *self, PyObject *args)
{
  pn_data_t * x0;
  pn_bytes_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_data_put_binary", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(132), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_put_binary(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static int _cffi_f_pn_data_put_binary(pn_data_t * x0, pn_bytes_t *x1)
{
  int result;
  { result = pn_data_put_binary(x0, *x1); }
  return result;
}
#endif

static int _cffi_d_pn_data_put_bool(pn_data_t * x0, _Bool x1)
{
  return pn_data_put_bool(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_put_bool(PyObject *self, PyObject *args)
{
  pn_data_t * x0;
  _Bool x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_data_put_bool", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (_Bool)_cffi_to_c__Bool(arg1);
  if (x1 == (_Bool)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_put_bool(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_put_bool _cffi_d_pn_data_put_bool
#endif

static int _cffi_d_pn_data_put_byte(pn_data_t * x0, int8_t x1)
{
  return pn_data_put_byte(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_put_byte(PyObject *self, PyObject *args)
{
  pn_data_t * x0;
  int8_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_data_put_byte", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int8_t);
  if (x1 == (int8_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_put_byte(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_put_byte _cffi_d_pn_data_put_byte
#endif

static int _cffi_d_pn_data_put_char(pn_data_t * x0, uint32_t x1)
{
  return pn_data_put_char(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_put_char(PyObject *self, PyObject *args)
{
  pn_data_t * x0;
  uint32_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_data_put_char", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint32_t);
  if (x1 == (uint32_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_put_char(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_put_char _cffi_d_pn_data_put_char
#endif

static int _cffi_d_pn_data_put_decimal128(pn_data_t * x0, pn_decimal128_t x1)
{
  return pn_data_put_decimal128(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_put_decimal128(PyObject *self, PyObject *args)
{
  pn_data_t * x0;
  pn_decimal128_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_data_put_decimal128", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(140), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_put_decimal128(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static int _cffi_f_pn_data_put_decimal128(pn_data_t * x0, pn_decimal128_t *x1)
{
  int result;
  { result = pn_data_put_decimal128(x0, *x1); }
  return result;
}
#endif

static int _cffi_d_pn_data_put_decimal32(pn_data_t * x0, uint32_t x1)
{
  return pn_data_put_decimal32(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_put_decimal32(PyObject *self, PyObject *args)
{
  pn_data_t * x0;
  uint32_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_data_put_decimal32", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint32_t);
  if (x1 == (uint32_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_put_decimal32(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_put_decimal32 _cffi_d_pn_data_put_decimal32
#endif

static int _cffi_d_pn_data_put_decimal64(pn_data_t * x0, uint64_t x1)
{
  return pn_data_put_decimal64(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_put_decimal64(PyObject *self, PyObject *args)
{
  pn_data_t * x0;
  uint64_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_data_put_decimal64", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint64_t);
  if (x1 == (uint64_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_put_decimal64(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_put_decimal64 _cffi_d_pn_data_put_decimal64
#endif

static int _cffi_d_pn_data_put_described(pn_data_t * x0)
{
  return pn_data_put_described(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_put_described(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_put_described(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_put_described _cffi_d_pn_data_put_described
#endif

static int _cffi_d_pn_data_put_double(pn_data_t * x0, double x1)
{
  return pn_data_put_double(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_put_double(PyObject *self, PyObject *args)
{
  pn_data_t * x0;
  double x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_data_put_double", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (double)_cffi_to_c_double(arg1);
  if (x1 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_put_double(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_put_double _cffi_d_pn_data_put_double
#endif

static int _cffi_d_pn_data_put_float(pn_data_t * x0, float x1)
{
  return pn_data_put_float(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_put_float(PyObject *self, PyObject *args)
{
  pn_data_t * x0;
  float x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_data_put_float", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (float)_cffi_to_c_float(arg1);
  if (x1 == (float)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_put_float(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_put_float _cffi_d_pn_data_put_float
#endif

static int _cffi_d_pn_data_put_int(pn_data_t * x0, int32_t x1)
{
  return pn_data_put_int(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_put_int(PyObject *self, PyObject *args)
{
  pn_data_t * x0;
  int32_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_data_put_int", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int32_t);
  if (x1 == (int32_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_put_int(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_put_int _cffi_d_pn_data_put_int
#endif

static int _cffi_d_pn_data_put_list(pn_data_t * x0)
{
  return pn_data_put_list(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_put_list(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_put_list(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_put_list _cffi_d_pn_data_put_list
#endif

static int _cffi_d_pn_data_put_long(pn_data_t * x0, int64_t x1)
{
  return pn_data_put_long(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_put_long(PyObject *self, PyObject *args)
{
  pn_data_t * x0;
  int64_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_data_put_long", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int64_t);
  if (x1 == (int64_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_put_long(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_put_long _cffi_d_pn_data_put_long
#endif

static int _cffi_d_pn_data_put_map(pn_data_t * x0)
{
  return pn_data_put_map(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_put_map(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_put_map(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_put_map _cffi_d_pn_data_put_map
#endif

static int _cffi_d_pn_data_put_null(pn_data_t * x0)
{
  return pn_data_put_null(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_put_null(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_put_null(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_put_null _cffi_d_pn_data_put_null
#endif

static int _cffi_d_pn_data_put_short(pn_data_t * x0, int16_t x1)
{
  return pn_data_put_short(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_put_short(PyObject *self, PyObject *args)
{
  pn_data_t * x0;
  int16_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_data_put_short", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int16_t);
  if (x1 == (int16_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_put_short(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_put_short _cffi_d_pn_data_put_short
#endif

static int _cffi_d_pn_data_put_string(pn_data_t * x0, pn_bytes_t x1)
{
  return pn_data_put_string(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_put_string(PyObject *self, PyObject *args)
{
  pn_data_t * x0;
  pn_bytes_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_data_put_string", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(132), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_put_string(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static int _cffi_f_pn_data_put_string(pn_data_t * x0, pn_bytes_t *x1)
{
  int result;
  { result = pn_data_put_string(x0, *x1); }
  return result;
}
#endif

static int _cffi_d_pn_data_put_symbol(pn_data_t * x0, pn_bytes_t x1)
{
  return pn_data_put_symbol(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_put_symbol(PyObject *self, PyObject *args)
{
  pn_data_t * x0;
  pn_bytes_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_data_put_symbol", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(132), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_put_symbol(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static int _cffi_f_pn_data_put_symbol(pn_data_t * x0, pn_bytes_t *x1)
{
  int result;
  { result = pn_data_put_symbol(x0, *x1); }
  return result;
}
#endif

static int _cffi_d_pn_data_put_timestamp(pn_data_t * x0, int64_t x1)
{
  return pn_data_put_timestamp(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_put_timestamp(PyObject *self, PyObject *args)
{
  pn_data_t * x0;
  int64_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_data_put_timestamp", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int64_t);
  if (x1 == (int64_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_put_timestamp(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_put_timestamp _cffi_d_pn_data_put_timestamp
#endif

static int _cffi_d_pn_data_put_ubyte(pn_data_t * x0, uint8_t x1)
{
  return pn_data_put_ubyte(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_put_ubyte(PyObject *self, PyObject *args)
{
  pn_data_t * x0;
  uint8_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_data_put_ubyte", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint8_t);
  if (x1 == (uint8_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_put_ubyte(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_put_ubyte _cffi_d_pn_data_put_ubyte
#endif

static int _cffi_d_pn_data_put_uint(pn_data_t * x0, uint32_t x1)
{
  return pn_data_put_uint(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_put_uint(PyObject *self, PyObject *args)
{
  pn_data_t * x0;
  uint32_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_data_put_uint", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint32_t);
  if (x1 == (uint32_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_put_uint(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_put_uint _cffi_d_pn_data_put_uint
#endif

static int _cffi_d_pn_data_put_ulong(pn_data_t * x0, uint64_t x1)
{
  return pn_data_put_ulong(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_put_ulong(PyObject *self, PyObject *args)
{
  pn_data_t * x0;
  uint64_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_data_put_ulong", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint64_t);
  if (x1 == (uint64_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_put_ulong(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_put_ulong _cffi_d_pn_data_put_ulong
#endif

static int _cffi_d_pn_data_put_ushort(pn_data_t * x0, uint16_t x1)
{
  return pn_data_put_ushort(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_put_ushort(PyObject *self, PyObject *args)
{
  pn_data_t * x0;
  uint16_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_data_put_ushort", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint16_t);
  if (x1 == (uint16_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_put_ushort(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_put_ushort _cffi_d_pn_data_put_ushort
#endif

static int _cffi_d_pn_data_put_uuid(pn_data_t * x0, pn_uuid_t x1)
{
  return pn_data_put_uuid(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_put_uuid(PyObject *self, PyObject *args)
{
  pn_data_t * x0;
  pn_uuid_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_data_put_uuid", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(144), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_put_uuid(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static int _cffi_f_pn_data_put_uuid(pn_data_t * x0, pn_uuid_t *x1)
{
  int result;
  { result = pn_data_put_uuid(x0, *x1); }
  return result;
}
#endif

static void _cffi_d_pn_data_rewind(pn_data_t * x0)
{
  pn_data_rewind(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_rewind(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_data_rewind(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_data_rewind _cffi_d_pn_data_rewind
#endif

static pn_type_t _cffi_d_pn_data_type(pn_data_t * x0)
{
  return pn_data_type(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_type(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_type_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_data_type(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_data_type _cffi_d_pn_data_type
#endif

static void _cffi_d_pn_data_widen(pn_data_t * x0)
{
  pn_data_widen(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_data_widen(PyObject *self, PyObject *arg0)
{
  pn_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(7), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_data_widen(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_data_widen _cffi_d_pn_data_widen
#endif

static int _cffi_d_pn_decref(void * x0)
{
  return pn_decref(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_decref(PyObject *self, PyObject *arg0)
{
  void * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(42), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(42), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_decref(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_decref _cffi_d_pn_decref
#endif

static pn_delivery_t * _cffi_d_pn_delivery(pn_link_t * x0, pn_bytes_t x1)
{
  return pn_delivery(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_delivery(PyObject *self, PyObject *args)
{
  pn_link_t * x0;
  pn_bytes_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_delivery_t * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_delivery", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(132), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_delivery(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(14));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static pn_delivery_t * _cffi_f_pn_delivery(pn_link_t * x0, pn_bytes_t *x1)
{
  pn_delivery_t * result;
  { result = pn_delivery(x0, *x1); }
  return result;
}
#endif

static void _cffi_d_pn_delivery_abort(pn_delivery_t * x0)
{
  pn_delivery_abort(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_delivery_abort(PyObject *self, PyObject *arg0)
{
  pn_delivery_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_delivery_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_delivery_abort(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_delivery_abort _cffi_d_pn_delivery_abort
#endif

static _Bool _cffi_d_pn_delivery_aborted(pn_delivery_t * x0)
{
  return pn_delivery_aborted(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_delivery_aborted(PyObject *self, PyObject *arg0)
{
  pn_delivery_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_delivery_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_delivery_aborted(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_delivery_aborted _cffi_d_pn_delivery_aborted
#endif

static pn_record_t * _cffi_d_pn_delivery_attachments(pn_delivery_t * x0)
{
  return pn_delivery_attachments(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_delivery_attachments(PyObject *self, PyObject *arg0)
{
  pn_delivery_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_record_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_delivery_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_delivery_attachments(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(623));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_delivery_attachments _cffi_d_pn_delivery_attachments
#endif

static pn_link_t * _cffi_d_pn_delivery_link(pn_delivery_t * x0)
{
  return pn_delivery_link(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_delivery_link(PyObject *self, PyObject *arg0)
{
  pn_delivery_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_link_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_delivery_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_delivery_link(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(20));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_delivery_link _cffi_d_pn_delivery_link
#endif

static pn_disposition_t * _cffi_d_pn_delivery_local(pn_delivery_t * x0)
{
  return pn_delivery_local(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_delivery_local(PyObject *self, PyObject *arg0)
{
  pn_delivery_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_disposition_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_delivery_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_delivery_local(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_delivery_local _cffi_d_pn_delivery_local
#endif

static uint64_t _cffi_d_pn_delivery_local_state(pn_delivery_t * x0)
{
  return pn_delivery_local_state(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_delivery_local_state(PyObject *self, PyObject *arg0)
{
  pn_delivery_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint64_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_delivery_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_delivery_local_state(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint64_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_delivery_local_state _cffi_d_pn_delivery_local_state
#endif

static _Bool _cffi_d_pn_delivery_partial(pn_delivery_t * x0)
{
  return pn_delivery_partial(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_delivery_partial(PyObject *self, PyObject *arg0)
{
  pn_delivery_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_delivery_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_delivery_partial(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_delivery_partial _cffi_d_pn_delivery_partial
#endif

static size_t _cffi_d_pn_delivery_pending(pn_delivery_t * x0)
{
  return pn_delivery_pending(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_delivery_pending(PyObject *self, PyObject *arg0)
{
  pn_delivery_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  size_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_delivery_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_delivery_pending(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, size_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_delivery_pending _cffi_d_pn_delivery_pending
#endif

static _Bool _cffi_d_pn_delivery_readable(pn_delivery_t * x0)
{
  return pn_delivery_readable(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_delivery_readable(PyObject *self, PyObject *arg0)
{
  pn_delivery_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_delivery_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_delivery_readable(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_delivery_readable _cffi_d_pn_delivery_readable
#endif

static pn_disposition_t * _cffi_d_pn_delivery_remote(pn_delivery_t * x0)
{
  return pn_delivery_remote(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_delivery_remote(PyObject *self, PyObject *arg0)
{
  pn_delivery_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_disposition_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_delivery_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_delivery_remote(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(17));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_delivery_remote _cffi_d_pn_delivery_remote
#endif

static uint64_t _cffi_d_pn_delivery_remote_state(pn_delivery_t * x0)
{
  return pn_delivery_remote_state(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_delivery_remote_state(PyObject *self, PyObject *arg0)
{
  pn_delivery_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint64_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_delivery_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_delivery_remote_state(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint64_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_delivery_remote_state _cffi_d_pn_delivery_remote_state
#endif

static void _cffi_d_pn_delivery_settle(pn_delivery_t * x0)
{
  pn_delivery_settle(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_delivery_settle(PyObject *self, PyObject *arg0)
{
  pn_delivery_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_delivery_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_delivery_settle(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_delivery_settle _cffi_d_pn_delivery_settle
#endif

static _Bool _cffi_d_pn_delivery_settled(pn_delivery_t * x0)
{
  return pn_delivery_settled(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_delivery_settled(PyObject *self, PyObject *arg0)
{
  pn_delivery_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_delivery_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_delivery_settled(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_delivery_settled _cffi_d_pn_delivery_settled
#endif

static pn_bytes_t _cffi_d_pn_delivery_tag(pn_delivery_t * x0)
{
  return pn_delivery_tag(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_delivery_tag(PyObject *self, PyObject *arg0)
{
  pn_delivery_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_bytes_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_delivery_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_delivery_tag(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(132));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_pn_delivery_tag(pn_bytes_t *result, pn_delivery_t * x0)
{
  { *result = pn_delivery_tag(x0); }
}
#endif

static void _cffi_d_pn_delivery_update(pn_delivery_t * x0, uint64_t x1)
{
  pn_delivery_update(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_delivery_update(PyObject *self, PyObject *args)
{
  pn_delivery_t * x0;
  uint64_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_delivery_update", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_delivery_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint64_t);
  if (x1 == (uint64_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_delivery_update(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_delivery_update _cffi_d_pn_delivery_update
#endif

static _Bool _cffi_d_pn_delivery_updated(pn_delivery_t * x0)
{
  return pn_delivery_updated(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_delivery_updated(PyObject *self, PyObject *arg0)
{
  pn_delivery_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_delivery_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_delivery_updated(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_delivery_updated _cffi_d_pn_delivery_updated
#endif

static _Bool _cffi_d_pn_delivery_writable(pn_delivery_t * x0)
{
  return pn_delivery_writable(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_delivery_writable(PyObject *self, PyObject *arg0)
{
  pn_delivery_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(14), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_delivery_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(14), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_delivery_writable(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_delivery_writable _cffi_d_pn_delivery_writable
#endif

static pn_data_t * _cffi_d_pn_disposition_annotations(pn_disposition_t * x0)
{
  return pn_disposition_annotations(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_disposition_annotations(PyObject *self, PyObject *arg0)
{
  pn_disposition_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_data_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(17), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_disposition_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(17), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_disposition_annotations(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(7));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_disposition_annotations _cffi_d_pn_disposition_annotations
#endif

static pn_condition_t * _cffi_d_pn_disposition_condition(pn_disposition_t * x0)
{
  return pn_disposition_condition(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_disposition_condition(PyObject *self, PyObject *arg0)
{
  pn_disposition_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_condition_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(17), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_disposition_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(17), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_disposition_condition(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(4));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_disposition_condition _cffi_d_pn_disposition_condition
#endif

static pn_data_t * _cffi_d_pn_disposition_data(pn_disposition_t * x0)
{
  return pn_disposition_data(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_disposition_data(PyObject *self, PyObject *arg0)
{
  pn_disposition_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_data_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(17), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_disposition_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(17), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_disposition_data(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(7));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_disposition_data _cffi_d_pn_disposition_data
#endif

static uint32_t _cffi_d_pn_disposition_get_section_number(pn_disposition_t * x0)
{
  return pn_disposition_get_section_number(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_disposition_get_section_number(PyObject *self, PyObject *arg0)
{
  pn_disposition_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint32_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(17), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_disposition_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(17), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_disposition_get_section_number(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint32_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_disposition_get_section_number _cffi_d_pn_disposition_get_section_number
#endif

static uint64_t _cffi_d_pn_disposition_get_section_offset(pn_disposition_t * x0)
{
  return pn_disposition_get_section_offset(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_disposition_get_section_offset(PyObject *self, PyObject *arg0)
{
  pn_disposition_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint64_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(17), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_disposition_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(17), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_disposition_get_section_offset(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint64_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_disposition_get_section_offset _cffi_d_pn_disposition_get_section_offset
#endif

static _Bool _cffi_d_pn_disposition_is_failed(pn_disposition_t * x0)
{
  return pn_disposition_is_failed(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_disposition_is_failed(PyObject *self, PyObject *arg0)
{
  pn_disposition_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(17), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_disposition_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(17), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_disposition_is_failed(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_disposition_is_failed _cffi_d_pn_disposition_is_failed
#endif

static _Bool _cffi_d_pn_disposition_is_undeliverable(pn_disposition_t * x0)
{
  return pn_disposition_is_undeliverable(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_disposition_is_undeliverable(PyObject *self, PyObject *arg0)
{
  pn_disposition_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(17), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_disposition_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(17), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_disposition_is_undeliverable(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_disposition_is_undeliverable _cffi_d_pn_disposition_is_undeliverable
#endif

static void _cffi_d_pn_disposition_set_failed(pn_disposition_t * x0, _Bool x1)
{
  pn_disposition_set_failed(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_disposition_set_failed(PyObject *self, PyObject *args)
{
  pn_disposition_t * x0;
  _Bool x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_disposition_set_failed", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(17), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_disposition_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(17), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (_Bool)_cffi_to_c__Bool(arg1);
  if (x1 == (_Bool)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_disposition_set_failed(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_disposition_set_failed _cffi_d_pn_disposition_set_failed
#endif

static void _cffi_d_pn_disposition_set_section_number(pn_disposition_t * x0, uint32_t x1)
{
  pn_disposition_set_section_number(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_disposition_set_section_number(PyObject *self, PyObject *args)
{
  pn_disposition_t * x0;
  uint32_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_disposition_set_section_number", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(17), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_disposition_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(17), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint32_t);
  if (x1 == (uint32_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_disposition_set_section_number(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_disposition_set_section_number _cffi_d_pn_disposition_set_section_number
#endif

static void _cffi_d_pn_disposition_set_section_offset(pn_disposition_t * x0, uint64_t x1)
{
  pn_disposition_set_section_offset(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_disposition_set_section_offset(PyObject *self, PyObject *args)
{
  pn_disposition_t * x0;
  uint64_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_disposition_set_section_offset", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(17), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_disposition_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(17), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint64_t);
  if (x1 == (uint64_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_disposition_set_section_offset(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_disposition_set_section_offset _cffi_d_pn_disposition_set_section_offset
#endif

static void _cffi_d_pn_disposition_set_undeliverable(pn_disposition_t * x0, _Bool x1)
{
  pn_disposition_set_undeliverable(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_disposition_set_undeliverable(PyObject *self, PyObject *args)
{
  pn_disposition_t * x0;
  _Bool x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_disposition_set_undeliverable", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(17), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_disposition_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(17), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (_Bool)_cffi_to_c__Bool(arg1);
  if (x1 == (_Bool)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_disposition_set_undeliverable(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_disposition_set_undeliverable _cffi_d_pn_disposition_set_undeliverable
#endif

static uint64_t _cffi_d_pn_disposition_type(pn_disposition_t * x0)
{
  return pn_disposition_type(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_disposition_type(PyObject *self, PyObject *arg0)
{
  pn_disposition_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint64_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(17), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_disposition_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(17), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_disposition_type(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint64_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_disposition_type _cffi_d_pn_disposition_type
#endif

static int _cffi_d_pn_error_code(pn_error_t * x0)
{
  return pn_error_code(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_error_code(PyObject *self, PyObject *arg0)
{
  pn_error_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(51), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_error_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(51), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_error_code(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_error_code _cffi_d_pn_error_code
#endif

static char const * _cffi_d_pn_error_text(pn_error_t * x0)
{
  return pn_error_text(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_error_text(PyObject *self, PyObject *arg0)
{
  pn_error_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(51), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_error_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(51), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_error_text(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_error_text _cffi_d_pn_error_text
#endif

static char const * _cffi_d_pn_event_class_name_py(pn_event_t * x0)
{
  return pn_event_class_name_py(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_event_class_name_py(PyObject *self, PyObject *arg0)
{
  pn_event_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(54), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_event_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(54), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_event_class_name_py(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_event_class_name_py _cffi_d_pn_event_class_name_py
#endif

static pn_connection_t * _cffi_d_pn_event_connection(pn_event_t * x0)
{
  return pn_event_connection(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_event_connection(PyObject *self, PyObject *arg0)
{
  pn_event_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_connection_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(54), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_event_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(54), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_event_connection(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(48));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_event_connection _cffi_d_pn_event_connection
#endif

static void * _cffi_d_pn_event_context(pn_event_t * x0)
{
  return pn_event_context(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_event_context(PyObject *self, PyObject *arg0)
{
  pn_event_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  void * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(54), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_event_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(54), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_event_context(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(42));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_event_context _cffi_d_pn_event_context
#endif

static pn_delivery_t * _cffi_d_pn_event_delivery(pn_event_t * x0)
{
  return pn_event_delivery(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_event_delivery(PyObject *self, PyObject *arg0)
{
  pn_event_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_delivery_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(54), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_event_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(54), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_event_delivery(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(14));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_event_delivery _cffi_d_pn_event_delivery
#endif

static pn_link_t * _cffi_d_pn_event_link(pn_event_t * x0)
{
  return pn_event_link(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_event_link(PyObject *self, PyObject *arg0)
{
  pn_event_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_link_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(54), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_event_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(54), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_event_link(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(20));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_event_link _cffi_d_pn_event_link
#endif

static pn_session_t * _cffi_d_pn_event_session(pn_event_t * x0)
{
  return pn_event_session(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_event_session(PyObject *self, PyObject *arg0)
{
  pn_event_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_session_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(54), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_event_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(54), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_event_session(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(202));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_event_session _cffi_d_pn_event_session
#endif

static pn_transport_t * _cffi_d_pn_event_transport(pn_event_t * x0)
{
  return pn_event_transport(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_event_transport(PyObject *self, PyObject *arg0)
{
  pn_event_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_transport_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(54), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_event_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(54), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_event_transport(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(37));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_event_transport _cffi_d_pn_event_transport
#endif

static pn_event_type_t _cffi_d_pn_event_type(pn_event_t * x0)
{
  return pn_event_type(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_event_type(PyObject *self, PyObject *arg0)
{
  pn_event_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_event_type_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(54), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_event_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(54), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_event_type(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(57));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_event_type _cffi_d_pn_event_type
#endif

static char const * _cffi_d_pn_event_type_name(pn_event_type_t x0)
{
  return pn_event_type_name(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_event_type_name(PyObject *self, PyObject *arg0)
{
  pn_event_type_t x0;
  char const * result;
  PyObject *pyresult;

  if (_cffi_to_c((char *)&x0, _cffi_type(57), arg0) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_event_type_name(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  return pyresult;
}
#else
#  define _cffi_f_pn_event_type_name _cffi_d_pn_event_type_name
#endif

static void * _cffi_d_pn_incref(void * x0)
{
  return pn_incref(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_incref(PyObject *self, PyObject *arg0)
{
  void * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  void * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(42), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(42), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_incref(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(42));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_incref _cffi_d_pn_incref
#endif

static _Bool _cffi_d_pn_link_advance(pn_link_t * x0)
{
  return pn_link_advance(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_advance(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_advance(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_advance _cffi_d_pn_link_advance
#endif

static pn_record_t * _cffi_d_pn_link_attachments(pn_link_t * x0)
{
  return pn_link_attachments(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_attachments(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_record_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_attachments(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(623));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_attachments _cffi_d_pn_link_attachments
#endif

static int _cffi_d_pn_link_available(pn_link_t * x0)
{
  return pn_link_available(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_available(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_available(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_available _cffi_d_pn_link_available
#endif

static void _cffi_d_pn_link_close(pn_link_t * x0)
{
  pn_link_close(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_close(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_link_close(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_link_close _cffi_d_pn_link_close
#endif

static pn_condition_t * _cffi_d_pn_link_condition(pn_link_t * x0)
{
  return pn_link_condition(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_condition(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_condition_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_condition(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(4));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_condition _cffi_d_pn_link_condition
#endif

static int _cffi_d_pn_link_credit(pn_link_t * x0)
{
  return pn_link_credit(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_credit(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_credit(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_credit _cffi_d_pn_link_credit
#endif

static pn_delivery_t * _cffi_d_pn_link_current(pn_link_t * x0)
{
  return pn_link_current(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_current(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_delivery_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_current(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(14));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_current _cffi_d_pn_link_current
#endif

static void _cffi_d_pn_link_detach(pn_link_t * x0)
{
  pn_link_detach(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_detach(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_link_detach(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_link_detach _cffi_d_pn_link_detach
#endif

static void _cffi_d_pn_link_drain(pn_link_t * x0, int x1)
{
  pn_link_drain(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_drain(PyObject *self, PyObject *args)
{
  pn_link_t * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_link_drain", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_link_drain(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_link_drain _cffi_d_pn_link_drain
#endif

static int _cffi_d_pn_link_drained(pn_link_t * x0)
{
  return pn_link_drained(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_drained(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_drained(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_drained _cffi_d_pn_link_drained
#endif

static _Bool _cffi_d_pn_link_draining(pn_link_t * x0)
{
  return pn_link_draining(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_draining(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_draining(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_draining _cffi_d_pn_link_draining
#endif

static pn_error_t * _cffi_d_pn_link_error(pn_link_t * x0)
{
  return pn_link_error(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_error(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_error_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_error(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(51));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_error _cffi_d_pn_link_error
#endif

static void _cffi_d_pn_link_flow(pn_link_t * x0, int x1)
{
  pn_link_flow(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_flow(PyObject *self, PyObject *args)
{
  pn_link_t * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_link_flow", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_link_flow(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_link_flow _cffi_d_pn_link_flow
#endif

static void _cffi_d_pn_link_free(pn_link_t * x0)
{
  pn_link_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_free(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_link_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_link_free _cffi_d_pn_link_free
#endif

static _Bool _cffi_d_pn_link_get_drain(pn_link_t * x0)
{
  return pn_link_get_drain(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_get_drain(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_get_drain(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_get_drain _cffi_d_pn_link_get_drain
#endif

static pn_link_t * _cffi_d_pn_link_head(pn_connection_t * x0, int x1)
{
  return pn_link_head(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_head(PyObject *self, PyObject *args)
{
  pn_connection_t * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_link_t * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_link_head", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_connection_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_head(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(20));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_head _cffi_d_pn_link_head
#endif

static _Bool _cffi_d_pn_link_is_receiver(pn_link_t * x0)
{
  return pn_link_is_receiver(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_is_receiver(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_is_receiver(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_is_receiver _cffi_d_pn_link_is_receiver
#endif

static _Bool _cffi_d_pn_link_is_sender(pn_link_t * x0)
{
  return pn_link_is_sender(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_is_sender(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_is_sender(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_is_sender _cffi_d_pn_link_is_sender
#endif

static uint64_t _cffi_d_pn_link_max_message_size(pn_link_t * x0)
{
  return pn_link_max_message_size(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_max_message_size(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint64_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_max_message_size(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint64_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_max_message_size _cffi_d_pn_link_max_message_size
#endif

static char const * _cffi_d_pn_link_name(pn_link_t * x0)
{
  return pn_link_name(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_name(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_name(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_name _cffi_d_pn_link_name
#endif

static pn_link_t * _cffi_d_pn_link_next(pn_link_t * x0, int x1)
{
  return pn_link_next(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_next(PyObject *self, PyObject *args)
{
  pn_link_t * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_link_t * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_link_next", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_next(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(20));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_next _cffi_d_pn_link_next
#endif

static void _cffi_d_pn_link_offered(pn_link_t * x0, int x1)
{
  pn_link_offered(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_offered(PyObject *self, PyObject *args)
{
  pn_link_t * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_link_offered", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_link_offered(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_link_offered _cffi_d_pn_link_offered
#endif

static void _cffi_d_pn_link_open(pn_link_t * x0)
{
  pn_link_open(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_open(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_link_open(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_link_open _cffi_d_pn_link_open
#endif

static pn_data_t * _cffi_d_pn_link_properties(pn_link_t * x0)
{
  return pn_link_properties(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_properties(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_data_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_properties(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(7));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_properties _cffi_d_pn_link_properties
#endif

static int _cffi_d_pn_link_queued(pn_link_t * x0)
{
  return pn_link_queued(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_queued(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_queued(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_queued _cffi_d_pn_link_queued
#endif

static pn_rcv_settle_mode_t _cffi_d_pn_link_rcv_settle_mode(pn_link_t * x0)
{
  return pn_link_rcv_settle_mode(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_rcv_settle_mode(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_rcv_settle_mode_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_rcv_settle_mode(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(680));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_rcv_settle_mode _cffi_d_pn_link_rcv_settle_mode
#endif

static ssize_t _cffi_d_pn_link_recv(pn_link_t * x0, char * x1, size_t x2)
{
  return pn_link_recv(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_recv(PyObject *self, PyObject *args)
{
  pn_link_t * x0;
  char * x1;
  size_t x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  ssize_t result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "pn_link_recv", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(30), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(30), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, size_t);
  if (x2 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_recv(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, ssize_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_recv _cffi_d_pn_link_recv
#endif

static pn_condition_t * _cffi_d_pn_link_remote_condition(pn_link_t * x0)
{
  return pn_link_remote_condition(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_remote_condition(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_condition_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_remote_condition(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(4));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_remote_condition _cffi_d_pn_link_remote_condition
#endif

static uint64_t _cffi_d_pn_link_remote_max_message_size(pn_link_t * x0)
{
  return pn_link_remote_max_message_size(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_remote_max_message_size(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint64_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_remote_max_message_size(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint64_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_remote_max_message_size _cffi_d_pn_link_remote_max_message_size
#endif

static pn_data_t * _cffi_d_pn_link_remote_properties(pn_link_t * x0)
{
  return pn_link_remote_properties(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_remote_properties(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_data_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_remote_properties(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(7));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_remote_properties _cffi_d_pn_link_remote_properties
#endif

static pn_rcv_settle_mode_t _cffi_d_pn_link_remote_rcv_settle_mode(pn_link_t * x0)
{
  return pn_link_remote_rcv_settle_mode(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_remote_rcv_settle_mode(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_rcv_settle_mode_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_remote_rcv_settle_mode(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(680));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_remote_rcv_settle_mode _cffi_d_pn_link_remote_rcv_settle_mode
#endif

static pn_snd_settle_mode_t _cffi_d_pn_link_remote_snd_settle_mode(pn_link_t * x0)
{
  return pn_link_remote_snd_settle_mode(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_remote_snd_settle_mode(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_snd_settle_mode_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_remote_snd_settle_mode(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(684));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_remote_snd_settle_mode _cffi_d_pn_link_remote_snd_settle_mode
#endif

static pn_terminus_t * _cffi_d_pn_link_remote_source(pn_link_t * x0)
{
  return pn_link_remote_source(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_remote_source(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_terminus_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_remote_source(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(34));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_remote_source _cffi_d_pn_link_remote_source
#endif

static pn_terminus_t * _cffi_d_pn_link_remote_target(pn_link_t * x0)
{
  return pn_link_remote_target(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_remote_target(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_terminus_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_remote_target(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(34));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_remote_target _cffi_d_pn_link_remote_target
#endif

static ssize_t _cffi_d_pn_link_send(pn_link_t * x0, char const * x1, size_t x2)
{
  return pn_link_send(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_send(PyObject *self, PyObject *args)
{
  pn_link_t * x0;
  char const * x1;
  size_t x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  ssize_t result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "pn_link_send", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, size_t);
  if (x2 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_send(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, ssize_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_send _cffi_d_pn_link_send
#endif

static pn_session_t * _cffi_d_pn_link_session(pn_link_t * x0)
{
  return pn_link_session(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_session(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_session_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_session(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(202));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_session _cffi_d_pn_link_session
#endif

static void _cffi_d_pn_link_set_drain(pn_link_t * x0, _Bool x1)
{
  pn_link_set_drain(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_set_drain(PyObject *self, PyObject *args)
{
  pn_link_t * x0;
  _Bool x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_link_set_drain", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (_Bool)_cffi_to_c__Bool(arg1);
  if (x1 == (_Bool)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_link_set_drain(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_link_set_drain _cffi_d_pn_link_set_drain
#endif

static void _cffi_d_pn_link_set_max_message_size(pn_link_t * x0, uint64_t x1)
{
  pn_link_set_max_message_size(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_set_max_message_size(PyObject *self, PyObject *args)
{
  pn_link_t * x0;
  uint64_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_link_set_max_message_size", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint64_t);
  if (x1 == (uint64_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_link_set_max_message_size(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_link_set_max_message_size _cffi_d_pn_link_set_max_message_size
#endif

static void _cffi_d_pn_link_set_rcv_settle_mode(pn_link_t * x0, pn_rcv_settle_mode_t x1)
{
  pn_link_set_rcv_settle_mode(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_set_rcv_settle_mode(PyObject *self, PyObject *args)
{
  pn_link_t * x0;
  pn_rcv_settle_mode_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_link_set_rcv_settle_mode", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(680), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_link_set_rcv_settle_mode(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_link_set_rcv_settle_mode _cffi_d_pn_link_set_rcv_settle_mode
#endif

static void _cffi_d_pn_link_set_snd_settle_mode(pn_link_t * x0, pn_snd_settle_mode_t x1)
{
  pn_link_set_snd_settle_mode(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_set_snd_settle_mode(PyObject *self, PyObject *args)
{
  pn_link_t * x0;
  pn_snd_settle_mode_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_link_set_snd_settle_mode", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(684), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_link_set_snd_settle_mode(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_link_set_snd_settle_mode _cffi_d_pn_link_set_snd_settle_mode
#endif

static pn_snd_settle_mode_t _cffi_d_pn_link_snd_settle_mode(pn_link_t * x0)
{
  return pn_link_snd_settle_mode(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_snd_settle_mode(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_snd_settle_mode_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_snd_settle_mode(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(684));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_snd_settle_mode _cffi_d_pn_link_snd_settle_mode
#endif

static pn_terminus_t * _cffi_d_pn_link_source(pn_link_t * x0)
{
  return pn_link_source(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_source(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_terminus_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_source(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(34));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_source _cffi_d_pn_link_source
#endif

static int _cffi_d_pn_link_state(pn_link_t * x0)
{
  return pn_link_state(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_state(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_state(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_state _cffi_d_pn_link_state
#endif

static pn_terminus_t * _cffi_d_pn_link_target(pn_link_t * x0)
{
  return pn_link_target(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_target(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_terminus_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_target(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(34));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_target _cffi_d_pn_link_target
#endif

static int _cffi_d_pn_link_unsettled(pn_link_t * x0)
{
  return pn_link_unsettled(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_link_unsettled(PyObject *self, PyObject *arg0)
{
  pn_link_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(20), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_link_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(20), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_link_unsettled(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_link_unsettled _cffi_d_pn_link_unsettled
#endif

static pn_message_t * _cffi_d_pn_message(void)
{
  return pn_message();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message(PyObject *self, PyObject *noarg)
{
  pn_message_t * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(23));
  return pyresult;
}
#else
#  define _cffi_f_pn_message _cffi_d_pn_message
#endif

static pn_data_t * _cffi_d_pn_message_annotations(pn_message_t * x0)
{
  return pn_message_annotations(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_annotations(PyObject *self, PyObject *arg0)
{
  pn_message_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_data_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_annotations(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(7));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_annotations _cffi_d_pn_message_annotations
#endif

static pn_data_t * _cffi_d_pn_message_body(pn_message_t * x0)
{
  return pn_message_body(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_body(PyObject *self, PyObject *arg0)
{
  pn_message_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_data_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_body(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(7));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_body _cffi_d_pn_message_body
#endif

static void _cffi_d_pn_message_clear(pn_message_t * x0)
{
  pn_message_clear(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_clear(PyObject *self, PyObject *arg0)
{
  pn_message_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_message_clear(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_message_clear _cffi_d_pn_message_clear
#endif

static int _cffi_d_pn_message_decode(pn_message_t * x0, char const * x1, size_t x2)
{
  return pn_message_decode(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_decode(PyObject *self, PyObject *args)
{
  pn_message_t * x0;
  char const * x1;
  size_t x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "pn_message_decode", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, size_t);
  if (x2 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_decode(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_decode _cffi_d_pn_message_decode
#endif

static ssize_t _cffi_d_pn_message_encode_py(pn_message_t * x0, char * x1, size_t x2)
{
  return pn_message_encode_py(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_encode_py(PyObject *self, PyObject *args)
{
  pn_message_t * x0;
  char * x1;
  size_t x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  ssize_t result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "pn_message_encode_py", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(30), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(30), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, size_t);
  if (x2 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_encode_py(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, ssize_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_encode_py _cffi_d_pn_message_encode_py
#endif

static pn_error_t * _cffi_d_pn_message_error(pn_message_t * x0)
{
  return pn_message_error(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_error(PyObject *self, PyObject *arg0)
{
  pn_message_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_error_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_error(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(51));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_error _cffi_d_pn_message_error
#endif

static void _cffi_d_pn_message_free(pn_message_t * x0)
{
  pn_message_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_free(PyObject *self, PyObject *arg0)
{
  pn_message_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_message_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_message_free _cffi_d_pn_message_free
#endif

static char const * _cffi_d_pn_message_get_address(pn_message_t * x0)
{
  return pn_message_get_address(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_get_address(PyObject *self, PyObject *arg0)
{
  pn_message_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_get_address(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_get_address _cffi_d_pn_message_get_address
#endif

static char const * _cffi_d_pn_message_get_content_encoding(pn_message_t * x0)
{
  return pn_message_get_content_encoding(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_get_content_encoding(PyObject *self, PyObject *arg0)
{
  pn_message_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_get_content_encoding(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_get_content_encoding _cffi_d_pn_message_get_content_encoding
#endif

static char const * _cffi_d_pn_message_get_content_type(pn_message_t * x0)
{
  return pn_message_get_content_type(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_get_content_type(PyObject *self, PyObject *arg0)
{
  pn_message_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_get_content_type(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_get_content_type _cffi_d_pn_message_get_content_type
#endif

static pn_atom_t _cffi_d_pn_message_get_correlation_id(pn_message_t * x0)
{
  return pn_message_get_correlation_id(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_get_correlation_id(PyObject *self, PyObject *arg0)
{
  pn_message_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_atom_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_get_correlation_id(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(187));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_pn_message_get_correlation_id(pn_atom_t *result, pn_message_t * x0)
{
  { *result = pn_message_get_correlation_id(x0); }
}
#endif

static int64_t _cffi_d_pn_message_get_creation_time(pn_message_t * x0)
{
  return pn_message_get_creation_time(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_get_creation_time(PyObject *self, PyObject *arg0)
{
  pn_message_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int64_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_get_creation_time(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int64_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_get_creation_time _cffi_d_pn_message_get_creation_time
#endif

static uint32_t _cffi_d_pn_message_get_delivery_count(pn_message_t * x0)
{
  return pn_message_get_delivery_count(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_get_delivery_count(PyObject *self, PyObject *arg0)
{
  pn_message_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint32_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_get_delivery_count(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint32_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_get_delivery_count _cffi_d_pn_message_get_delivery_count
#endif

static int64_t _cffi_d_pn_message_get_expiry_time(pn_message_t * x0)
{
  return pn_message_get_expiry_time(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_get_expiry_time(PyObject *self, PyObject *arg0)
{
  pn_message_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int64_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_get_expiry_time(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int64_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_get_expiry_time _cffi_d_pn_message_get_expiry_time
#endif

static char const * _cffi_d_pn_message_get_group_id(pn_message_t * x0)
{
  return pn_message_get_group_id(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_get_group_id(PyObject *self, PyObject *arg0)
{
  pn_message_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_get_group_id(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_get_group_id _cffi_d_pn_message_get_group_id
#endif

static uint32_t _cffi_d_pn_message_get_group_sequence(pn_message_t * x0)
{
  return pn_message_get_group_sequence(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_get_group_sequence(PyObject *self, PyObject *arg0)
{
  pn_message_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint32_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_get_group_sequence(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint32_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_get_group_sequence _cffi_d_pn_message_get_group_sequence
#endif

static pn_atom_t _cffi_d_pn_message_get_id(pn_message_t * x0)
{
  return pn_message_get_id(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_get_id(PyObject *self, PyObject *arg0)
{
  pn_message_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_atom_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_get_id(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(187));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_pn_message_get_id(pn_atom_t *result, pn_message_t * x0)
{
  { *result = pn_message_get_id(x0); }
}
#endif

static uint8_t _cffi_d_pn_message_get_priority(pn_message_t * x0)
{
  return pn_message_get_priority(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_get_priority(PyObject *self, PyObject *arg0)
{
  pn_message_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint8_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_get_priority(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint8_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_get_priority _cffi_d_pn_message_get_priority
#endif

static char const * _cffi_d_pn_message_get_reply_to(pn_message_t * x0)
{
  return pn_message_get_reply_to(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_get_reply_to(PyObject *self, PyObject *arg0)
{
  pn_message_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_get_reply_to(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_get_reply_to _cffi_d_pn_message_get_reply_to
#endif

static char const * _cffi_d_pn_message_get_reply_to_group_id(pn_message_t * x0)
{
  return pn_message_get_reply_to_group_id(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_get_reply_to_group_id(PyObject *self, PyObject *arg0)
{
  pn_message_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_get_reply_to_group_id(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_get_reply_to_group_id _cffi_d_pn_message_get_reply_to_group_id
#endif

static char const * _cffi_d_pn_message_get_subject(pn_message_t * x0)
{
  return pn_message_get_subject(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_get_subject(PyObject *self, PyObject *arg0)
{
  pn_message_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_get_subject(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_get_subject _cffi_d_pn_message_get_subject
#endif

static uint32_t _cffi_d_pn_message_get_ttl(pn_message_t * x0)
{
  return pn_message_get_ttl(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_get_ttl(PyObject *self, PyObject *arg0)
{
  pn_message_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint32_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_get_ttl(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint32_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_get_ttl _cffi_d_pn_message_get_ttl
#endif

static pn_bytes_t _cffi_d_pn_message_get_user_id(pn_message_t * x0)
{
  return pn_message_get_user_id(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_get_user_id(PyObject *self, PyObject *arg0)
{
  pn_message_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_bytes_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_get_user_id(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(132));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_pn_message_get_user_id(pn_bytes_t *result, pn_message_t * x0)
{
  { *result = pn_message_get_user_id(x0); }
}
#endif

static pn_data_t * _cffi_d_pn_message_instructions(pn_message_t * x0)
{
  return pn_message_instructions(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_instructions(PyObject *self, PyObject *arg0)
{
  pn_message_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_data_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_instructions(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(7));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_instructions _cffi_d_pn_message_instructions
#endif

static _Bool _cffi_d_pn_message_is_durable(pn_message_t * x0)
{
  return pn_message_is_durable(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_is_durable(PyObject *self, PyObject *arg0)
{
  pn_message_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_is_durable(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_is_durable _cffi_d_pn_message_is_durable
#endif

static _Bool _cffi_d_pn_message_is_first_acquirer(pn_message_t * x0)
{
  return pn_message_is_first_acquirer(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_is_first_acquirer(PyObject *self, PyObject *arg0)
{
  pn_message_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_is_first_acquirer(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_is_first_acquirer _cffi_d_pn_message_is_first_acquirer
#endif

static _Bool _cffi_d_pn_message_is_inferred(pn_message_t * x0)
{
  return pn_message_is_inferred(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_is_inferred(PyObject *self, PyObject *arg0)
{
  pn_message_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_is_inferred(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_is_inferred _cffi_d_pn_message_is_inferred
#endif

static pn_data_t * _cffi_d_pn_message_properties(pn_message_t * x0)
{
  return pn_message_properties(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_properties(PyObject *self, PyObject *arg0)
{
  pn_message_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_data_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_properties(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(7));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_properties _cffi_d_pn_message_properties
#endif

static int _cffi_d_pn_message_set_address(pn_message_t * x0, char const * x1)
{
  return pn_message_set_address(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_set_address(PyObject *self, PyObject *args)
{
  pn_message_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_message_set_address", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_set_address(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_set_address _cffi_d_pn_message_set_address
#endif

static int _cffi_d_pn_message_set_content_encoding(pn_message_t * x0, char const * x1)
{
  return pn_message_set_content_encoding(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_set_content_encoding(PyObject *self, PyObject *args)
{
  pn_message_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_message_set_content_encoding", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_set_content_encoding(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_set_content_encoding _cffi_d_pn_message_set_content_encoding
#endif

static int _cffi_d_pn_message_set_content_type(pn_message_t * x0, char const * x1)
{
  return pn_message_set_content_type(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_set_content_type(PyObject *self, PyObject *args)
{
  pn_message_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_message_set_content_type", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_set_content_type(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_set_content_type _cffi_d_pn_message_set_content_type
#endif

static int _cffi_d_pn_message_set_correlation_id(pn_message_t * x0, pn_atom_t x1)
{
  return pn_message_set_correlation_id(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_set_correlation_id(PyObject *self, PyObject *args)
{
  pn_message_t * x0;
  pn_atom_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_message_set_correlation_id", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(187), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_set_correlation_id(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static int _cffi_f_pn_message_set_correlation_id(pn_message_t * x0, pn_atom_t *x1)
{
  int result;
  { result = pn_message_set_correlation_id(x0, *x1); }
  return result;
}
#endif

static int _cffi_d_pn_message_set_creation_time(pn_message_t * x0, int64_t x1)
{
  return pn_message_set_creation_time(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_set_creation_time(PyObject *self, PyObject *args)
{
  pn_message_t * x0;
  int64_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_message_set_creation_time", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int64_t);
  if (x1 == (int64_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_set_creation_time(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_set_creation_time _cffi_d_pn_message_set_creation_time
#endif

static int _cffi_d_pn_message_set_delivery_count(pn_message_t * x0, uint32_t x1)
{
  return pn_message_set_delivery_count(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_set_delivery_count(PyObject *self, PyObject *args)
{
  pn_message_t * x0;
  uint32_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_message_set_delivery_count", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint32_t);
  if (x1 == (uint32_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_set_delivery_count(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_set_delivery_count _cffi_d_pn_message_set_delivery_count
#endif

static int _cffi_d_pn_message_set_durable(pn_message_t * x0, _Bool x1)
{
  return pn_message_set_durable(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_set_durable(PyObject *self, PyObject *args)
{
  pn_message_t * x0;
  _Bool x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_message_set_durable", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (_Bool)_cffi_to_c__Bool(arg1);
  if (x1 == (_Bool)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_set_durable(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_set_durable _cffi_d_pn_message_set_durable
#endif

static int _cffi_d_pn_message_set_expiry_time(pn_message_t * x0, int64_t x1)
{
  return pn_message_set_expiry_time(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_set_expiry_time(PyObject *self, PyObject *args)
{
  pn_message_t * x0;
  int64_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_message_set_expiry_time", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int64_t);
  if (x1 == (int64_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_set_expiry_time(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_set_expiry_time _cffi_d_pn_message_set_expiry_time
#endif

static int _cffi_d_pn_message_set_first_acquirer(pn_message_t * x0, _Bool x1)
{
  return pn_message_set_first_acquirer(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_set_first_acquirer(PyObject *self, PyObject *args)
{
  pn_message_t * x0;
  _Bool x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_message_set_first_acquirer", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (_Bool)_cffi_to_c__Bool(arg1);
  if (x1 == (_Bool)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_set_first_acquirer(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_set_first_acquirer _cffi_d_pn_message_set_first_acquirer
#endif

static int _cffi_d_pn_message_set_group_id(pn_message_t * x0, char const * x1)
{
  return pn_message_set_group_id(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_set_group_id(PyObject *self, PyObject *args)
{
  pn_message_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_message_set_group_id", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_set_group_id(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_set_group_id _cffi_d_pn_message_set_group_id
#endif

static int _cffi_d_pn_message_set_group_sequence(pn_message_t * x0, uint32_t x1)
{
  return pn_message_set_group_sequence(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_set_group_sequence(PyObject *self, PyObject *args)
{
  pn_message_t * x0;
  uint32_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_message_set_group_sequence", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint32_t);
  if (x1 == (uint32_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_set_group_sequence(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_set_group_sequence _cffi_d_pn_message_set_group_sequence
#endif

static int _cffi_d_pn_message_set_id(pn_message_t * x0, pn_atom_t x1)
{
  return pn_message_set_id(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_set_id(PyObject *self, PyObject *args)
{
  pn_message_t * x0;
  pn_atom_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_message_set_id", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(187), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_set_id(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static int _cffi_f_pn_message_set_id(pn_message_t * x0, pn_atom_t *x1)
{
  int result;
  { result = pn_message_set_id(x0, *x1); }
  return result;
}
#endif

static int _cffi_d_pn_message_set_inferred(pn_message_t * x0, _Bool x1)
{
  return pn_message_set_inferred(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_set_inferred(PyObject *self, PyObject *args)
{
  pn_message_t * x0;
  _Bool x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_message_set_inferred", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (_Bool)_cffi_to_c__Bool(arg1);
  if (x1 == (_Bool)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_set_inferred(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_set_inferred _cffi_d_pn_message_set_inferred
#endif

static int _cffi_d_pn_message_set_priority(pn_message_t * x0, uint8_t x1)
{
  return pn_message_set_priority(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_set_priority(PyObject *self, PyObject *args)
{
  pn_message_t * x0;
  uint8_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_message_set_priority", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint8_t);
  if (x1 == (uint8_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_set_priority(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_set_priority _cffi_d_pn_message_set_priority
#endif

static int _cffi_d_pn_message_set_reply_to(pn_message_t * x0, char const * x1)
{
  return pn_message_set_reply_to(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_set_reply_to(PyObject *self, PyObject *args)
{
  pn_message_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_message_set_reply_to", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_set_reply_to(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_set_reply_to _cffi_d_pn_message_set_reply_to
#endif

static int _cffi_d_pn_message_set_reply_to_group_id(pn_message_t * x0, char const * x1)
{
  return pn_message_set_reply_to_group_id(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_set_reply_to_group_id(PyObject *self, PyObject *args)
{
  pn_message_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_message_set_reply_to_group_id", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_set_reply_to_group_id(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_set_reply_to_group_id _cffi_d_pn_message_set_reply_to_group_id
#endif

static int _cffi_d_pn_message_set_subject(pn_message_t * x0, char const * x1)
{
  return pn_message_set_subject(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_set_subject(PyObject *self, PyObject *args)
{
  pn_message_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_message_set_subject", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_set_subject(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_set_subject _cffi_d_pn_message_set_subject
#endif

static int _cffi_d_pn_message_set_ttl(pn_message_t * x0, uint32_t x1)
{
  return pn_message_set_ttl(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_set_ttl(PyObject *self, PyObject *args)
{
  pn_message_t * x0;
  uint32_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_message_set_ttl", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint32_t);
  if (x1 == (uint32_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_set_ttl(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_message_set_ttl _cffi_d_pn_message_set_ttl
#endif

static int _cffi_d_pn_message_set_user_id(pn_message_t * x0, pn_bytes_t x1)
{
  return pn_message_set_user_id(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_message_set_user_id(PyObject *self, PyObject *args)
{
  pn_message_t * x0;
  pn_bytes_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_message_set_user_id", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(23), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_message_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(23), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(132), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_message_set_user_id(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static int _cffi_f_pn_message_set_user_id(pn_message_t * x0, pn_bytes_t *x1)
{
  int result;
  { result = pn_message_set_user_id(x0, *x1); }
  return result;
}
#endif

static pn_link_t * _cffi_d_pn_receiver(pn_session_t * x0, char const * x1)
{
  return pn_receiver(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_receiver(PyObject *self, PyObject *args)
{
  pn_session_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_link_t * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_receiver", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(202), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_session_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(202), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_receiver(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(20));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_receiver _cffi_d_pn_receiver
#endif

static void _cffi_d_pn_record_def_py(pn_record_t * x0)
{
  pn_record_def_py(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_record_def_py(PyObject *self, PyObject *arg0)
{
  pn_record_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(623), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_record_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(623), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_record_def_py(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_record_def_py _cffi_d_pn_record_def_py
#endif

static void * _cffi_d_pn_record_get_py(pn_record_t * x0)
{
  return pn_record_get_py(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_record_get_py(PyObject *self, PyObject *arg0)
{
  pn_record_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  void * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(623), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_record_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(623), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_record_get_py(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(42));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_record_get_py _cffi_d_pn_record_get_py
#endif

static void _cffi_d_pn_record_set_py(pn_record_t * x0, void * x1)
{
  pn_record_set_py(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_record_set_py(PyObject *self, PyObject *args)
{
  pn_record_t * x0;
  void * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_record_set_py", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(623), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_record_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(623), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(42), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(42), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_record_set_py(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_record_set_py _cffi_d_pn_record_set_py
#endif

static pn_sasl_t * _cffi_d_pn_sasl(pn_transport_t * x0)
{
  return pn_sasl(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_sasl(PyObject *self, PyObject *arg0)
{
  pn_transport_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_sasl_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_sasl(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(26));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_sasl _cffi_d_pn_sasl
#endif

static void _cffi_d_pn_sasl_allowed_mechs(pn_sasl_t * x0, char const * x1)
{
  pn_sasl_allowed_mechs(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_sasl_allowed_mechs(PyObject *self, PyObject *args)
{
  pn_sasl_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_sasl_allowed_mechs", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_sasl_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(26), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_sasl_allowed_mechs(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_sasl_allowed_mechs _cffi_d_pn_sasl_allowed_mechs
#endif

static void _cffi_d_pn_sasl_config_name(pn_sasl_t * x0, char const * x1)
{
  pn_sasl_config_name(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_sasl_config_name(PyObject *self, PyObject *args)
{
  pn_sasl_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_sasl_config_name", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_sasl_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(26), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_sasl_config_name(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_sasl_config_name _cffi_d_pn_sasl_config_name
#endif

static void _cffi_d_pn_sasl_config_path(pn_sasl_t * x0, char const * x1)
{
  pn_sasl_config_path(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_sasl_config_path(PyObject *self, PyObject *args)
{
  pn_sasl_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_sasl_config_path", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_sasl_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(26), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_sasl_config_path(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_sasl_config_path _cffi_d_pn_sasl_config_path
#endif

static void _cffi_d_pn_sasl_done(pn_sasl_t * x0, pn_sasl_outcome_t x1)
{
  pn_sasl_done(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_sasl_done(PyObject *self, PyObject *args)
{
  pn_sasl_t * x0;
  pn_sasl_outcome_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_sasl_done", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_sasl_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(26), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(710), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_sasl_done(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_sasl_done _cffi_d_pn_sasl_done
#endif

static _Bool _cffi_d_pn_sasl_extended(void)
{
  return pn_sasl_extended();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_sasl_extended(PyObject *self, PyObject *noarg)
{
  _Bool result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_sasl_extended(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  return pyresult;
}
#else
#  define _cffi_f_pn_sasl_extended _cffi_d_pn_sasl_extended
#endif

static _Bool _cffi_d_pn_sasl_get_allow_insecure_mechs(pn_sasl_t * x0)
{
  return pn_sasl_get_allow_insecure_mechs(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_sasl_get_allow_insecure_mechs(PyObject *self, PyObject *arg0)
{
  pn_sasl_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_sasl_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(26), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_sasl_get_allow_insecure_mechs(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_sasl_get_allow_insecure_mechs _cffi_d_pn_sasl_get_allow_insecure_mechs
#endif

static char const * _cffi_d_pn_sasl_get_authorization(pn_sasl_t * x0)
{
  return pn_sasl_get_authorization(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_sasl_get_authorization(PyObject *self, PyObject *arg0)
{
  pn_sasl_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_sasl_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(26), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_sasl_get_authorization(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_sasl_get_authorization _cffi_d_pn_sasl_get_authorization
#endif

static char const * _cffi_d_pn_sasl_get_mech(pn_sasl_t * x0)
{
  return pn_sasl_get_mech(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_sasl_get_mech(PyObject *self, PyObject *arg0)
{
  pn_sasl_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_sasl_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(26), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_sasl_get_mech(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_sasl_get_mech _cffi_d_pn_sasl_get_mech
#endif

static char const * _cffi_d_pn_sasl_get_user(pn_sasl_t * x0)
{
  return pn_sasl_get_user(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_sasl_get_user(PyObject *self, PyObject *arg0)
{
  pn_sasl_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_sasl_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(26), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_sasl_get_user(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_sasl_get_user _cffi_d_pn_sasl_get_user
#endif

static pn_sasl_outcome_t _cffi_d_pn_sasl_outcome(pn_sasl_t * x0)
{
  return pn_sasl_outcome(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_sasl_outcome(PyObject *self, PyObject *arg0)
{
  pn_sasl_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_sasl_outcome_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_sasl_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(26), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_sasl_outcome(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(710));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_sasl_outcome _cffi_d_pn_sasl_outcome
#endif

static void _cffi_d_pn_sasl_set_allow_insecure_mechs(pn_sasl_t * x0, _Bool x1)
{
  pn_sasl_set_allow_insecure_mechs(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_sasl_set_allow_insecure_mechs(PyObject *self, PyObject *args)
{
  pn_sasl_t * x0;
  _Bool x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_sasl_set_allow_insecure_mechs", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_sasl_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(26), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (_Bool)_cffi_to_c__Bool(arg1);
  if (x1 == (_Bool)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_sasl_set_allow_insecure_mechs(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_sasl_set_allow_insecure_mechs _cffi_d_pn_sasl_set_allow_insecure_mechs
#endif

static pn_link_t * _cffi_d_pn_sender(pn_session_t * x0, char const * x1)
{
  return pn_sender(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_sender(PyObject *self, PyObject *args)
{
  pn_session_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_link_t * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_sender", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(202), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_session_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(202), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_sender(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(20));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_sender _cffi_d_pn_sender
#endif

static pn_session_t * _cffi_d_pn_session(pn_connection_t * x0)
{
  return pn_session(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_session(PyObject *self, PyObject *arg0)
{
  pn_connection_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_session_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_connection_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_session(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(202));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_session _cffi_d_pn_session
#endif

static pn_record_t * _cffi_d_pn_session_attachments(pn_session_t * x0)
{
  return pn_session_attachments(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_session_attachments(PyObject *self, PyObject *arg0)
{
  pn_session_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_record_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(202), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_session_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(202), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_session_attachments(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(623));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_session_attachments _cffi_d_pn_session_attachments
#endif

static void _cffi_d_pn_session_close(pn_session_t * x0)
{
  pn_session_close(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_session_close(PyObject *self, PyObject *arg0)
{
  pn_session_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(202), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_session_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(202), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_session_close(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_session_close _cffi_d_pn_session_close
#endif

static pn_condition_t * _cffi_d_pn_session_condition(pn_session_t * x0)
{
  return pn_session_condition(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_session_condition(PyObject *self, PyObject *arg0)
{
  pn_session_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_condition_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(202), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_session_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(202), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_session_condition(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(4));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_session_condition _cffi_d_pn_session_condition
#endif

static pn_connection_t * _cffi_d_pn_session_connection(pn_session_t * x0)
{
  return pn_session_connection(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_session_connection(PyObject *self, PyObject *arg0)
{
  pn_session_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_connection_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(202), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_session_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(202), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_session_connection(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(48));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_session_connection _cffi_d_pn_session_connection
#endif

static void _cffi_d_pn_session_free(pn_session_t * x0)
{
  pn_session_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_session_free(PyObject *self, PyObject *arg0)
{
  pn_session_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(202), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_session_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(202), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_session_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_session_free _cffi_d_pn_session_free
#endif

static size_t _cffi_d_pn_session_get_incoming_capacity(pn_session_t * x0)
{
  return pn_session_get_incoming_capacity(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_session_get_incoming_capacity(PyObject *self, PyObject *arg0)
{
  pn_session_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  size_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(202), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_session_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(202), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_session_get_incoming_capacity(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, size_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_session_get_incoming_capacity _cffi_d_pn_session_get_incoming_capacity
#endif

static size_t _cffi_d_pn_session_get_outgoing_window(pn_session_t * x0)
{
  return pn_session_get_outgoing_window(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_session_get_outgoing_window(PyObject *self, PyObject *arg0)
{
  pn_session_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  size_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(202), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_session_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(202), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_session_get_outgoing_window(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, size_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_session_get_outgoing_window _cffi_d_pn_session_get_outgoing_window
#endif

static pn_session_t * _cffi_d_pn_session_head(pn_connection_t * x0, int x1)
{
  return pn_session_head(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_session_head(PyObject *self, PyObject *args)
{
  pn_connection_t * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_session_t * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_session_head", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_connection_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_session_head(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(202));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_session_head _cffi_d_pn_session_head
#endif

static size_t _cffi_d_pn_session_incoming_bytes(pn_session_t * x0)
{
  return pn_session_incoming_bytes(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_session_incoming_bytes(PyObject *self, PyObject *arg0)
{
  pn_session_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  size_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(202), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_session_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(202), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_session_incoming_bytes(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, size_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_session_incoming_bytes _cffi_d_pn_session_incoming_bytes
#endif

static pn_session_t * _cffi_d_pn_session_next(pn_session_t * x0, int x1)
{
  return pn_session_next(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_session_next(PyObject *self, PyObject *args)
{
  pn_session_t * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_session_t * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_session_next", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(202), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_session_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(202), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_session_next(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(202));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_session_next _cffi_d_pn_session_next
#endif

static void _cffi_d_pn_session_open(pn_session_t * x0)
{
  pn_session_open(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_session_open(PyObject *self, PyObject *arg0)
{
  pn_session_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(202), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_session_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(202), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_session_open(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_session_open _cffi_d_pn_session_open
#endif

static size_t _cffi_d_pn_session_outgoing_bytes(pn_session_t * x0)
{
  return pn_session_outgoing_bytes(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_session_outgoing_bytes(PyObject *self, PyObject *arg0)
{
  pn_session_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  size_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(202), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_session_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(202), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_session_outgoing_bytes(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, size_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_session_outgoing_bytes _cffi_d_pn_session_outgoing_bytes
#endif

static pn_condition_t * _cffi_d_pn_session_remote_condition(pn_session_t * x0)
{
  return pn_session_remote_condition(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_session_remote_condition(PyObject *self, PyObject *arg0)
{
  pn_session_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_condition_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(202), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_session_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(202), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_session_remote_condition(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(4));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_session_remote_condition _cffi_d_pn_session_remote_condition
#endif

static void _cffi_d_pn_session_set_incoming_capacity(pn_session_t * x0, size_t x1)
{
  pn_session_set_incoming_capacity(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_session_set_incoming_capacity(PyObject *self, PyObject *args)
{
  pn_session_t * x0;
  size_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_session_set_incoming_capacity", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(202), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_session_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(202), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, size_t);
  if (x1 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_session_set_incoming_capacity(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_session_set_incoming_capacity _cffi_d_pn_session_set_incoming_capacity
#endif

static void _cffi_d_pn_session_set_outgoing_window(pn_session_t * x0, size_t x1)
{
  pn_session_set_outgoing_window(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_session_set_outgoing_window(PyObject *self, PyObject *args)
{
  pn_session_t * x0;
  size_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_session_set_outgoing_window", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(202), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_session_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(202), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, size_t);
  if (x1 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_session_set_outgoing_window(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_session_set_outgoing_window _cffi_d_pn_session_set_outgoing_window
#endif

static int _cffi_d_pn_session_state(pn_session_t * x0)
{
  return pn_session_state(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_session_state(PyObject *self, PyObject *arg0)
{
  pn_session_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(202), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_session_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(202), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_session_state(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_session_state _cffi_d_pn_session_state
#endif

static pn_ssl_t * _cffi_d_pn_ssl(pn_transport_t * x0)
{
  return pn_ssl(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_ssl(PyObject *self, PyObject *arg0)
{
  pn_transport_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_ssl_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_ssl(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(29));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_ssl _cffi_d_pn_ssl
#endif

static pn_ssl_domain_t * _cffi_d_pn_ssl_domain(pn_ssl_mode_t x0)
{
  return pn_ssl_domain(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_ssl_domain(PyObject *self, PyObject *arg0)
{
  pn_ssl_mode_t x0;
  pn_ssl_domain_t * result;
  PyObject *pyresult;

  if (_cffi_to_c((char *)&x0, _cffi_type(496), arg0) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_ssl_domain(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(205));
  return pyresult;
}
#else
#  define _cffi_f_pn_ssl_domain _cffi_d_pn_ssl_domain
#endif

static int _cffi_d_pn_ssl_domain_allow_unsecured_client(pn_ssl_domain_t * x0)
{
  return pn_ssl_domain_allow_unsecured_client(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_ssl_domain_allow_unsecured_client(PyObject *self, PyObject *arg0)
{
  pn_ssl_domain_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(205), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_ssl_domain_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(205), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_ssl_domain_allow_unsecured_client(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_ssl_domain_allow_unsecured_client _cffi_d_pn_ssl_domain_allow_unsecured_client
#endif

static void _cffi_d_pn_ssl_domain_free(pn_ssl_domain_t * x0)
{
  pn_ssl_domain_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_ssl_domain_free(PyObject *self, PyObject *arg0)
{
  pn_ssl_domain_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(205), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_ssl_domain_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(205), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_ssl_domain_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_ssl_domain_free _cffi_d_pn_ssl_domain_free
#endif

static int _cffi_d_pn_ssl_domain_set_ciphers(pn_ssl_domain_t * x0, char const * x1)
{
  return pn_ssl_domain_set_ciphers(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_ssl_domain_set_ciphers(PyObject *self, PyObject *args)
{
  pn_ssl_domain_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_ssl_domain_set_ciphers", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(205), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_ssl_domain_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(205), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_ssl_domain_set_ciphers(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_ssl_domain_set_ciphers _cffi_d_pn_ssl_domain_set_ciphers
#endif

static int _cffi_d_pn_ssl_domain_set_credentials(pn_ssl_domain_t * x0, char const * x1, char const * x2, char const * x3)
{
  return pn_ssl_domain_set_credentials(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_ssl_domain_set_credentials(PyObject *self, PyObject *args)
{
  pn_ssl_domain_t * x0;
  char const * x1;
  char const * x2;
  char const * x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "pn_ssl_domain_set_credentials", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(205), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_ssl_domain_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(205), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_ssl_domain_set_credentials(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_ssl_domain_set_credentials _cffi_d_pn_ssl_domain_set_credentials
#endif

static int _cffi_d_pn_ssl_domain_set_peer_authentication(pn_ssl_domain_t * x0, pn_ssl_verify_mode_t x1, char const * x2)
{
  return pn_ssl_domain_set_peer_authentication(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_ssl_domain_set_peer_authentication(PyObject *self, PyObject *args)
{
  pn_ssl_domain_t * x0;
  pn_ssl_verify_mode_t x1;
  char const * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "pn_ssl_domain_set_peer_authentication", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(205), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_ssl_domain_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(205), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(219), arg1) < 0)
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_ssl_domain_set_peer_authentication(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_ssl_domain_set_peer_authentication _cffi_d_pn_ssl_domain_set_peer_authentication
#endif

static int _cffi_d_pn_ssl_domain_set_protocols(pn_ssl_domain_t * x0, char const * x1)
{
  return pn_ssl_domain_set_protocols(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_ssl_domain_set_protocols(PyObject *self, PyObject *args)
{
  pn_ssl_domain_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_ssl_domain_set_protocols", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(205), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_ssl_domain_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(205), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_ssl_domain_set_protocols(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_ssl_domain_set_protocols _cffi_d_pn_ssl_domain_set_protocols
#endif

static int _cffi_d_pn_ssl_domain_set_trusted_ca_db(pn_ssl_domain_t * x0, char const * x1)
{
  return pn_ssl_domain_set_trusted_ca_db(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_ssl_domain_set_trusted_ca_db(PyObject *self, PyObject *args)
{
  pn_ssl_domain_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_ssl_domain_set_trusted_ca_db", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(205), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_ssl_domain_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(205), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_ssl_domain_set_trusted_ca_db(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_ssl_domain_set_trusted_ca_db _cffi_d_pn_ssl_domain_set_trusted_ca_db
#endif

static int _cffi_d_pn_ssl_get_cert_fingerprint(pn_ssl_t * x0, char * x1, size_t x2, pn_ssl_hash_alg x3)
{
  return pn_ssl_get_cert_fingerprint(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_ssl_get_cert_fingerprint(PyObject *self, PyObject *args)
{
  pn_ssl_t * x0;
  char * x1;
  size_t x2;
  pn_ssl_hash_alg x3;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "pn_ssl_get_cert_fingerprint", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(29), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_ssl_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(29), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(30), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(30), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, size_t);
  if (x2 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  if (_cffi_to_c((char *)&x3, _cffi_type(231), arg3) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_ssl_get_cert_fingerprint(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_ssl_get_cert_fingerprint _cffi_d_pn_ssl_get_cert_fingerprint
#endif

static _Bool _cffi_d_pn_ssl_get_cipher_name(pn_ssl_t * x0, char * x1, size_t x2)
{
  return pn_ssl_get_cipher_name(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_ssl_get_cipher_name(PyObject *self, PyObject *args)
{
  pn_ssl_t * x0;
  char * x1;
  size_t x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "pn_ssl_get_cipher_name", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(29), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_ssl_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(29), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(30), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(30), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, size_t);
  if (x2 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_ssl_get_cipher_name(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_ssl_get_cipher_name _cffi_d_pn_ssl_get_cipher_name
#endif

static int _cffi_d_pn_ssl_get_peer_hostname_py(pn_ssl_t * x0, char * x1, size_t x2)
{
  return pn_ssl_get_peer_hostname_py(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_ssl_get_peer_hostname_py(PyObject *self, PyObject *args)
{
  pn_ssl_t * x0;
  char * x1;
  size_t x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "pn_ssl_get_peer_hostname_py", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(29), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_ssl_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(29), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(30), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(30), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, size_t);
  if (x2 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_ssl_get_peer_hostname_py(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_ssl_get_peer_hostname_py _cffi_d_pn_ssl_get_peer_hostname_py
#endif

static _Bool _cffi_d_pn_ssl_get_protocol_name(pn_ssl_t * x0, char * x1, size_t x2)
{
  return pn_ssl_get_protocol_name(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_ssl_get_protocol_name(PyObject *self, PyObject *args)
{
  pn_ssl_t * x0;
  char * x1;
  size_t x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "pn_ssl_get_protocol_name", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(29), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_ssl_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(29), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(30), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(30), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, size_t);
  if (x2 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_ssl_get_protocol_name(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_ssl_get_protocol_name _cffi_d_pn_ssl_get_protocol_name
#endif

static char const * _cffi_d_pn_ssl_get_remote_subject(pn_ssl_t * x0)
{
  return pn_ssl_get_remote_subject(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_ssl_get_remote_subject(PyObject *self, PyObject *arg0)
{
  pn_ssl_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(29), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_ssl_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(29), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_ssl_get_remote_subject(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_ssl_get_remote_subject _cffi_d_pn_ssl_get_remote_subject
#endif

static char const * _cffi_d_pn_ssl_get_remote_subject_subfield(pn_ssl_t * x0, pn_ssl_cert_subject_subfield x1)
{
  return pn_ssl_get_remote_subject_subfield(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_ssl_get_remote_subject_subfield(PyObject *self, PyObject *args)
{
  pn_ssl_t * x0;
  pn_ssl_cert_subject_subfield x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_ssl_get_remote_subject_subfield", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(29), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_ssl_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(29), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(73), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_ssl_get_remote_subject_subfield(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_ssl_get_remote_subject_subfield _cffi_d_pn_ssl_get_remote_subject_subfield
#endif

static int _cffi_d_pn_ssl_init(pn_ssl_t * x0, pn_ssl_domain_t * x1, char const * x2)
{
  return pn_ssl_init(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_ssl_init(PyObject *self, PyObject *args)
{
  pn_ssl_t * x0;
  pn_ssl_domain_t * x1;
  char const * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "pn_ssl_init", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(29), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_ssl_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(29), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(205), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (pn_ssl_domain_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(205), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_ssl_init(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_ssl_init _cffi_d_pn_ssl_init
#endif

static _Bool _cffi_d_pn_ssl_present(void)
{
  return pn_ssl_present();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_ssl_present(PyObject *self, PyObject *noarg)
{
  _Bool result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_ssl_present(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  return pyresult;
}
#else
#  define _cffi_f_pn_ssl_present _cffi_d_pn_ssl_present
#endif

static pn_ssl_resume_status_t _cffi_d_pn_ssl_resume_status(pn_ssl_t * x0)
{
  return pn_ssl_resume_status(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_ssl_resume_status(PyObject *self, PyObject *arg0)
{
  pn_ssl_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_ssl_resume_status_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(29), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_ssl_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(29), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_ssl_resume_status(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(771));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_ssl_resume_status _cffi_d_pn_ssl_resume_status
#endif

static int _cffi_d_pn_ssl_set_peer_hostname(pn_ssl_t * x0, char const * x1)
{
  return pn_ssl_set_peer_hostname(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_ssl_set_peer_hostname(PyObject *self, PyObject *args)
{
  pn_ssl_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_ssl_set_peer_hostname", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(29), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_ssl_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(29), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_ssl_set_peer_hostname(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_ssl_set_peer_hostname _cffi_d_pn_ssl_set_peer_hostname
#endif

static pn_data_t * _cffi_d_pn_terminus_capabilities(pn_terminus_t * x0)
{
  return pn_terminus_capabilities(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_terminus_capabilities(PyObject *self, PyObject *arg0)
{
  pn_terminus_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_data_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_terminus_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_terminus_capabilities(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(7));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_terminus_capabilities _cffi_d_pn_terminus_capabilities
#endif

static int _cffi_d_pn_terminus_copy(pn_terminus_t * x0, pn_terminus_t * x1)
{
  return pn_terminus_copy(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_terminus_copy(PyObject *self, PyObject *args)
{
  pn_terminus_t * x0;
  pn_terminus_t * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_terminus_copy", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_terminus_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (pn_terminus_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_terminus_copy(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_terminus_copy _cffi_d_pn_terminus_copy
#endif

static pn_data_t * _cffi_d_pn_terminus_filter(pn_terminus_t * x0)
{
  return pn_terminus_filter(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_terminus_filter(PyObject *self, PyObject *arg0)
{
  pn_terminus_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_data_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_terminus_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_terminus_filter(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(7));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_terminus_filter _cffi_d_pn_terminus_filter
#endif

static char const * _cffi_d_pn_terminus_get_address(pn_terminus_t * x0)
{
  return pn_terminus_get_address(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_terminus_get_address(PyObject *self, PyObject *arg0)
{
  pn_terminus_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_terminus_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_terminus_get_address(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_terminus_get_address _cffi_d_pn_terminus_get_address
#endif

static pn_distribution_mode_t _cffi_d_pn_terminus_get_distribution_mode(pn_terminus_t const * x0)
{
  return pn_terminus_get_distribution_mode(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_terminus_get_distribution_mode(PyObject *self, PyObject *arg0)
{
  pn_terminus_t const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_distribution_mode_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(391), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_terminus_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(391), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_terminus_get_distribution_mode(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(252));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_terminus_get_distribution_mode _cffi_d_pn_terminus_get_distribution_mode
#endif

static pn_durability_t _cffi_d_pn_terminus_get_durability(pn_terminus_t * x0)
{
  return pn_terminus_get_durability(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_terminus_get_durability(PyObject *self, PyObject *arg0)
{
  pn_terminus_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_durability_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_terminus_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_terminus_get_durability(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(256));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_terminus_get_durability _cffi_d_pn_terminus_get_durability
#endif

static pn_expiry_policy_t _cffi_d_pn_terminus_get_expiry_policy(pn_terminus_t * x0)
{
  return pn_terminus_get_expiry_policy(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_terminus_get_expiry_policy(PyObject *self, PyObject *arg0)
{
  pn_terminus_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_expiry_policy_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_terminus_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_terminus_get_expiry_policy(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(260));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_terminus_get_expiry_policy _cffi_d_pn_terminus_get_expiry_policy
#endif

static uint32_t _cffi_d_pn_terminus_get_timeout(pn_terminus_t * x0)
{
  return pn_terminus_get_timeout(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_terminus_get_timeout(PyObject *self, PyObject *arg0)
{
  pn_terminus_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint32_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_terminus_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_terminus_get_timeout(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint32_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_terminus_get_timeout _cffi_d_pn_terminus_get_timeout
#endif

static pn_terminus_type_t _cffi_d_pn_terminus_get_type(pn_terminus_t * x0)
{
  return pn_terminus_get_type(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_terminus_get_type(PyObject *self, PyObject *arg0)
{
  pn_terminus_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_terminus_type_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_terminus_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_terminus_get_type(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(268));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_terminus_get_type _cffi_d_pn_terminus_get_type
#endif

static _Bool _cffi_d_pn_terminus_is_dynamic(pn_terminus_t * x0)
{
  return pn_terminus_is_dynamic(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_terminus_is_dynamic(PyObject *self, PyObject *arg0)
{
  pn_terminus_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_terminus_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_terminus_is_dynamic(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_terminus_is_dynamic _cffi_d_pn_terminus_is_dynamic
#endif

static pn_data_t * _cffi_d_pn_terminus_outcomes(pn_terminus_t * x0)
{
  return pn_terminus_outcomes(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_terminus_outcomes(PyObject *self, PyObject *arg0)
{
  pn_terminus_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_data_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_terminus_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_terminus_outcomes(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(7));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_terminus_outcomes _cffi_d_pn_terminus_outcomes
#endif

static pn_data_t * _cffi_d_pn_terminus_properties(pn_terminus_t * x0)
{
  return pn_terminus_properties(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_terminus_properties(PyObject *self, PyObject *arg0)
{
  pn_terminus_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_data_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_terminus_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_terminus_properties(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(7));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_terminus_properties _cffi_d_pn_terminus_properties
#endif

static int _cffi_d_pn_terminus_set_address(pn_terminus_t * x0, char const * x1)
{
  return pn_terminus_set_address(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_terminus_set_address(PyObject *self, PyObject *args)
{
  pn_terminus_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_terminus_set_address", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_terminus_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_terminus_set_address(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_terminus_set_address _cffi_d_pn_terminus_set_address
#endif

static int _cffi_d_pn_terminus_set_distribution_mode(pn_terminus_t * x0, pn_distribution_mode_t x1)
{
  return pn_terminus_set_distribution_mode(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_terminus_set_distribution_mode(PyObject *self, PyObject *args)
{
  pn_terminus_t * x0;
  pn_distribution_mode_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_terminus_set_distribution_mode", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_terminus_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(252), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_terminus_set_distribution_mode(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_terminus_set_distribution_mode _cffi_d_pn_terminus_set_distribution_mode
#endif

static int _cffi_d_pn_terminus_set_durability(pn_terminus_t * x0, pn_durability_t x1)
{
  return pn_terminus_set_durability(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_terminus_set_durability(PyObject *self, PyObject *args)
{
  pn_terminus_t * x0;
  pn_durability_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_terminus_set_durability", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_terminus_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(256), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_terminus_set_durability(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_terminus_set_durability _cffi_d_pn_terminus_set_durability
#endif

static int _cffi_d_pn_terminus_set_dynamic(pn_terminus_t * x0, _Bool x1)
{
  return pn_terminus_set_dynamic(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_terminus_set_dynamic(PyObject *self, PyObject *args)
{
  pn_terminus_t * x0;
  _Bool x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_terminus_set_dynamic", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_terminus_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (_Bool)_cffi_to_c__Bool(arg1);
  if (x1 == (_Bool)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_terminus_set_dynamic(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_terminus_set_dynamic _cffi_d_pn_terminus_set_dynamic
#endif

static int _cffi_d_pn_terminus_set_expiry_policy(pn_terminus_t * x0, pn_expiry_policy_t x1)
{
  return pn_terminus_set_expiry_policy(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_terminus_set_expiry_policy(PyObject *self, PyObject *args)
{
  pn_terminus_t * x0;
  pn_expiry_policy_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_terminus_set_expiry_policy", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_terminus_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(260), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_terminus_set_expiry_policy(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_terminus_set_expiry_policy _cffi_d_pn_terminus_set_expiry_policy
#endif

static int _cffi_d_pn_terminus_set_timeout(pn_terminus_t * x0, uint32_t x1)
{
  return pn_terminus_set_timeout(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_terminus_set_timeout(PyObject *self, PyObject *args)
{
  pn_terminus_t * x0;
  uint32_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_terminus_set_timeout", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_terminus_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint32_t);
  if (x1 == (uint32_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_terminus_set_timeout(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_terminus_set_timeout _cffi_d_pn_terminus_set_timeout
#endif

static int _cffi_d_pn_terminus_set_type(pn_terminus_t * x0, pn_terminus_type_t x1)
{
  return pn_terminus_set_type(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_terminus_set_type(PyObject *self, PyObject *args)
{
  pn_terminus_t * x0;
  pn_terminus_type_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_terminus_set_type", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(34), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_terminus_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(34), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(268), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_terminus_set_type(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_terminus_set_type _cffi_d_pn_terminus_set_type
#endif

static char * _cffi_d_pn_tostring(void * x0)
{
  return pn_tostring(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_tostring(PyObject *self, PyObject *arg0)
{
  void * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(42), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (void *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(42), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_tostring(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(30));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_tostring _cffi_d_pn_tostring
#endif

static pn_transport_t * _cffi_d_pn_transport(void)
{
  return pn_transport();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport(PyObject *self, PyObject *noarg)
{
  pn_transport_t * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_transport(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(37));
  return pyresult;
}
#else
#  define _cffi_f_pn_transport _cffi_d_pn_transport
#endif

static pn_record_t * _cffi_d_pn_transport_attachments(pn_transport_t * x0)
{
  return pn_transport_attachments(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_attachments(PyObject *self, PyObject *arg0)
{
  pn_transport_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_record_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_transport_attachments(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(623));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_transport_attachments _cffi_d_pn_transport_attachments
#endif

static int _cffi_d_pn_transport_bind(pn_transport_t * x0, pn_connection_t * x1)
{
  return pn_transport_bind(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_bind(PyObject *self, PyObject *args)
{
  pn_transport_t * x0;
  pn_connection_t * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_transport_bind", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(48), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (pn_connection_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(48), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_transport_bind(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_transport_bind _cffi_d_pn_transport_bind
#endif

static ssize_t _cffi_d_pn_transport_capacity(pn_transport_t * x0)
{
  return pn_transport_capacity(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_capacity(PyObject *self, PyObject *arg0)
{
  pn_transport_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  ssize_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_transport_capacity(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, ssize_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_transport_capacity _cffi_d_pn_transport_capacity
#endif

static int _cffi_d_pn_transport_close_head(pn_transport_t * x0)
{
  return pn_transport_close_head(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_close_head(PyObject *self, PyObject *arg0)
{
  pn_transport_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_transport_close_head(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_transport_close_head _cffi_d_pn_transport_close_head
#endif

static int _cffi_d_pn_transport_close_tail(pn_transport_t * x0)
{
  return pn_transport_close_tail(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_close_tail(PyObject *self, PyObject *arg0)
{
  pn_transport_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_transport_close_tail(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_transport_close_tail _cffi_d_pn_transport_close_tail
#endif

static _Bool _cffi_d_pn_transport_closed(pn_transport_t * x0)
{
  return pn_transport_closed(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_closed(PyObject *self, PyObject *arg0)
{
  pn_transport_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_transport_closed(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_transport_closed _cffi_d_pn_transport_closed
#endif

static pn_condition_t * _cffi_d_pn_transport_condition(pn_transport_t * x0)
{
  return pn_transport_condition(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_condition(PyObject *self, PyObject *arg0)
{
  pn_transport_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_condition_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_transport_condition(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(4));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_transport_condition _cffi_d_pn_transport_condition
#endif

static pn_connection_t * _cffi_d_pn_transport_connection(pn_transport_t * x0)
{
  return pn_transport_connection(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_connection(PyObject *self, PyObject *arg0)
{
  pn_transport_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_connection_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_transport_connection(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(48));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_transport_connection _cffi_d_pn_transport_connection
#endif

static pn_error_t * _cffi_d_pn_transport_error(pn_transport_t * x0)
{
  return pn_transport_error(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_error(PyObject *self, PyObject *arg0)
{
  pn_transport_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  pn_error_t * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_transport_error(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(51));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_transport_error _cffi_d_pn_transport_error
#endif

static uint16_t _cffi_d_pn_transport_get_channel_max(pn_transport_t * x0)
{
  return pn_transport_get_channel_max(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_get_channel_max(PyObject *self, PyObject *arg0)
{
  pn_transport_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint16_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_transport_get_channel_max(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint16_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_transport_get_channel_max _cffi_d_pn_transport_get_channel_max
#endif

static uint64_t _cffi_d_pn_transport_get_frames_input(pn_transport_t const * x0)
{
  return pn_transport_get_frames_input(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_get_frames_input(PyObject *self, PyObject *arg0)
{
  pn_transport_t const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint64_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(611), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(611), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_transport_get_frames_input(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint64_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_transport_get_frames_input _cffi_d_pn_transport_get_frames_input
#endif

static uint64_t _cffi_d_pn_transport_get_frames_output(pn_transport_t const * x0)
{
  return pn_transport_get_frames_output(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_get_frames_output(PyObject *self, PyObject *arg0)
{
  pn_transport_t const * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint64_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(611), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(611), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_transport_get_frames_output(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint64_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_transport_get_frames_output _cffi_d_pn_transport_get_frames_output
#endif

static uint32_t _cffi_d_pn_transport_get_idle_timeout(pn_transport_t * x0)
{
  return pn_transport_get_idle_timeout(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_get_idle_timeout(PyObject *self, PyObject *arg0)
{
  pn_transport_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint32_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_transport_get_idle_timeout(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint32_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_transport_get_idle_timeout _cffi_d_pn_transport_get_idle_timeout
#endif

static uint32_t _cffi_d_pn_transport_get_max_frame(pn_transport_t * x0)
{
  return pn_transport_get_max_frame(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_get_max_frame(PyObject *self, PyObject *arg0)
{
  pn_transport_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint32_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_transport_get_max_frame(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint32_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_transport_get_max_frame _cffi_d_pn_transport_get_max_frame
#endif

static uint32_t _cffi_d_pn_transport_get_remote_idle_timeout(pn_transport_t * x0)
{
  return pn_transport_get_remote_idle_timeout(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_get_remote_idle_timeout(PyObject *self, PyObject *arg0)
{
  pn_transport_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint32_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_transport_get_remote_idle_timeout(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint32_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_transport_get_remote_idle_timeout _cffi_d_pn_transport_get_remote_idle_timeout
#endif

static uint32_t _cffi_d_pn_transport_get_remote_max_frame(pn_transport_t * x0)
{
  return pn_transport_get_remote_max_frame(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_get_remote_max_frame(PyObject *self, PyObject *arg0)
{
  pn_transport_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint32_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_transport_get_remote_max_frame(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint32_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_transport_get_remote_max_frame _cffi_d_pn_transport_get_remote_max_frame
#endif

static char const * _cffi_d_pn_transport_get_user(pn_transport_t * x0)
{
  return pn_transport_get_user(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_get_user(PyObject *self, PyObject *arg0)
{
  pn_transport_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char const * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_transport_get_user(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(11));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_transport_get_user _cffi_d_pn_transport_get_user
#endif

static _Bool _cffi_d_pn_transport_is_authenticated(pn_transport_t * x0)
{
  return pn_transport_is_authenticated(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_is_authenticated(PyObject *self, PyObject *arg0)
{
  pn_transport_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_transport_is_authenticated(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_transport_is_authenticated _cffi_d_pn_transport_is_authenticated
#endif

static _Bool _cffi_d_pn_transport_is_encrypted(pn_transport_t * x0)
{
  return pn_transport_is_encrypted(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_is_encrypted(PyObject *self, PyObject *arg0)
{
  pn_transport_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  _Bool result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_transport_is_encrypted(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c__Bool(result);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_transport_is_encrypted _cffi_d_pn_transport_is_encrypted
#endif

static void _cffi_d_pn_transport_log(pn_transport_t * x0, char const * x1)
{
  pn_transport_log(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_log(PyObject *self, PyObject *args)
{
  pn_transport_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_transport_log", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_transport_log(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_transport_log _cffi_d_pn_transport_log
#endif

static ssize_t _cffi_d_pn_transport_peek(pn_transport_t * x0, char * x1, size_t x2)
{
  return pn_transport_peek(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_peek(PyObject *self, PyObject *args)
{
  pn_transport_t * x0;
  char * x1;
  size_t x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  ssize_t result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "pn_transport_peek", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(30), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(30), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, size_t);
  if (x2 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_transport_peek(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, ssize_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_transport_peek _cffi_d_pn_transport_peek
#endif

static ssize_t _cffi_d_pn_transport_pending(pn_transport_t * x0)
{
  return pn_transport_pending(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_pending(PyObject *self, PyObject *arg0)
{
  pn_transport_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  ssize_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_transport_pending(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, ssize_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_transport_pending _cffi_d_pn_transport_pending
#endif

static void _cffi_d_pn_transport_pop(pn_transport_t * x0, size_t x1)
{
  pn_transport_pop(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_pop(PyObject *self, PyObject *args)
{
  pn_transport_t * x0;
  size_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_transport_pop", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, size_t);
  if (x1 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_transport_pop(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_transport_pop _cffi_d_pn_transport_pop
#endif

static ssize_t _cffi_d_pn_transport_push(pn_transport_t * x0, char const * x1, size_t x2)
{
  return pn_transport_push(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_push(PyObject *self, PyObject *args)
{
  pn_transport_t * x0;
  char const * x1;
  size_t x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  ssize_t result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "pn_transport_push", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(11), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(11), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, size_t);
  if (x2 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_transport_push(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, ssize_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_transport_push _cffi_d_pn_transport_push
#endif

static uint16_t _cffi_d_pn_transport_remote_channel_max(pn_transport_t * x0)
{
  return pn_transport_remote_channel_max(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_remote_channel_max(PyObject *self, PyObject *arg0)
{
  pn_transport_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  uint16_t result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_transport_remote_channel_max(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, uint16_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_transport_remote_channel_max _cffi_d_pn_transport_remote_channel_max
#endif

static void _cffi_d_pn_transport_require_auth(pn_transport_t * x0, _Bool x1)
{
  pn_transport_require_auth(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_require_auth(PyObject *self, PyObject *args)
{
  pn_transport_t * x0;
  _Bool x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_transport_require_auth", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (_Bool)_cffi_to_c__Bool(arg1);
  if (x1 == (_Bool)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_transport_require_auth(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_transport_require_auth _cffi_d_pn_transport_require_auth
#endif

static void _cffi_d_pn_transport_require_encryption(pn_transport_t * x0, _Bool x1)
{
  pn_transport_require_encryption(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_require_encryption(PyObject *self, PyObject *args)
{
  pn_transport_t * x0;
  _Bool x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_transport_require_encryption", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (_Bool)_cffi_to_c__Bool(arg1);
  if (x1 == (_Bool)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_transport_require_encryption(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_transport_require_encryption _cffi_d_pn_transport_require_encryption
#endif

static int _cffi_d_pn_transport_set_channel_max(pn_transport_t * x0, uint16_t x1)
{
  return pn_transport_set_channel_max(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_set_channel_max(PyObject *self, PyObject *args)
{
  pn_transport_t * x0;
  uint16_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_transport_set_channel_max", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint16_t);
  if (x1 == (uint16_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_transport_set_channel_max(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_transport_set_channel_max _cffi_d_pn_transport_set_channel_max
#endif

static void _cffi_d_pn_transport_set_idle_timeout(pn_transport_t * x0, uint32_t x1)
{
  pn_transport_set_idle_timeout(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_set_idle_timeout(PyObject *self, PyObject *args)
{
  pn_transport_t * x0;
  uint32_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_transport_set_idle_timeout", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint32_t);
  if (x1 == (uint32_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_transport_set_idle_timeout(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_transport_set_idle_timeout _cffi_d_pn_transport_set_idle_timeout
#endif

static void _cffi_d_pn_transport_set_max_frame(pn_transport_t * x0, uint32_t x1)
{
  pn_transport_set_max_frame(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_set_max_frame(PyObject *self, PyObject *args)
{
  pn_transport_t * x0;
  uint32_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_transport_set_max_frame", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint32_t);
  if (x1 == (uint32_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_transport_set_max_frame(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_transport_set_max_frame _cffi_d_pn_transport_set_max_frame
#endif

static void _cffi_d_pn_transport_set_server(pn_transport_t * x0)
{
  pn_transport_set_server(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_set_server(PyObject *self, PyObject *arg0)
{
  pn_transport_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_transport_set_server(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_transport_set_server _cffi_d_pn_transport_set_server
#endif

static void _cffi_d_pn_transport_set_tracer(pn_transport_t * x0, void(* x1)(pn_transport_t *, char const *))
{
  pn_transport_set_tracer(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_set_tracer(PyObject *self, PyObject *args)
{
  pn_transport_t * x0;
  void(* x1)(pn_transport_t *, char const *);
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_transport_set_tracer", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = (void(*)(pn_transport_t *, char const *))_cffi_to_c_pointer(arg1, _cffi_type(747));
  if (x1 == (void(*)(pn_transport_t *, char const *))NULL && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_transport_set_tracer(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_transport_set_tracer _cffi_d_pn_transport_set_tracer
#endif

static int64_t _cffi_d_pn_transport_tick(pn_transport_t * x0, int64_t x1)
{
  return pn_transport_tick(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_tick(PyObject *self, PyObject *args)
{
  pn_transport_t * x0;
  int64_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int64_t result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_transport_tick", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int64_t);
  if (x1 == (int64_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_transport_tick(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int64_t);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_transport_tick _cffi_d_pn_transport_tick
#endif

static void _cffi_d_pn_transport_trace(pn_transport_t * x0, int x1)
{
  pn_transport_trace(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_trace(PyObject *self, PyObject *args)
{
  pn_transport_t * x0;
  int x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "pn_transport_trace", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { pn_transport_trace(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_pn_transport_trace _cffi_d_pn_transport_trace
#endif

static int _cffi_d_pn_transport_unbind(pn_transport_t * x0)
{
  return pn_transport_unbind(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_pn_transport_unbind(PyObject *self, PyObject *arg0)
{
  pn_transport_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(37), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (pn_transport_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(37), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = pn_transport_unbind(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_pn_transport_unbind _cffi_d_pn_transport_unbind
#endif

static int _cffi_const_PN_ACCEPTED(unsigned long long *o)
{
  int n = (PN_ACCEPTED) <= 0;
  *o = (unsigned long long)((PN_ACCEPTED) | 0);  /* check that PN_ACCEPTED is an integer */
  return n;
}

static int _cffi_const_PN_DEFAULT_PRIORITY(unsigned long long *o)
{
  int n = (PN_DEFAULT_PRIORITY) <= 0;
  *o = (unsigned long long)((PN_DEFAULT_PRIORITY) | 0);  /* check that PN_DEFAULT_PRIORITY is an integer */
  return n;
}

static int _cffi_const_PN_EOS(unsigned long long *o)
{
  int n = (PN_EOS) <= 0;
  *o = (unsigned long long)((PN_EOS) | 0);  /* check that PN_EOS is an integer */
  return n;
}

static int _cffi_const_PN_INTR(unsigned long long *o)
{
  int n = (PN_INTR) <= 0;
  *o = (unsigned long long)((PN_INTR) | 0);  /* check that PN_INTR is an integer */
  return n;
}

static int _cffi_const_PN_LOCAL_ACTIVE(unsigned long long *o)
{
  int n = (PN_LOCAL_ACTIVE) <= 0;
  *o = (unsigned long long)((PN_LOCAL_ACTIVE) | 0);  /* check that PN_LOCAL_ACTIVE is an integer */
  return n;
}

static int _cffi_const_PN_LOCAL_CLOSED(unsigned long long *o)
{
  int n = (PN_LOCAL_CLOSED) <= 0;
  *o = (unsigned long long)((PN_LOCAL_CLOSED) | 0);  /* check that PN_LOCAL_CLOSED is an integer */
  return n;
}

static int _cffi_const_PN_LOCAL_UNINIT(unsigned long long *o)
{
  int n = (PN_LOCAL_UNINIT) <= 0;
  *o = (unsigned long long)((PN_LOCAL_UNINIT) | 0);  /* check that PN_LOCAL_UNINIT is an integer */
  return n;
}

static int _cffi_const_PN_MODIFIED(unsigned long long *o)
{
  int n = (PN_MODIFIED) <= 0;
  *o = (unsigned long long)((PN_MODIFIED) | 0);  /* check that PN_MODIFIED is an integer */
  return n;
}

static int _cffi_const_PN_OK(unsigned long long *o)
{
  int n = (PN_OK) <= 0;
  *o = (unsigned long long)((PN_OK) | 0);  /* check that PN_OK is an integer */
  return n;
}

static int _cffi_const_PN_OVERFLOW(unsigned long long *o)
{
  int n = (PN_OVERFLOW) <= 0;
  *o = (unsigned long long)((PN_OVERFLOW) | 0);  /* check that PN_OVERFLOW is an integer */
  return n;
}

static int _cffi_const_PN_RECEIVED(unsigned long long *o)
{
  int n = (PN_RECEIVED) <= 0;
  *o = (unsigned long long)((PN_RECEIVED) | 0);  /* check that PN_RECEIVED is an integer */
  return n;
}

static int _cffi_const_PN_REJECTED(unsigned long long *o)
{
  int n = (PN_REJECTED) <= 0;
  *o = (unsigned long long)((PN_REJECTED) | 0);  /* check that PN_REJECTED is an integer */
  return n;
}

static int _cffi_const_PN_RELEASED(unsigned long long *o)
{
  int n = (PN_RELEASED) <= 0;
  *o = (unsigned long long)((PN_RELEASED) | 0);  /* check that PN_RELEASED is an integer */
  return n;
}

static int _cffi_const_PN_REMOTE_ACTIVE(unsigned long long *o)
{
  int n = (PN_REMOTE_ACTIVE) <= 0;
  *o = (unsigned long long)((PN_REMOTE_ACTIVE) | 0);  /* check that PN_REMOTE_ACTIVE is an integer */
  return n;
}

static int _cffi_const_PN_REMOTE_CLOSED(unsigned long long *o)
{
  int n = (PN_REMOTE_CLOSED) <= 0;
  *o = (unsigned long long)((PN_REMOTE_CLOSED) | 0);  /* check that PN_REMOTE_CLOSED is an integer */
  return n;
}

static int _cffi_const_PN_REMOTE_UNINIT(unsigned long long *o)
{
  int n = (PN_REMOTE_UNINIT) <= 0;
  *o = (unsigned long long)((PN_REMOTE_UNINIT) | 0);  /* check that PN_REMOTE_UNINIT is an integer */
  return n;
}

static int _cffi_const_PN_TIMEOUT(unsigned long long *o)
{
  int n = (PN_TIMEOUT) <= 0;
  *o = (unsigned long long)((PN_TIMEOUT) | 0);  /* check that PN_TIMEOUT is an integer */
  return n;
}

static int _cffi_const_PN_TRACE_DRV(unsigned long long *o)
{
  int n = (PN_TRACE_DRV) <= 0;
  *o = (unsigned long long)((PN_TRACE_DRV) | 0);  /* check that PN_TRACE_DRV is an integer */
  return n;
}

static int _cffi_const_PN_TRACE_FRM(unsigned long long *o)
{
  int n = (PN_TRACE_FRM) <= 0;
  *o = (unsigned long long)((PN_TRACE_FRM) | 0);  /* check that PN_TRACE_FRM is an integer */
  return n;
}

static int _cffi_const_PN_TRACE_OFF(unsigned long long *o)
{
  int n = (PN_TRACE_OFF) <= 0;
  *o = (unsigned long long)((PN_TRACE_OFF) | 0);  /* check that PN_TRACE_OFF is an integer */
  return n;
}

static int _cffi_const_PN_TRACE_RAW(unsigned long long *o)
{
  int n = (PN_TRACE_RAW) <= 0;
  *o = (unsigned long long)((PN_TRACE_RAW) | 0);  /* check that PN_TRACE_RAW is an integer */
  return n;
}

static int _cffi_const_PN_VERSION_MAJOR(unsigned long long *o)
{
  int n = (PN_VERSION_MAJOR) <= 0;
  *o = (unsigned long long)((PN_VERSION_MAJOR) | 0);  /* check that PN_VERSION_MAJOR is an integer */
  return n;
}

static int _cffi_const_PN_VERSION_MINOR(unsigned long long *o)
{
  int n = (PN_VERSION_MINOR) <= 0;
  *o = (unsigned long long)((PN_VERSION_MINOR) | 0);  /* check that PN_VERSION_MINOR is an integer */
  return n;
}

static int _cffi_const_PN_VERSION_POINT(unsigned long long *o)
{
  int n = (PN_VERSION_POINT) <= 0;
  *o = (unsigned long long)((PN_VERSION_POINT) | 0);  /* check that PN_VERSION_POINT is an integer */
  return n;
}

_CFFI_UNUSED_FN
static void _cffi_checkfld__pn_bytes_t(pn_bytes_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->size) | 0);  /* check that 'pn_bytes_t.size' is an integer */
  { char const * *tmp = &p->start; (void)tmp; }
}
struct _cffi_align__pn_bytes_t { char x; pn_bytes_t y; };

static const struct _cffi_global_s _cffi_globals[] = {
  { "PN_ACCEPTED", (void *)_cffi_const_PN_ACCEPTED, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "PN_ARRAY", (void *)_cffi_const_PN_ARRAY, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_BINARY", (void *)_cffi_const_PN_BINARY, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_BOOL", (void *)_cffi_const_PN_BOOL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_BYTE", (void *)_cffi_const_PN_BYTE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_CHAR", (void *)_cffi_const_PN_CHAR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_CONFIGURATION", (void *)_cffi_const_PN_CONFIGURATION, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_CONNECTION_BOUND", (void *)_cffi_const_PN_CONNECTION_BOUND, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_CONNECTION_FINAL", (void *)_cffi_const_PN_CONNECTION_FINAL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_CONNECTION_INIT", (void *)_cffi_const_PN_CONNECTION_INIT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_CONNECTION_LOCAL_CLOSE", (void *)_cffi_const_PN_CONNECTION_LOCAL_CLOSE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_CONNECTION_LOCAL_OPEN", (void *)_cffi_const_PN_CONNECTION_LOCAL_OPEN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_CONNECTION_REMOTE_CLOSE", (void *)_cffi_const_PN_CONNECTION_REMOTE_CLOSE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_CONNECTION_REMOTE_OPEN", (void *)_cffi_const_PN_CONNECTION_REMOTE_OPEN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_CONNECTION_UNBOUND", (void *)_cffi_const_PN_CONNECTION_UNBOUND, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_CONNECTION_WAKE", (void *)_cffi_const_PN_CONNECTION_WAKE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_COORDINATOR", (void *)_cffi_const_PN_COORDINATOR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_DECIMAL128", (void *)_cffi_const_PN_DECIMAL128, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_DECIMAL32", (void *)_cffi_const_PN_DECIMAL32, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_DECIMAL64", (void *)_cffi_const_PN_DECIMAL64, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_DEFAULT_PRIORITY", (void *)_cffi_const_PN_DEFAULT_PRIORITY, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "PN_DELIVERIES", (void *)_cffi_const_PN_DELIVERIES, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_DELIVERY", (void *)_cffi_const_PN_DELIVERY, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_DESCRIBED", (void *)_cffi_const_PN_DESCRIBED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_DIST_MODE_COPY", (void *)_cffi_const_PN_DIST_MODE_COPY, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_DIST_MODE_MOVE", (void *)_cffi_const_PN_DIST_MODE_MOVE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_DIST_MODE_UNSPECIFIED", (void *)_cffi_const_PN_DIST_MODE_UNSPECIFIED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_DOUBLE", (void *)_cffi_const_PN_DOUBLE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_EOS", (void *)_cffi_const_PN_EOS, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "PN_EVENT_NONE", (void *)_cffi_const_PN_EVENT_NONE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_EXPIRE_NEVER", (void *)_cffi_const_PN_EXPIRE_NEVER, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_EXPIRE_WITH_CONNECTION", (void *)_cffi_const_PN_EXPIRE_WITH_CONNECTION, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_EXPIRE_WITH_LINK", (void *)_cffi_const_PN_EXPIRE_WITH_LINK, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_EXPIRE_WITH_SESSION", (void *)_cffi_const_PN_EXPIRE_WITH_SESSION, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_FLOAT", (void *)_cffi_const_PN_FLOAT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_INT", (void *)_cffi_const_PN_INT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_INTR", (void *)_cffi_const_PN_INTR, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "PN_INVALID", (void *)_cffi_const_PN_INVALID, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_LINK_FINAL", (void *)_cffi_const_PN_LINK_FINAL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_LINK_FLOW", (void *)_cffi_const_PN_LINK_FLOW, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_LINK_INIT", (void *)_cffi_const_PN_LINK_INIT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_LINK_LOCAL_CLOSE", (void *)_cffi_const_PN_LINK_LOCAL_CLOSE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_LINK_LOCAL_DETACH", (void *)_cffi_const_PN_LINK_LOCAL_DETACH, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_LINK_LOCAL_OPEN", (void *)_cffi_const_PN_LINK_LOCAL_OPEN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_LINK_REMOTE_CLOSE", (void *)_cffi_const_PN_LINK_REMOTE_CLOSE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_LINK_REMOTE_DETACH", (void *)_cffi_const_PN_LINK_REMOTE_DETACH, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_LINK_REMOTE_OPEN", (void *)_cffi_const_PN_LINK_REMOTE_OPEN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_LIST", (void *)_cffi_const_PN_LIST, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_LISTENER_ACCEPT", (void *)_cffi_const_PN_LISTENER_ACCEPT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_LISTENER_CLOSE", (void *)_cffi_const_PN_LISTENER_CLOSE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_LISTENER_OPEN", (void *)_cffi_const_PN_LISTENER_OPEN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_LOCAL_ACTIVE", (void *)_cffi_const_PN_LOCAL_ACTIVE, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "PN_LOCAL_CLOSED", (void *)_cffi_const_PN_LOCAL_CLOSED, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "PN_LOCAL_UNINIT", (void *)_cffi_const_PN_LOCAL_UNINIT, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "PN_LONG", (void *)_cffi_const_PN_LONG, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_MAP", (void *)_cffi_const_PN_MAP, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_MODIFIED", (void *)_cffi_const_PN_MODIFIED, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "PN_NONDURABLE", (void *)_cffi_const_PN_NONDURABLE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_NULL", (void *)_cffi_const_PN_NULL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_OK", (void *)_cffi_const_PN_OK, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "PN_OVERFLOW", (void *)_cffi_const_PN_OVERFLOW, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "PN_PROACTOR_INACTIVE", (void *)_cffi_const_PN_PROACTOR_INACTIVE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_PROACTOR_INTERRUPT", (void *)_cffi_const_PN_PROACTOR_INTERRUPT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_PROACTOR_TIMEOUT", (void *)_cffi_const_PN_PROACTOR_TIMEOUT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_RAW_CONNECTION_CLOSED_READ", (void *)_cffi_const_PN_RAW_CONNECTION_CLOSED_READ, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_RAW_CONNECTION_CLOSED_WRITE", (void *)_cffi_const_PN_RAW_CONNECTION_CLOSED_WRITE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_RAW_CONNECTION_CONNECTED", (void *)_cffi_const_PN_RAW_CONNECTION_CONNECTED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_RAW_CONNECTION_DISCONNECTED", (void *)_cffi_const_PN_RAW_CONNECTION_DISCONNECTED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_RAW_CONNECTION_DRAIN_BUFFERS", (void *)_cffi_const_PN_RAW_CONNECTION_DRAIN_BUFFERS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_RAW_CONNECTION_NEED_READ_BUFFERS", (void *)_cffi_const_PN_RAW_CONNECTION_NEED_READ_BUFFERS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_RAW_CONNECTION_NEED_WRITE_BUFFERS", (void *)_cffi_const_PN_RAW_CONNECTION_NEED_WRITE_BUFFERS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_RAW_CONNECTION_READ", (void *)_cffi_const_PN_RAW_CONNECTION_READ, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_RAW_CONNECTION_WAKE", (void *)_cffi_const_PN_RAW_CONNECTION_WAKE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_RAW_CONNECTION_WRITTEN", (void *)_cffi_const_PN_RAW_CONNECTION_WRITTEN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_RCV_FIRST", (void *)_cffi_const_PN_RCV_FIRST, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_RCV_SECOND", (void *)_cffi_const_PN_RCV_SECOND, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_REACTOR_FINAL", (void *)_cffi_const_PN_REACTOR_FINAL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_REACTOR_INIT", (void *)_cffi_const_PN_REACTOR_INIT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_REACTOR_QUIESCED", (void *)_cffi_const_PN_REACTOR_QUIESCED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_RECEIVED", (void *)_cffi_const_PN_RECEIVED, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "PN_REJECTED", (void *)_cffi_const_PN_REJECTED, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "PN_RELEASED", (void *)_cffi_const_PN_RELEASED, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "PN_REMOTE_ACTIVE", (void *)_cffi_const_PN_REMOTE_ACTIVE, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "PN_REMOTE_CLOSED", (void *)_cffi_const_PN_REMOTE_CLOSED, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "PN_REMOTE_UNINIT", (void *)_cffi_const_PN_REMOTE_UNINIT, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "PN_SASL_AUTH", (void *)_cffi_const_PN_SASL_AUTH, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SASL_NONE", (void *)_cffi_const_PN_SASL_NONE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SASL_OK", (void *)_cffi_const_PN_SASL_OK, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SASL_PERM", (void *)_cffi_const_PN_SASL_PERM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SASL_SYS", (void *)_cffi_const_PN_SASL_SYS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SASL_TEMP", (void *)_cffi_const_PN_SASL_TEMP, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SELECTABLE_ERROR", (void *)_cffi_const_PN_SELECTABLE_ERROR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SELECTABLE_EXPIRED", (void *)_cffi_const_PN_SELECTABLE_EXPIRED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SELECTABLE_FINAL", (void *)_cffi_const_PN_SELECTABLE_FINAL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SELECTABLE_INIT", (void *)_cffi_const_PN_SELECTABLE_INIT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SELECTABLE_READABLE", (void *)_cffi_const_PN_SELECTABLE_READABLE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SELECTABLE_UPDATED", (void *)_cffi_const_PN_SELECTABLE_UPDATED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SELECTABLE_WRITABLE", (void *)_cffi_const_PN_SELECTABLE_WRITABLE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SESSION_FINAL", (void *)_cffi_const_PN_SESSION_FINAL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SESSION_INIT", (void *)_cffi_const_PN_SESSION_INIT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SESSION_LOCAL_CLOSE", (void *)_cffi_const_PN_SESSION_LOCAL_CLOSE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SESSION_LOCAL_OPEN", (void *)_cffi_const_PN_SESSION_LOCAL_OPEN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SESSION_REMOTE_CLOSE", (void *)_cffi_const_PN_SESSION_REMOTE_CLOSE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SESSION_REMOTE_OPEN", (void *)_cffi_const_PN_SESSION_REMOTE_OPEN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SHORT", (void *)_cffi_const_PN_SHORT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SND_MIXED", (void *)_cffi_const_PN_SND_MIXED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SND_SETTLED", (void *)_cffi_const_PN_SND_SETTLED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SND_UNSETTLED", (void *)_cffi_const_PN_SND_UNSETTLED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SOURCE", (void *)_cffi_const_PN_SOURCE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SSL_ANONYMOUS_PEER", (void *)_cffi_const_PN_SSL_ANONYMOUS_PEER, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SSL_CERT_SUBJECT_CITY_OR_LOCALITY", (void *)_cffi_const_PN_SSL_CERT_SUBJECT_CITY_OR_LOCALITY, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SSL_CERT_SUBJECT_COMMON_NAME", (void *)_cffi_const_PN_SSL_CERT_SUBJECT_COMMON_NAME, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SSL_CERT_SUBJECT_COUNTRY_NAME", (void *)_cffi_const_PN_SSL_CERT_SUBJECT_COUNTRY_NAME, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SSL_CERT_SUBJECT_ORGANIZATION_NAME", (void *)_cffi_const_PN_SSL_CERT_SUBJECT_ORGANIZATION_NAME, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SSL_CERT_SUBJECT_ORGANIZATION_UNIT", (void *)_cffi_const_PN_SSL_CERT_SUBJECT_ORGANIZATION_UNIT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SSL_CERT_SUBJECT_STATE_OR_PROVINCE", (void *)_cffi_const_PN_SSL_CERT_SUBJECT_STATE_OR_PROVINCE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SSL_MD5", (void *)_cffi_const_PN_SSL_MD5, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SSL_MODE_CLIENT", (void *)_cffi_const_PN_SSL_MODE_CLIENT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SSL_MODE_SERVER", (void *)_cffi_const_PN_SSL_MODE_SERVER, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SSL_RESUME_NEW", (void *)_cffi_const_PN_SSL_RESUME_NEW, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SSL_RESUME_REUSED", (void *)_cffi_const_PN_SSL_RESUME_REUSED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SSL_RESUME_UNKNOWN", (void *)_cffi_const_PN_SSL_RESUME_UNKNOWN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SSL_SHA1", (void *)_cffi_const_PN_SSL_SHA1, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SSL_SHA256", (void *)_cffi_const_PN_SSL_SHA256, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SSL_SHA512", (void *)_cffi_const_PN_SSL_SHA512, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SSL_VERIFY_NULL", (void *)_cffi_const_PN_SSL_VERIFY_NULL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SSL_VERIFY_PEER", (void *)_cffi_const_PN_SSL_VERIFY_PEER, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SSL_VERIFY_PEER_NAME", (void *)_cffi_const_PN_SSL_VERIFY_PEER_NAME, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_STRING", (void *)_cffi_const_PN_STRING, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_SYMBOL", (void *)_cffi_const_PN_SYMBOL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_TARGET", (void *)_cffi_const_PN_TARGET, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_TIMEOUT", (void *)_cffi_const_PN_TIMEOUT, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "PN_TIMER_TASK", (void *)_cffi_const_PN_TIMER_TASK, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_TIMESTAMP", (void *)_cffi_const_PN_TIMESTAMP, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_TRACE_DRV", (void *)_cffi_const_PN_TRACE_DRV, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "PN_TRACE_FRM", (void *)_cffi_const_PN_TRACE_FRM, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "PN_TRACE_OFF", (void *)_cffi_const_PN_TRACE_OFF, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "PN_TRACE_RAW", (void *)_cffi_const_PN_TRACE_RAW, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "PN_TRANSPORT", (void *)_cffi_const_PN_TRANSPORT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_TRANSPORT_AUTHENTICATED", (void *)_cffi_const_PN_TRANSPORT_AUTHENTICATED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_TRANSPORT_CLOSED", (void *)_cffi_const_PN_TRANSPORT_CLOSED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_TRANSPORT_ERROR", (void *)_cffi_const_PN_TRANSPORT_ERROR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_TRANSPORT_HEAD_CLOSED", (void *)_cffi_const_PN_TRANSPORT_HEAD_CLOSED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_TRANSPORT_TAIL_CLOSED", (void *)_cffi_const_PN_TRANSPORT_TAIL_CLOSED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_UBYTE", (void *)_cffi_const_PN_UBYTE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_UINT", (void *)_cffi_const_PN_UINT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_ULONG", (void *)_cffi_const_PN_ULONG, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_UNSPECIFIED", (void *)_cffi_const_PN_UNSPECIFIED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_USHORT", (void *)_cffi_const_PN_USHORT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_UUID", (void *)_cffi_const_PN_UUID, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PN_VERSION_MAJOR", (void *)_cffi_const_PN_VERSION_MAJOR, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "PN_VERSION_MINOR", (void *)_cffi_const_PN_VERSION_MINOR, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "PN_VERSION_POINT", (void *)_cffi_const_PN_VERSION_POINT, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "free", (void *)_cffi_f_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 749), (void *)_cffi_d_free },
  { "init", (void *)_cffi_f_init, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 752), (void *)_cffi_d_init },
  { "pn_cast_pn_connection", (void *)_cffi_f_pn_cast_pn_connection, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 345), (void *)_cffi_d_pn_cast_pn_connection },
  { "pn_cast_pn_delivery", (void *)_cffi_f_pn_cast_pn_delivery, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 384), (void *)_cffi_d_pn_cast_pn_delivery },
  { "pn_cast_pn_link", (void *)_cffi_f_pn_cast_pn_link, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 443), (void *)_cffi_d_pn_cast_pn_link },
  { "pn_cast_pn_session", (void *)_cffi_f_pn_cast_pn_session, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 489), (void *)_cffi_d_pn_cast_pn_session },
  { "pn_cast_pn_transport", (void *)_cffi_f_pn_cast_pn_transport, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 516), (void *)_cffi_d_pn_cast_pn_transport },
  { "pn_collector", (void *)_cffi_f_pn_collector, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 319), (void *)_cffi_d_pn_collector },
  { "pn_collector_free", (void *)_cffi_f_pn_collector_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 628), (void *)_cffi_d_pn_collector_free },
  { "pn_collector_more", (void *)_cffi_f_pn_collector_more, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 0), (void *)_cffi_d_pn_collector_more },
  { "pn_collector_peek", (void *)_cffi_f_pn_collector_peek, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 411), (void *)_cffi_d_pn_collector_peek },
  { "pn_collector_pop", (void *)_cffi_f_pn_collector_pop, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 0), (void *)_cffi_d_pn_collector_pop },
  { "pn_collector_put_py", (void *)_cffi_f_pn_collector_put_py, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 414), (void *)_cffi_d_pn_collector_put_py },
  { "pn_collector_release", (void *)_cffi_f_pn_collector_release, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 628), (void *)_cffi_d_pn_collector_release },
  { "pn_condition_clear", (void *)_cffi_f_pn_condition_clear, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 631), (void *)_cffi_d_pn_condition_clear },
  { "pn_condition_get_description", (void *)_cffi_f_pn_condition_get_description, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 44), (void *)_cffi_d_pn_condition_get_description },
  { "pn_condition_get_name", (void *)_cffi_f_pn_condition_get_name, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 44), (void *)_cffi_d_pn_condition_get_name },
  { "pn_condition_info", (void *)_cffi_f_pn_condition_info, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 350), (void *)_cffi_d_pn_condition_info },
  { "pn_condition_is_set", (void *)_cffi_f_pn_condition_is_set, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 3), (void *)_cffi_d_pn_condition_is_set },
  { "pn_condition_set_description", (void *)_cffi_f_pn_condition_set_description, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 87), (void *)_cffi_d_pn_condition_set_description },
  { "pn_condition_set_name", (void *)_cffi_f_pn_condition_set_name, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 87), (void *)_cffi_d_pn_condition_set_name },
  { "pn_connection", (void *)_cffi_f_pn_connection, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 348), (void *)_cffi_d_pn_connection },
  { "pn_connection_attachments", (void *)_cffi_f_pn_connection_attachments, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 451), (void *)_cffi_d_pn_connection_attachments },
  { "pn_connection_close", (void *)_cffi_f_pn_connection_close, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 634), (void *)_cffi_d_pn_connection_close },
  { "pn_connection_collect", (void *)_cffi_f_pn_connection_collect, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 641), (void *)_cffi_d_pn_connection_collect },
  { "pn_connection_condition", (void *)_cffi_f_pn_connection_condition, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 321), (void *)_cffi_d_pn_connection_condition },
  { "pn_connection_desired_capabilities", (void *)_cffi_f_pn_connection_desired_capabilities, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 353), (void *)_cffi_d_pn_connection_desired_capabilities },
  { "pn_connection_error", (void *)_cffi_f_pn_connection_error, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 396), (void *)_cffi_d_pn_connection_error },
  { "pn_connection_get_authorization", (void *)_cffi_f_pn_connection_get_authorization, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 47), (void *)_cffi_d_pn_connection_get_authorization },
  { "pn_connection_get_container", (void *)_cffi_f_pn_connection_get_container, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 47), (void *)_cffi_d_pn_connection_get_container },
  { "pn_connection_get_hostname", (void *)_cffi_f_pn_connection_get_hostname, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 47), (void *)_cffi_d_pn_connection_get_hostname },
  { "pn_connection_get_user", (void *)_cffi_f_pn_connection_get_user, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 47), (void *)_cffi_d_pn_connection_get_user },
  { "pn_connection_offered_capabilities", (void *)_cffi_f_pn_connection_offered_capabilities, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 353), (void *)_cffi_d_pn_connection_offered_capabilities },
  { "pn_connection_open", (void *)_cffi_f_pn_connection_open, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 634), (void *)_cffi_d_pn_connection_open },
  { "pn_connection_properties", (void *)_cffi_f_pn_connection_properties, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 353), (void *)_cffi_d_pn_connection_properties },
  { "pn_connection_release", (void *)_cffi_f_pn_connection_release, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 634), (void *)_cffi_d_pn_connection_release },
  { "pn_connection_remote_condition", (void *)_cffi_f_pn_connection_remote_condition, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 321), (void *)_cffi_d_pn_connection_remote_condition },
  { "pn_connection_remote_container", (void *)_cffi_f_pn_connection_remote_container, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 47), (void *)_cffi_d_pn_connection_remote_container },
  { "pn_connection_remote_desired_capabilities", (void *)_cffi_f_pn_connection_remote_desired_capabilities, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 353), (void *)_cffi_d_pn_connection_remote_desired_capabilities },
  { "pn_connection_remote_hostname", (void *)_cffi_f_pn_connection_remote_hostname, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 47), (void *)_cffi_d_pn_connection_remote_hostname },
  { "pn_connection_remote_offered_capabilities", (void *)_cffi_f_pn_connection_remote_offered_capabilities, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 353), (void *)_cffi_d_pn_connection_remote_offered_capabilities },
  { "pn_connection_remote_properties", (void *)_cffi_f_pn_connection_remote_properties, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 353), (void *)_cffi_d_pn_connection_remote_properties },
  { "pn_connection_set_authorization", (void *)_cffi_f_pn_connection_set_authorization, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 637), (void *)_cffi_d_pn_connection_set_authorization },
  { "pn_connection_set_container", (void *)_cffi_f_pn_connection_set_container, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 637), (void *)_cffi_d_pn_connection_set_container },
  { "pn_connection_set_hostname", (void *)_cffi_f_pn_connection_set_hostname, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 637), (void *)_cffi_d_pn_connection_set_hostname },
  { "pn_connection_set_password", (void *)_cffi_f_pn_connection_set_password, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 637), (void *)_cffi_d_pn_connection_set_password },
  { "pn_connection_set_user", (void *)_cffi_f_pn_connection_set_user, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 637), (void *)_cffi_d_pn_connection_set_user },
  { "pn_connection_state", (void *)_cffi_f_pn_connection_state, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 91), (void *)_cffi_d_pn_connection_state },
  { "pn_connection_transport", (void *)_cffi_f_pn_connection_transport, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 510), (void *)_cffi_d_pn_connection_transport },
  { "pn_data", (void *)_cffi_f_pn_data, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 368), (void *)_cffi_d_pn_data },
  { "pn_data_clear", (void *)_cffi_f_pn_data_clear, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 645), (void *)_cffi_d_pn_data_clear },
  { "pn_data_copy", (void *)_cffi_f_pn_data_copy, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 134), (void *)_cffi_d_pn_data_copy },
  { "pn_data_decode", (void *)_cffi_f_pn_data_decode, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 544), (void *)_cffi_d_pn_data_decode },
  { "pn_data_dump", (void *)_cffi_f_pn_data_dump, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 645), (void *)_cffi_d_pn_data_dump },
  { "pn_data_encode", (void *)_cffi_f_pn_data_encode, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 539), (void *)_cffi_d_pn_data_encode },
  { "pn_data_encoded_size", (void *)_cffi_f_pn_data_encoded_size, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 536), (void *)_cffi_d_pn_data_encoded_size },
  { "pn_data_enter", (void *)_cffi_f_pn_data_enter, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 6), (void *)_cffi_d_pn_data_enter },
  { "pn_data_error", (void *)_cffi_f_pn_data_error, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 399), (void *)_cffi_d_pn_data_error },
  { "pn_data_exit", (void *)_cffi_f_pn_data_exit, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 6), (void *)_cffi_d_pn_data_exit },
  { "pn_data_format_py", (void *)_cffi_f_pn_data_format_py, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 539), (void *)_cffi_d_pn_data_format_py },
  { "pn_data_free", (void *)_cffi_f_pn_data_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 645), (void *)_cffi_d_pn_data_free },
  { "pn_data_get_array", (void *)_cffi_f_pn_data_get_array, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 527), (void *)_cffi_d_pn_data_get_array },
  { "pn_data_get_array_type", (void *)_cffi_f_pn_data_get_array_type, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 521), (void *)_cffi_d_pn_data_get_array_type },
  { "pn_data_get_binary", (void *)_cffi_f_pn_data_get_binary, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 310), (void *)_cffi_d_pn_data_get_binary },
  { "pn_data_get_bool", (void *)_cffi_f_pn_data_get_bool, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 6), (void *)_cffi_d_pn_data_get_bool },
  { "pn_data_get_byte", (void *)_cffi_f_pn_data_get_byte, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 304), (void *)_cffi_d_pn_data_get_byte },
  { "pn_data_get_char", (void *)_cffi_f_pn_data_get_char, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 583), (void *)_cffi_d_pn_data_get_char },
  { "pn_data_get_decimal128", (void *)_cffi_f_pn_data_get_decimal128, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 371), (void *)_cffi_d_pn_data_get_decimal128 },
  { "pn_data_get_decimal32", (void *)_cffi_f_pn_data_get_decimal32, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 583), (void *)_cffi_d_pn_data_get_decimal32 },
  { "pn_data_get_decimal64", (void *)_cffi_f_pn_data_get_decimal64, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 598), (void *)_cffi_d_pn_data_get_decimal64 },
  { "pn_data_get_double", (void *)_cffi_f_pn_data_get_double, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 81), (void *)_cffi_d_pn_data_get_double },
  { "pn_data_get_float", (void *)_cffi_f_pn_data_get_float, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 84), (void *)_cffi_d_pn_data_get_float },
  { "pn_data_get_int", (void *)_cffi_f_pn_data_get_int, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 291), (void *)_cffi_d_pn_data_get_int },
  { "pn_data_get_list", (void *)_cffi_f_pn_data_get_list, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 527), (void *)_cffi_d_pn_data_get_list },
  { "pn_data_get_long", (void *)_cffi_f_pn_data_get_long, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 294), (void *)_cffi_d_pn_data_get_long },
  { "pn_data_get_map", (void *)_cffi_f_pn_data_get_map, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 527), (void *)_cffi_d_pn_data_get_map },
  { "pn_data_get_short", (void *)_cffi_f_pn_data_get_short, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 288), (void *)_cffi_d_pn_data_get_short },
  { "pn_data_get_string", (void *)_cffi_f_pn_data_get_string, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 310), (void *)_cffi_d_pn_data_get_string },
  { "pn_data_get_symbol", (void *)_cffi_f_pn_data_get_symbol, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 310), (void *)_cffi_d_pn_data_get_symbol },
  { "pn_data_get_timestamp", (void *)_cffi_f_pn_data_get_timestamp, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 294), (void *)_cffi_d_pn_data_get_timestamp },
  { "pn_data_get_ubyte", (void *)_cffi_f_pn_data_get_ubyte, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 613), (void *)_cffi_d_pn_data_get_ubyte },
  { "pn_data_get_uint", (void *)_cffi_f_pn_data_get_uint, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 583), (void *)_cffi_d_pn_data_get_uint },
  { "pn_data_get_ulong", (void *)_cffi_f_pn_data_get_ulong, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 598), (void *)_cffi_d_pn_data_get_ulong },
  { "pn_data_get_ushort", (void *)_cffi_f_pn_data_get_ushort, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 577), (void *)_cffi_d_pn_data_get_ushort },
  { "pn_data_get_uuid", (void *)_cffi_f_pn_data_get_uuid, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 524), (void *)_cffi_d_pn_data_get_uuid },
  { "pn_data_is_array_described", (void *)_cffi_f_pn_data_is_array_described, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 6), (void *)_cffi_d_pn_data_is_array_described },
  { "pn_data_is_described", (void *)_cffi_f_pn_data_is_described, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 6), (void *)_cffi_d_pn_data_is_described },
  { "pn_data_is_null", (void *)_cffi_f_pn_data_is_null, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 6), (void *)_cffi_d_pn_data_is_null },
  { "pn_data_lookup", (void *)_cffi_f_pn_data_lookup, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 9), (void *)_cffi_d_pn_data_lookup },
  { "pn_data_narrow", (void *)_cffi_f_pn_data_narrow, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 645), (void *)_cffi_d_pn_data_narrow },
  { "pn_data_next", (void *)_cffi_f_pn_data_next, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 6), (void *)_cffi_d_pn_data_next },
  { "pn_data_prev", (void *)_cffi_f_pn_data_prev, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 6), (void *)_cffi_d_pn_data_prev },
  { "pn_data_put_array", (void *)_cffi_f_pn_data_put_array, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 101), (void *)_cffi_d_pn_data_put_array },
  { "pn_data_put_binary", (void *)_cffi_f_pn_data_put_binary, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 130), (void *)_cffi_d_pn_data_put_binary },
  { "pn_data_put_bool", (void *)_cffi_f_pn_data_put_bool, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 97), (void *)_cffi_d_pn_data_put_bool },
  { "pn_data_put_byte", (void *)_cffi_f_pn_data_put_byte, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 126), (void *)_cffi_d_pn_data_put_byte },
  { "pn_data_put_char", (void *)_cffi_f_pn_data_put_char, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 150), (void *)_cffi_d_pn_data_put_char },
  { "pn_data_put_decimal128", (void *)_cffi_f_pn_data_put_decimal128, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 138), (void *)_cffi_d_pn_data_put_decimal128 },
  { "pn_data_put_decimal32", (void *)_cffi_f_pn_data_put_decimal32, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 150), (void *)_cffi_d_pn_data_put_decimal32 },
  { "pn_data_put_decimal64", (void *)_cffi_f_pn_data_put_decimal64, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 154), (void *)_cffi_d_pn_data_put_decimal64 },
  { "pn_data_put_described", (void *)_cffi_f_pn_data_put_described, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 94), (void *)_cffi_d_pn_data_put_described },
  { "pn_data_put_double", (void *)_cffi_f_pn_data_put_double, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 106), (void *)_cffi_d_pn_data_put_double },
  { "pn_data_put_float", (void *)_cffi_f_pn_data_put_float, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 110), (void *)_cffi_d_pn_data_put_float },
  { "pn_data_put_int", (void *)_cffi_f_pn_data_put_int, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 118), (void *)_cffi_d_pn_data_put_int },
  { "pn_data_put_list", (void *)_cffi_f_pn_data_put_list, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 94), (void *)_cffi_d_pn_data_put_list },
  { "pn_data_put_long", (void *)_cffi_f_pn_data_put_long, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 122), (void *)_cffi_d_pn_data_put_long },
  { "pn_data_put_map", (void *)_cffi_f_pn_data_put_map, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 94), (void *)_cffi_d_pn_data_put_map },
  { "pn_data_put_null", (void *)_cffi_f_pn_data_put_null, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 94), (void *)_cffi_d_pn_data_put_null },
  { "pn_data_put_short", (void *)_cffi_f_pn_data_put_short, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 114), (void *)_cffi_d_pn_data_put_short },
  { "pn_data_put_string", (void *)_cffi_f_pn_data_put_string, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 130), (void *)_cffi_d_pn_data_put_string },
  { "pn_data_put_symbol", (void *)_cffi_f_pn_data_put_symbol, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 130), (void *)_cffi_d_pn_data_put_symbol },
  { "pn_data_put_timestamp", (void *)_cffi_f_pn_data_put_timestamp, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 122), (void *)_cffi_d_pn_data_put_timestamp },
  { "pn_data_put_ubyte", (void *)_cffi_f_pn_data_put_ubyte, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 158), (void *)_cffi_d_pn_data_put_ubyte },
  { "pn_data_put_uint", (void *)_cffi_f_pn_data_put_uint, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 150), (void *)_cffi_d_pn_data_put_uint },
  { "pn_data_put_ulong", (void *)_cffi_f_pn_data_put_ulong, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 154), (void *)_cffi_d_pn_data_put_ulong },
  { "pn_data_put_ushort", (void *)_cffi_f_pn_data_put_ushort, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 146), (void *)_cffi_d_pn_data_put_ushort },
  { "pn_data_put_uuid", (void *)_cffi_f_pn_data_put_uuid, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 142), (void *)_cffi_d_pn_data_put_uuid },
  { "pn_data_rewind", (void *)_cffi_f_pn_data_rewind, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 645), (void *)_cffi_d_pn_data_rewind },
  { "pn_data_type", (void *)_cffi_f_pn_data_type, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 521), (void *)_cffi_d_pn_data_type },
  { "pn_data_widen", (void *)_cffi_f_pn_data_widen, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 645), (void *)_cffi_d_pn_data_widen },
  { "pn_decref", (void *)_cffi_f_pn_decref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 285), (void *)_cffi_d_pn_decref },
  { "pn_delivery", (void *)_cffi_f_pn_delivery, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 380), (void *)_cffi_d_pn_delivery },
  { "pn_delivery_abort", (void *)_cffi_f_pn_delivery_abort, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 648), (void *)_cffi_d_pn_delivery_abort },
  { "pn_delivery_aborted", (void *)_cffi_f_pn_delivery_aborted, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 13), (void *)_cffi_d_pn_delivery_aborted },
  { "pn_delivery_attachments", (void *)_cffi_f_pn_delivery_attachments, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 454), (void *)_cffi_d_pn_delivery_attachments },
  { "pn_delivery_link", (void *)_cffi_f_pn_delivery_link, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 429), (void *)_cffi_d_pn_delivery_link },
  { "pn_delivery_local", (void *)_cffi_f_pn_delivery_local, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 387), (void *)_cffi_d_pn_delivery_local },
  { "pn_delivery_local_state", (void *)_cffi_f_pn_delivery_local_state, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 601), (void *)_cffi_d_pn_delivery_local_state },
  { "pn_delivery_partial", (void *)_cffi_f_pn_delivery_partial, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 13), (void *)_cffi_d_pn_delivery_partial },
  { "pn_delivery_pending", (void *)_cffi_f_pn_delivery_pending, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 530), (void *)_cffi_d_pn_delivery_pending },
  { "pn_delivery_readable", (void *)_cffi_f_pn_delivery_readable, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 13), (void *)_cffi_d_pn_delivery_readable },
  { "pn_delivery_remote", (void *)_cffi_f_pn_delivery_remote, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 387), (void *)_cffi_d_pn_delivery_remote },
  { "pn_delivery_remote_state", (void *)_cffi_f_pn_delivery_remote_state, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 601), (void *)_cffi_d_pn_delivery_remote_state },
  { "pn_delivery_settle", (void *)_cffi_f_pn_delivery_settle, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 648), (void *)_cffi_d_pn_delivery_settle },
  { "pn_delivery_settled", (void *)_cffi_f_pn_delivery_settled, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 13), (void *)_cffi_d_pn_delivery_settled },
  { "pn_delivery_tag", (void *)_cffi_f_pn_delivery_tag, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 313), (void *)_cffi_d_pn_delivery_tag },
  { "pn_delivery_update", (void *)_cffi_f_pn_delivery_update, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 651), (void *)_cffi_d_pn_delivery_update },
  { "pn_delivery_updated", (void *)_cffi_f_pn_delivery_updated, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 13), (void *)_cffi_d_pn_delivery_updated },
  { "pn_delivery_writable", (void *)_cffi_f_pn_delivery_writable, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 13), (void *)_cffi_d_pn_delivery_writable },
  { "pn_disposition_annotations", (void *)_cffi_f_pn_disposition_annotations, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 356), (void *)_cffi_d_pn_disposition_annotations },
  { "pn_disposition_condition", (void *)_cffi_f_pn_disposition_condition, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 324), (void *)_cffi_d_pn_disposition_condition },
  { "pn_disposition_data", (void *)_cffi_f_pn_disposition_data, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 356), (void *)_cffi_d_pn_disposition_data },
  { "pn_disposition_get_section_number", (void *)_cffi_f_pn_disposition_get_section_number, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 586), (void *)_cffi_d_pn_disposition_get_section_number },
  { "pn_disposition_get_section_offset", (void *)_cffi_f_pn_disposition_get_section_offset, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 604), (void *)_cffi_d_pn_disposition_get_section_offset },
  { "pn_disposition_is_failed", (void *)_cffi_f_pn_disposition_is_failed, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 16), (void *)_cffi_d_pn_disposition_is_failed },
  { "pn_disposition_is_undeliverable", (void *)_cffi_f_pn_disposition_is_undeliverable, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 16), (void *)_cffi_d_pn_disposition_is_undeliverable },
  { "pn_disposition_set_failed", (void *)_cffi_f_pn_disposition_set_failed, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 655), (void *)_cffi_d_pn_disposition_set_failed },
  { "pn_disposition_set_section_number", (void *)_cffi_f_pn_disposition_set_section_number, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 659), (void *)_cffi_d_pn_disposition_set_section_number },
  { "pn_disposition_set_section_offset", (void *)_cffi_f_pn_disposition_set_section_offset, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 663), (void *)_cffi_d_pn_disposition_set_section_offset },
  { "pn_disposition_set_undeliverable", (void *)_cffi_f_pn_disposition_set_undeliverable, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 655), (void *)_cffi_d_pn_disposition_set_undeliverable },
  { "pn_disposition_type", (void *)_cffi_f_pn_disposition_type, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 604), (void *)_cffi_d_pn_disposition_type },
  { "pn_error_code", (void *)_cffi_f_pn_error_code, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 162), (void *)_cffi_d_pn_error_code },
  { "pn_error_text", (void *)_cffi_f_pn_error_text, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 50), (void *)_cffi_d_pn_error_text },
  { "pn_event_class_name_py", (void *)_cffi_f_pn_event_class_name_py, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 53), (void *)_cffi_d_pn_event_class_name_py },
  { "pn_event_connection", (void *)_cffi_f_pn_event_connection, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 336), (void *)_cffi_d_pn_event_connection },
  { "pn_event_context", (void *)_cffi_f_pn_event_context, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 619), (void *)_cffi_d_pn_event_context },
  { "pn_event_delivery", (void *)_cffi_f_pn_event_delivery, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 374), (void *)_cffi_d_pn_event_delivery },
  { "pn_event_link", (void *)_cffi_f_pn_event_link, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 432), (void *)_cffi_d_pn_event_link },
  { "pn_event_session", (void *)_cffi_f_pn_event_session, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 479), (void *)_cffi_d_pn_event_session },
  { "pn_event_transport", (void *)_cffi_f_pn_event_transport, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 513), (void *)_cffi_d_pn_event_transport },
  { "pn_event_type", (void *)_cffi_f_pn_event_type, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 419), (void *)_cffi_d_pn_event_type },
  { "pn_event_type_name", (void *)_cffi_f_pn_event_type_name, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 56), (void *)_cffi_d_pn_event_type_name },
  { "pn_incref", (void *)_cffi_f_pn_incref, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 625), (void *)_cffi_d_pn_incref },
  { "pn_link_advance", (void *)_cffi_f_pn_link_advance, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 19), (void *)_cffi_d_pn_link_advance },
  { "pn_link_attachments", (void *)_cffi_f_pn_link_attachments, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 457), (void *)_cffi_d_pn_link_attachments },
  { "pn_link_available", (void *)_cffi_f_pn_link_available, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 165), (void *)_cffi_d_pn_link_available },
  { "pn_link_close", (void *)_cffi_f_pn_link_close, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 667), (void *)_cffi_d_pn_link_close },
  { "pn_link_condition", (void *)_cffi_f_pn_link_condition, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 327), (void *)_cffi_d_pn_link_condition },
  { "pn_link_credit", (void *)_cffi_f_pn_link_credit, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 165), (void *)_cffi_d_pn_link_credit },
  { "pn_link_current", (void *)_cffi_f_pn_link_current, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 377), (void *)_cffi_d_pn_link_current },
  { "pn_link_detach", (void *)_cffi_f_pn_link_detach, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 667), (void *)_cffi_d_pn_link_detach },
  { "pn_link_drain", (void *)_cffi_f_pn_link_drain, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 674), (void *)_cffi_d_pn_link_drain },
  { "pn_link_drained", (void *)_cffi_f_pn_link_drained, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 165), (void *)_cffi_d_pn_link_drained },
  { "pn_link_draining", (void *)_cffi_f_pn_link_draining, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 19), (void *)_cffi_d_pn_link_draining },
  { "pn_link_error", (void *)_cffi_f_pn_link_error, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 402), (void *)_cffi_d_pn_link_error },
  { "pn_link_flow", (void *)_cffi_f_pn_link_flow, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 674), (void *)_cffi_d_pn_link_flow },
  { "pn_link_free", (void *)_cffi_f_pn_link_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 667), (void *)_cffi_d_pn_link_free },
  { "pn_link_get_drain", (void *)_cffi_f_pn_link_get_drain, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 19), (void *)_cffi_d_pn_link_get_drain },
  { "pn_link_head", (void *)_cffi_f_pn_link_head, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 425), (void *)_cffi_d_pn_link_head },
  { "pn_link_is_receiver", (void *)_cffi_f_pn_link_is_receiver, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 19), (void *)_cffi_d_pn_link_is_receiver },
  { "pn_link_is_sender", (void *)_cffi_f_pn_link_is_sender, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 19), (void *)_cffi_d_pn_link_is_sender },
  { "pn_link_max_message_size", (void *)_cffi_f_pn_link_max_message_size, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 607), (void *)_cffi_d_pn_link_max_message_size },
  { "pn_link_name", (void *)_cffi_f_pn_link_name, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 59), (void *)_cffi_d_pn_link_name },
  { "pn_link_next", (void *)_cffi_f_pn_link_next, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 435), (void *)_cffi_d_pn_link_next },
  { "pn_link_offered", (void *)_cffi_f_pn_link_offered, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 674), (void *)_cffi_d_pn_link_offered },
  { "pn_link_open", (void *)_cffi_f_pn_link_open, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 667), (void *)_cffi_d_pn_link_open },
  { "pn_link_properties", (void *)_cffi_f_pn_link_properties, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 359), (void *)_cffi_d_pn_link_properties },
  { "pn_link_queued", (void *)_cffi_f_pn_link_queued, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 165), (void *)_cffi_d_pn_link_queued },
  { "pn_link_rcv_settle_mode", (void *)_cffi_f_pn_link_rcv_settle_mode, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 448), (void *)_cffi_d_pn_link_rcv_settle_mode },
  { "pn_link_recv", (void *)_cffi_f_pn_link_recv, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 549), (void *)_cffi_d_pn_link_recv },
  { "pn_link_remote_condition", (void *)_cffi_f_pn_link_remote_condition, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 327), (void *)_cffi_d_pn_link_remote_condition },
  { "pn_link_remote_max_message_size", (void *)_cffi_f_pn_link_remote_max_message_size, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 607), (void *)_cffi_d_pn_link_remote_max_message_size },
  { "pn_link_remote_properties", (void *)_cffi_f_pn_link_remote_properties, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 359), (void *)_cffi_d_pn_link_remote_properties },
  { "pn_link_remote_rcv_settle_mode", (void *)_cffi_f_pn_link_remote_rcv_settle_mode, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 448), (void *)_cffi_d_pn_link_remote_rcv_settle_mode },
  { "pn_link_remote_snd_settle_mode", (void *)_cffi_f_pn_link_remote_snd_settle_mode, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 492), (void *)_cffi_d_pn_link_remote_snd_settle_mode },
  { "pn_link_remote_source", (void *)_cffi_f_pn_link_remote_source, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 504), (void *)_cffi_d_pn_link_remote_source },
  { "pn_link_remote_target", (void *)_cffi_f_pn_link_remote_target, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 504), (void *)_cffi_d_pn_link_remote_target },
  { "pn_link_send", (void *)_cffi_f_pn_link_send, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 554), (void *)_cffi_d_pn_link_send },
  { "pn_link_session", (void *)_cffi_f_pn_link_session, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 482), (void *)_cffi_d_pn_link_session },
  { "pn_link_set_drain", (void *)_cffi_f_pn_link_set_drain, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 670), (void *)_cffi_d_pn_link_set_drain },
  { "pn_link_set_max_message_size", (void *)_cffi_f_pn_link_set_max_message_size, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 686), (void *)_cffi_d_pn_link_set_max_message_size },
  { "pn_link_set_rcv_settle_mode", (void *)_cffi_f_pn_link_set_rcv_settle_mode, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 678), (void *)_cffi_d_pn_link_set_rcv_settle_mode },
  { "pn_link_set_snd_settle_mode", (void *)_cffi_f_pn_link_set_snd_settle_mode, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 682), (void *)_cffi_d_pn_link_set_snd_settle_mode },
  { "pn_link_snd_settle_mode", (void *)_cffi_f_pn_link_snd_settle_mode, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 492), (void *)_cffi_d_pn_link_snd_settle_mode },
  { "pn_link_source", (void *)_cffi_f_pn_link_source, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 504), (void *)_cffi_d_pn_link_source },
  { "pn_link_state", (void *)_cffi_f_pn_link_state, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 165), (void *)_cffi_d_pn_link_state },
  { "pn_link_target", (void *)_cffi_f_pn_link_target, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 504), (void *)_cffi_d_pn_link_target },
  { "pn_link_unsettled", (void *)_cffi_f_pn_link_unsettled, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 165), (void *)_cffi_d_pn_link_unsettled },
  { "pn_message", (void *)_cffi_f_pn_message, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 446), (void *)_cffi_d_pn_message },
  { "pn_message_annotations", (void *)_cffi_f_pn_message_annotations, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 362), (void *)_cffi_d_pn_message_annotations },
  { "pn_message_body", (void *)_cffi_f_pn_message_body, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 362), (void *)_cffi_d_pn_message_body },
  { "pn_message_clear", (void *)_cffi_f_pn_message_clear, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 690), (void *)_cffi_d_pn_message_clear },
  { "pn_message_decode", (void *)_cffi_f_pn_message_decode, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 176), (void *)_cffi_d_pn_message_decode },
  { "pn_message_encode_py", (void *)_cffi_f_pn_message_encode_py, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 559), (void *)_cffi_d_pn_message_encode_py },
  { "pn_message_error", (void *)_cffi_f_pn_message_error, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 405), (void *)_cffi_d_pn_message_error },
  { "pn_message_free", (void *)_cffi_f_pn_message_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 690), (void *)_cffi_d_pn_message_free },
  { "pn_message_get_address", (void *)_cffi_f_pn_message_get_address, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 62), (void *)_cffi_d_pn_message_get_address },
  { "pn_message_get_content_encoding", (void *)_cffi_f_pn_message_get_content_encoding, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 62), (void *)_cffi_d_pn_message_get_content_encoding },
  { "pn_message_get_content_type", (void *)_cffi_f_pn_message_get_content_type, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 62), (void *)_cffi_d_pn_message_get_content_type },
  { "pn_message_get_correlation_id", (void *)_cffi_f_pn_message_get_correlation_id, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 307), (void *)_cffi_d_pn_message_get_correlation_id },
  { "pn_message_get_creation_time", (void *)_cffi_f_pn_message_get_creation_time, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 297), (void *)_cffi_d_pn_message_get_creation_time },
  { "pn_message_get_delivery_count", (void *)_cffi_f_pn_message_get_delivery_count, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 589), (void *)_cffi_d_pn_message_get_delivery_count },
  { "pn_message_get_expiry_time", (void *)_cffi_f_pn_message_get_expiry_time, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 297), (void *)_cffi_d_pn_message_get_expiry_time },
  { "pn_message_get_group_id", (void *)_cffi_f_pn_message_get_group_id, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 62), (void *)_cffi_d_pn_message_get_group_id },
  { "pn_message_get_group_sequence", (void *)_cffi_f_pn_message_get_group_sequence, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 589), (void *)_cffi_d_pn_message_get_group_sequence },
  { "pn_message_get_id", (void *)_cffi_f_pn_message_get_id, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 307), (void *)_cffi_d_pn_message_get_id },
  { "pn_message_get_priority", (void *)_cffi_f_pn_message_get_priority, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 616), (void *)_cffi_d_pn_message_get_priority },
  { "pn_message_get_reply_to", (void *)_cffi_f_pn_message_get_reply_to, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 62), (void *)_cffi_d_pn_message_get_reply_to },
  { "pn_message_get_reply_to_group_id", (void *)_cffi_f_pn_message_get_reply_to_group_id, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 62), (void *)_cffi_d_pn_message_get_reply_to_group_id },
  { "pn_message_get_subject", (void *)_cffi_f_pn_message_get_subject, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 62), (void *)_cffi_d_pn_message_get_subject },
  { "pn_message_get_ttl", (void *)_cffi_f_pn_message_get_ttl, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 589), (void *)_cffi_d_pn_message_get_ttl },
  { "pn_message_get_user_id", (void *)_cffi_f_pn_message_get_user_id, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 316), (void *)_cffi_d_pn_message_get_user_id },
  { "pn_message_instructions", (void *)_cffi_f_pn_message_instructions, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 362), (void *)_cffi_d_pn_message_instructions },
  { "pn_message_is_durable", (void *)_cffi_f_pn_message_is_durable, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 22), (void *)_cffi_d_pn_message_is_durable },
  { "pn_message_is_first_acquirer", (void *)_cffi_f_pn_message_is_first_acquirer, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 22), (void *)_cffi_d_pn_message_is_first_acquirer },
  { "pn_message_is_inferred", (void *)_cffi_f_pn_message_is_inferred, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 22), (void *)_cffi_d_pn_message_is_inferred },
  { "pn_message_properties", (void *)_cffi_f_pn_message_properties, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 362), (void *)_cffi_d_pn_message_properties },
  { "pn_message_set_address", (void *)_cffi_f_pn_message_set_address, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 172), (void *)_cffi_d_pn_message_set_address },
  { "pn_message_set_content_encoding", (void *)_cffi_f_pn_message_set_content_encoding, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 172), (void *)_cffi_d_pn_message_set_content_encoding },
  { "pn_message_set_content_type", (void *)_cffi_f_pn_message_set_content_type, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 172), (void *)_cffi_d_pn_message_set_content_type },
  { "pn_message_set_correlation_id", (void *)_cffi_f_pn_message_set_correlation_id, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 185), (void *)_cffi_d_pn_message_set_correlation_id },
  { "pn_message_set_creation_time", (void *)_cffi_f_pn_message_set_creation_time, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 181), (void *)_cffi_d_pn_message_set_creation_time },
  { "pn_message_set_delivery_count", (void *)_cffi_f_pn_message_set_delivery_count, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 193), (void *)_cffi_d_pn_message_set_delivery_count },
  { "pn_message_set_durable", (void *)_cffi_f_pn_message_set_durable, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 168), (void *)_cffi_d_pn_message_set_durable },
  { "pn_message_set_expiry_time", (void *)_cffi_f_pn_message_set_expiry_time, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 181), (void *)_cffi_d_pn_message_set_expiry_time },
  { "pn_message_set_first_acquirer", (void *)_cffi_f_pn_message_set_first_acquirer, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 168), (void *)_cffi_d_pn_message_set_first_acquirer },
  { "pn_message_set_group_id", (void *)_cffi_f_pn_message_set_group_id, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 172), (void *)_cffi_d_pn_message_set_group_id },
  { "pn_message_set_group_sequence", (void *)_cffi_f_pn_message_set_group_sequence, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 193), (void *)_cffi_d_pn_message_set_group_sequence },
  { "pn_message_set_id", (void *)_cffi_f_pn_message_set_id, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 185), (void *)_cffi_d_pn_message_set_id },
  { "pn_message_set_inferred", (void *)_cffi_f_pn_message_set_inferred, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 168), (void *)_cffi_d_pn_message_set_inferred },
  { "pn_message_set_priority", (void *)_cffi_f_pn_message_set_priority, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 197), (void *)_cffi_d_pn_message_set_priority },
  { "pn_message_set_reply_to", (void *)_cffi_f_pn_message_set_reply_to, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 172), (void *)_cffi_d_pn_message_set_reply_to },
  { "pn_message_set_reply_to_group_id", (void *)_cffi_f_pn_message_set_reply_to_group_id, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 172), (void *)_cffi_d_pn_message_set_reply_to_group_id },
  { "pn_message_set_subject", (void *)_cffi_f_pn_message_set_subject, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 172), (void *)_cffi_d_pn_message_set_subject },
  { "pn_message_set_ttl", (void *)_cffi_f_pn_message_set_ttl, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 193), (void *)_cffi_d_pn_message_set_ttl },
  { "pn_message_set_user_id", (void *)_cffi_f_pn_message_set_user_id, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 189), (void *)_cffi_d_pn_message_set_user_id },
  { "pn_pyref_decref", (void *)&_cffi_externpy__pn_pyref_decref, _CFFI_OP(_CFFI_OP_EXTERN_PYTHON, 777), (void *)pn_pyref_decref },
  { "pn_pyref_incref", (void *)&_cffi_externpy__pn_pyref_incref, _CFFI_OP(_CFFI_OP_EXTERN_PYTHON, 777), (void *)pn_pyref_incref },
  { "pn_pytracer", (void *)&_cffi_externpy__pn_pytracer, _CFFI_OP(_CFFI_OP_EXTERN_PYTHON, 747), (void *)pn_pytracer },
  { "pn_receiver", (void *)_cffi_f_pn_receiver, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 439), (void *)_cffi_d_pn_receiver },
  { "pn_record_def_py", (void *)_cffi_f_pn_record_def_py, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 693), (void *)_cffi_d_pn_record_def_py },
  { "pn_record_get_py", (void *)_cffi_f_pn_record_get_py, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 622), (void *)_cffi_d_pn_record_get_py },
  { "pn_record_set_py", (void *)_cffi_f_pn_record_set_py, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 696), (void *)_cffi_d_pn_record_set_py },
  { "pn_sasl", (void *)_cffi_f_pn_sasl, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 469), (void *)_cffi_d_pn_sasl },
  { "pn_sasl_allowed_mechs", (void *)_cffi_f_pn_sasl_allowed_mechs, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 704), (void *)_cffi_d_pn_sasl_allowed_mechs },
  { "pn_sasl_config_name", (void *)_cffi_f_pn_sasl_config_name, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 704), (void *)_cffi_d_pn_sasl_config_name },
  { "pn_sasl_config_path", (void *)_cffi_f_pn_sasl_config_path, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 704), (void *)_cffi_d_pn_sasl_config_path },
  { "pn_sasl_done", (void *)_cffi_f_pn_sasl_done, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 708), (void *)_cffi_d_pn_sasl_done },
  { "pn_sasl_extended", (void *)_cffi_f_pn_sasl_extended, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 39), (void *)_cffi_d_pn_sasl_extended },
  { "pn_sasl_get_allow_insecure_mechs", (void *)_cffi_f_pn_sasl_get_allow_insecure_mechs, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 25), (void *)_cffi_d_pn_sasl_get_allow_insecure_mechs },
  { "pn_sasl_get_authorization", (void *)_cffi_f_pn_sasl_get_authorization, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 65), (void *)_cffi_d_pn_sasl_get_authorization },
  { "pn_sasl_get_mech", (void *)_cffi_f_pn_sasl_get_mech, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 65), (void *)_cffi_d_pn_sasl_get_mech },
  { "pn_sasl_get_user", (void *)_cffi_f_pn_sasl_get_user, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 65), (void *)_cffi_d_pn_sasl_get_user },
  { "pn_sasl_outcome", (void *)_cffi_f_pn_sasl_outcome, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 466), (void *)_cffi_d_pn_sasl_outcome },
  { "pn_sasl_set_allow_insecure_mechs", (void *)_cffi_f_pn_sasl_set_allow_insecure_mechs, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 700), (void *)_cffi_d_pn_sasl_set_allow_insecure_mechs },
  { "pn_sender", (void *)_cffi_f_pn_sender, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 439), (void *)_cffi_d_pn_sender },
  { "pn_session", (void *)_cffi_f_pn_session, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 472), (void *)_cffi_d_pn_session },
  { "pn_session_attachments", (void *)_cffi_f_pn_session_attachments, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 460), (void *)_cffi_d_pn_session_attachments },
  { "pn_session_close", (void *)_cffi_f_pn_session_close, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 712), (void *)_cffi_d_pn_session_close },
  { "pn_session_condition", (void *)_cffi_f_pn_session_condition, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 330), (void *)_cffi_d_pn_session_condition },
  { "pn_session_connection", (void *)_cffi_f_pn_session_connection, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 339), (void *)_cffi_d_pn_session_connection },
  { "pn_session_free", (void *)_cffi_f_pn_session_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 712), (void *)_cffi_d_pn_session_free },
  { "pn_session_get_incoming_capacity", (void *)_cffi_f_pn_session_get_incoming_capacity, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 533), (void *)_cffi_d_pn_session_get_incoming_capacity },
  { "pn_session_get_outgoing_window", (void *)_cffi_f_pn_session_get_outgoing_window, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 533), (void *)_cffi_d_pn_session_get_outgoing_window },
  { "pn_session_head", (void *)_cffi_f_pn_session_head, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 475), (void *)_cffi_d_pn_session_head },
  { "pn_session_incoming_bytes", (void *)_cffi_f_pn_session_incoming_bytes, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 533), (void *)_cffi_d_pn_session_incoming_bytes },
  { "pn_session_next", (void *)_cffi_f_pn_session_next, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 485), (void *)_cffi_d_pn_session_next },
  { "pn_session_open", (void *)_cffi_f_pn_session_open, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 712), (void *)_cffi_d_pn_session_open },
  { "pn_session_outgoing_bytes", (void *)_cffi_f_pn_session_outgoing_bytes, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 533), (void *)_cffi_d_pn_session_outgoing_bytes },
  { "pn_session_remote_condition", (void *)_cffi_f_pn_session_remote_condition, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 330), (void *)_cffi_d_pn_session_remote_condition },
  { "pn_session_set_incoming_capacity", (void *)_cffi_f_pn_session_set_incoming_capacity, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 715), (void *)_cffi_d_pn_session_set_incoming_capacity },
  { "pn_session_set_outgoing_window", (void *)_cffi_f_pn_session_set_outgoing_window, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 715), (void *)_cffi_d_pn_session_set_outgoing_window },
  { "pn_session_state", (void *)_cffi_f_pn_session_state, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 201), (void *)_cffi_d_pn_session_state },
  { "pn_ssl", (void *)_cffi_f_pn_ssl, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 501), (void *)_cffi_d_pn_ssl },
  { "pn_ssl_domain", (void *)_cffi_f_pn_ssl_domain, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 495), (void *)_cffi_d_pn_ssl_domain },
  { "pn_ssl_domain_allow_unsecured_client", (void *)_cffi_f_pn_ssl_domain_allow_unsecured_client, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 204), (void *)_cffi_d_pn_ssl_domain_allow_unsecured_client },
  { "pn_ssl_domain_free", (void *)_cffi_f_pn_ssl_domain_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 719), (void *)_cffi_d_pn_ssl_domain_free },
  { "pn_ssl_domain_set_ciphers", (void *)_cffi_f_pn_ssl_domain_set_ciphers, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 207), (void *)_cffi_d_pn_ssl_domain_set_ciphers },
  { "pn_ssl_domain_set_credentials", (void *)_cffi_f_pn_ssl_domain_set_credentials, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 211), (void *)_cffi_d_pn_ssl_domain_set_credentials },
  { "pn_ssl_domain_set_peer_authentication", (void *)_cffi_f_pn_ssl_domain_set_peer_authentication, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 217), (void *)_cffi_d_pn_ssl_domain_set_peer_authentication },
  { "pn_ssl_domain_set_protocols", (void *)_cffi_f_pn_ssl_domain_set_protocols, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 207), (void *)_cffi_d_pn_ssl_domain_set_protocols },
  { "pn_ssl_domain_set_trusted_ca_db", (void *)_cffi_f_pn_ssl_domain_set_trusted_ca_db, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 207), (void *)_cffi_d_pn_ssl_domain_set_trusted_ca_db },
  { "pn_ssl_get_cert_fingerprint", (void *)_cffi_f_pn_ssl_get_cert_fingerprint, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 227), (void *)_cffi_d_pn_ssl_get_cert_fingerprint },
  { "pn_ssl_get_cipher_name", (void *)_cffi_f_pn_ssl_get_cipher_name, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 28), (void *)_cffi_d_pn_ssl_get_cipher_name },
  { "pn_ssl_get_peer_hostname_py", (void *)_cffi_f_pn_ssl_get_peer_hostname_py, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 222), (void *)_cffi_d_pn_ssl_get_peer_hostname_py },
  { "pn_ssl_get_protocol_name", (void *)_cffi_f_pn_ssl_get_protocol_name, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 28), (void *)_cffi_d_pn_ssl_get_protocol_name },
  { "pn_ssl_get_remote_subject", (void *)_cffi_f_pn_ssl_get_remote_subject, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 68), (void *)_cffi_d_pn_ssl_get_remote_subject },
  { "pn_ssl_get_remote_subject_subfield", (void *)_cffi_f_pn_ssl_get_remote_subject_subfield, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 71), (void *)_cffi_d_pn_ssl_get_remote_subject_subfield },
  { "pn_ssl_init", (void *)_cffi_f_pn_ssl_init, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 237), (void *)_cffi_d_pn_ssl_init },
  { "pn_ssl_present", (void *)_cffi_f_pn_ssl_present, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 39), (void *)_cffi_d_pn_ssl_present },
  { "pn_ssl_resume_status", (void *)_cffi_f_pn_ssl_resume_status, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 498), (void *)_cffi_d_pn_ssl_resume_status },
  { "pn_ssl_set_peer_hostname", (void *)_cffi_f_pn_ssl_set_peer_hostname, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 233), (void *)_cffi_d_pn_ssl_set_peer_hostname },
  { "pn_terminus_capabilities", (void *)_cffi_f_pn_terminus_capabilities, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 365), (void *)_cffi_d_pn_terminus_capabilities },
  { "pn_terminus_copy", (void *)_cffi_f_pn_terminus_copy, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 262), (void *)_cffi_d_pn_terminus_copy },
  { "pn_terminus_filter", (void *)_cffi_f_pn_terminus_filter, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 365), (void *)_cffi_d_pn_terminus_filter },
  { "pn_terminus_get_address", (void *)_cffi_f_pn_terminus_get_address, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 75), (void *)_cffi_d_pn_terminus_get_address },
  { "pn_terminus_get_distribution_mode", (void *)_cffi_f_pn_terminus_get_distribution_mode, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 390), (void *)_cffi_d_pn_terminus_get_distribution_mode },
  { "pn_terminus_get_durability", (void *)_cffi_f_pn_terminus_get_durability, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 393), (void *)_cffi_d_pn_terminus_get_durability },
  { "pn_terminus_get_expiry_policy", (void *)_cffi_f_pn_terminus_get_expiry_policy, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 422), (void *)_cffi_d_pn_terminus_get_expiry_policy },
  { "pn_terminus_get_timeout", (void *)_cffi_f_pn_terminus_get_timeout, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 592), (void *)_cffi_d_pn_terminus_get_timeout },
  { "pn_terminus_get_type", (void *)_cffi_f_pn_terminus_get_type, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 507), (void *)_cffi_d_pn_terminus_get_type },
  { "pn_terminus_is_dynamic", (void *)_cffi_f_pn_terminus_is_dynamic, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 33), (void *)_cffi_d_pn_terminus_is_dynamic },
  { "pn_terminus_outcomes", (void *)_cffi_f_pn_terminus_outcomes, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 365), (void *)_cffi_d_pn_terminus_outcomes },
  { "pn_terminus_properties", (void *)_cffi_f_pn_terminus_properties, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 365), (void *)_cffi_d_pn_terminus_properties },
  { "pn_terminus_set_address", (void *)_cffi_f_pn_terminus_set_address, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 246), (void *)_cffi_d_pn_terminus_set_address },
  { "pn_terminus_set_distribution_mode", (void *)_cffi_f_pn_terminus_set_distribution_mode, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 250), (void *)_cffi_d_pn_terminus_set_distribution_mode },
  { "pn_terminus_set_durability", (void *)_cffi_f_pn_terminus_set_durability, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 254), (void *)_cffi_d_pn_terminus_set_durability },
  { "pn_terminus_set_dynamic", (void *)_cffi_f_pn_terminus_set_dynamic, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 242), (void *)_cffi_d_pn_terminus_set_dynamic },
  { "pn_terminus_set_expiry_policy", (void *)_cffi_f_pn_terminus_set_expiry_policy, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 258), (void *)_cffi_d_pn_terminus_set_expiry_policy },
  { "pn_terminus_set_timeout", (void *)_cffi_f_pn_terminus_set_timeout, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 270), (void *)_cffi_d_pn_terminus_set_timeout },
  { "pn_terminus_set_type", (void *)_cffi_f_pn_terminus_set_type, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 266), (void *)_cffi_d_pn_terminus_set_type },
  { "pn_tostring", (void *)_cffi_f_pn_tostring, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 41), (void *)_cffi_d_pn_tostring },
  { "pn_transport", (void *)_cffi_f_pn_transport, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 519), (void *)_cffi_d_pn_transport },
  { "pn_transport_attachments", (void *)_cffi_f_pn_transport_attachments, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 463), (void *)_cffi_d_pn_transport_attachments },
  { "pn_transport_bind", (void *)_cffi_f_pn_transport_bind, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 277), (void *)_cffi_d_pn_transport_bind },
  { "pn_transport_capacity", (void *)_cffi_f_pn_transport_capacity, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 564), (void *)_cffi_d_pn_transport_capacity },
  { "pn_transport_close_head", (void *)_cffi_f_pn_transport_close_head, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 274), (void *)_cffi_d_pn_transport_close_head },
  { "pn_transport_close_tail", (void *)_cffi_f_pn_transport_close_tail, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 274), (void *)_cffi_d_pn_transport_close_tail },
  { "pn_transport_closed", (void *)_cffi_f_pn_transport_closed, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 36), (void *)_cffi_d_pn_transport_closed },
  { "pn_transport_condition", (void *)_cffi_f_pn_transport_condition, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 333), (void *)_cffi_d_pn_transport_condition },
  { "pn_transport_connection", (void *)_cffi_f_pn_transport_connection, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 342), (void *)_cffi_d_pn_transport_connection },
  { "pn_transport_error", (void *)_cffi_f_pn_transport_error, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 408), (void *)_cffi_d_pn_transport_error },
  { "pn_transport_get_channel_max", (void *)_cffi_f_pn_transport_get_channel_max, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 580), (void *)_cffi_d_pn_transport_get_channel_max },
  { "pn_transport_get_frames_input", (void *)_cffi_f_pn_transport_get_frames_input, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 610), (void *)_cffi_d_pn_transport_get_frames_input },
  { "pn_transport_get_frames_output", (void *)_cffi_f_pn_transport_get_frames_output, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 610), (void *)_cffi_d_pn_transport_get_frames_output },
  { "pn_transport_get_idle_timeout", (void *)_cffi_f_pn_transport_get_idle_timeout, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 595), (void *)_cffi_d_pn_transport_get_idle_timeout },
  { "pn_transport_get_max_frame", (void *)_cffi_f_pn_transport_get_max_frame, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 595), (void *)_cffi_d_pn_transport_get_max_frame },
  { "pn_transport_get_remote_idle_timeout", (void *)_cffi_f_pn_transport_get_remote_idle_timeout, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 595), (void *)_cffi_d_pn_transport_get_remote_idle_timeout },
  { "pn_transport_get_remote_max_frame", (void *)_cffi_f_pn_transport_get_remote_max_frame, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 595), (void *)_cffi_d_pn_transport_get_remote_max_frame },
  { "pn_transport_get_user", (void *)_cffi_f_pn_transport_get_user, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 78), (void *)_cffi_d_pn_transport_get_user },
  { "pn_transport_is_authenticated", (void *)_cffi_f_pn_transport_is_authenticated, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 36), (void *)_cffi_d_pn_transport_is_authenticated },
  { "pn_transport_is_encrypted", (void *)_cffi_f_pn_transport_is_encrypted, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 36), (void *)_cffi_d_pn_transport_is_encrypted },
  { "pn_transport_log", (void *)_cffi_f_pn_transport_log, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 729), (void *)_cffi_d_pn_transport_log },
  { "pn_transport_peek", (void *)_cffi_f_pn_transport_peek, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 567), (void *)_cffi_d_pn_transport_peek },
  { "pn_transport_pending", (void *)_cffi_f_pn_transport_pending, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 564), (void *)_cffi_d_pn_transport_pending },
  { "pn_transport_pop", (void *)_cffi_f_pn_transport_pop, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 737), (void *)_cffi_d_pn_transport_pop },
  { "pn_transport_push", (void *)_cffi_f_pn_transport_push, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 572), (void *)_cffi_d_pn_transport_push },
  { "pn_transport_remote_channel_max", (void *)_cffi_f_pn_transport_remote_channel_max, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 580), (void *)_cffi_d_pn_transport_remote_channel_max },
  { "pn_transport_require_auth", (void *)_cffi_f_pn_transport_require_auth, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 725), (void *)_cffi_d_pn_transport_require_auth },
  { "pn_transport_require_encryption", (void *)_cffi_f_pn_transport_require_encryption, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 725), (void *)_cffi_d_pn_transport_require_encryption },
  { "pn_transport_set_channel_max", (void *)_cffi_f_pn_transport_set_channel_max, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 281), (void *)_cffi_d_pn_transport_set_channel_max },
  { "pn_transport_set_idle_timeout", (void *)_cffi_f_pn_transport_set_idle_timeout, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 741), (void *)_cffi_d_pn_transport_set_idle_timeout },
  { "pn_transport_set_max_frame", (void *)_cffi_f_pn_transport_set_max_frame, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 741), (void *)_cffi_d_pn_transport_set_max_frame },
  { "pn_transport_set_server", (void *)_cffi_f_pn_transport_set_server, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 722), (void *)_cffi_d_pn_transport_set_server },
  { "pn_transport_set_tracer", (void *)_cffi_f_pn_transport_set_tracer, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 745), (void *)_cffi_d_pn_transport_set_tracer },
  { "pn_transport_tick", (void *)_cffi_f_pn_transport_tick, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 300), (void *)_cffi_d_pn_transport_tick },
  { "pn_transport_trace", (void *)_cffi_f_pn_transport_trace, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 733), (void *)_cffi_d_pn_transport_trace },
  { "pn_transport_unbind", (void *)_cffi_f_pn_transport_unbind, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 274), (void *)_cffi_d_pn_transport_unbind },
};

static const struct _cffi_field_s _cffi_fields[] = {
  { "type", offsetof(pn_atom_t, type),
            sizeof(((pn_atom_t *)0)->type),
            _CFFI_OP(_CFFI_OP_NOOP, 104) },
  { "u", offsetof(pn_atom_t, u),
         sizeof(((pn_atom_t *)0)->u),
         _CFFI_OP(_CFFI_OP_NOOP, 776) },
  { "bytes", offsetof(pn_decimal128_t, bytes),
             sizeof(((pn_decimal128_t *)0)->bytes),
             _CFFI_OP(_CFFI_OP_NOOP, 755) },
  { "bytes", offsetof(pn_uuid_t, bytes),
             sizeof(((pn_uuid_t *)0)->bytes),
             _CFFI_OP(_CFFI_OP_NOOP, 755) },
  { "size", offsetof(pn_bytes_t, size),
            sizeof(((pn_bytes_t *)0)->size),
            _CFFI_OP(_CFFI_OP_NOOP, 31) },
  { "start", offsetof(pn_bytes_t, start),
             sizeof(((pn_bytes_t *)0)->start),
             _CFFI_OP(_CFFI_OP_NOOP, 11) },
  { "as_bool", (size_t)-1,
               (size_t)-1,
               _CFFI_OP(_CFFI_OP_NOOP, 99) },
  { "as_ubyte", (size_t)-1,
                (size_t)-1,
                _CFFI_OP(_CFFI_OP_NOOP, 160) },
  { "as_byte", (size_t)-1,
               (size_t)-1,
               _CFFI_OP(_CFFI_OP_NOOP, 128) },
  { "as_ushort", (size_t)-1,
                 (size_t)-1,
                 _CFFI_OP(_CFFI_OP_NOOP, 148) },
  { "as_short", (size_t)-1,
                (size_t)-1,
                _CFFI_OP(_CFFI_OP_NOOP, 116) },
  { "as_uint", (size_t)-1,
               (size_t)-1,
               _CFFI_OP(_CFFI_OP_NOOP, 152) },
  { "as_int", (size_t)-1,
              (size_t)-1,
              _CFFI_OP(_CFFI_OP_NOOP, 120) },
  { "as_char", (size_t)-1,
               (size_t)-1,
               _CFFI_OP(_CFFI_OP_NOOP, 152) },
  { "as_ulong", (size_t)-1,
                (size_t)-1,
                _CFFI_OP(_CFFI_OP_NOOP, 156) },
  { "as_long", (size_t)-1,
               (size_t)-1,
               _CFFI_OP(_CFFI_OP_NOOP, 124) },
  { "as_timestamp", (size_t)-1,
                    (size_t)-1,
                    _CFFI_OP(_CFFI_OP_NOOP, 124) },
  { "as_float", (size_t)-1,
                (size_t)-1,
                _CFFI_OP(_CFFI_OP_NOOP, 112) },
  { "as_double", (size_t)-1,
                 (size_t)-1,
                 _CFFI_OP(_CFFI_OP_NOOP, 108) },
  { "as_decimal32", (size_t)-1,
                    (size_t)-1,
                    _CFFI_OP(_CFFI_OP_NOOP, 152) },
  { "as_decimal64", (size_t)-1,
                    (size_t)-1,
                    _CFFI_OP(_CFFI_OP_NOOP, 156) },
  { "as_decimal128", (size_t)-1,
                     (size_t)-1,
                     _CFFI_OP(_CFFI_OP_NOOP, 140) },
  { "as_uuid", (size_t)-1,
               (size_t)-1,
               _CFFI_OP(_CFFI_OP_NOOP, 144) },
  { "as_bytes", (size_t)-1,
                (size_t)-1,
                _CFFI_OP(_CFFI_OP_NOOP, 132) },
};

static const struct _cffi_struct_union_s _cffi_struct_unions[] = {
  { "$1", 776, _CFFI_F_UNION|_CFFI_F_CHECK_FIELDS,
    (size_t)-2, -2, 6, 18 /* unnamed */ },
  { "$pn_atom_t", 187, _CFFI_F_CHECK_FIELDS,
    sizeof(pn_atom_t), offsetof(struct _cffi_align_typedef_pn_atom_t, y), 0, 2 },
  { "$pn_decimal128_t", 140, _CFFI_F_CHECK_FIELDS,
    sizeof(pn_decimal128_t), offsetof(struct _cffi_align_typedef_pn_decimal128_t, y), 2, 1 },
  { "$pn_uuid_t", 144, _CFFI_F_CHECK_FIELDS,
    sizeof(pn_uuid_t), offsetof(struct _cffi_align_typedef_pn_uuid_t, y), 3, 1 },
  { "pn_bytes_t", 132, _CFFI_F_CHECK_FIELDS,
    sizeof(pn_bytes_t), offsetof(struct _cffi_align__pn_bytes_t, y), 4, 2 },
  { "pn_collector_t", 757, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "pn_condition_t", 758, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "pn_connection_t", 759, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "pn_data_t", 760, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "pn_delivery_t", 761, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "pn_disposition_t", 762, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "pn_error_t", 763, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "pn_event_t", 764, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "pn_link_t", 765, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "pn_message_t", 766, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "pn_record_t", 767, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "pn_sasl_t", 768, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "pn_session_t", 769, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "pn_ssl_domain_t", 770, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "pn_ssl_t", 772, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "pn_terminus_t", 773, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "pn_transport_t", 774, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
};

static const struct _cffi_enum_s _cffi_enums[] = {
  { "$pn_distribution_mode_t", 252, _cffi_prim_int(sizeof(pn_distribution_mode_t), ((pn_distribution_mode_t)-1) <= 0),
    "PN_DIST_MODE_UNSPECIFIED,PN_DIST_MODE_COPY,PN_DIST_MODE_MOVE" },
  { "$pn_durability_t", 256, _cffi_prim_int(sizeof(pn_durability_t), ((pn_durability_t)-1) <= 0),
    "PN_NONDURABLE,PN_CONFIGURATION,PN_DELIVERIES" },
  { "$pn_event_type_t", 57, _cffi_prim_int(sizeof(pn_event_type_t), ((pn_event_type_t)-1) <= 0),
    "PN_EVENT_NONE,PN_REACTOR_INIT,PN_REACTOR_QUIESCED,PN_REACTOR_FINAL,PN_TIMER_TASK,PN_CONNECTION_INIT,PN_CONNECTION_BOUND,PN_CONNECTION_UNBOUND,PN_CONNECTION_LOCAL_OPEN,PN_CONNECTION_REMOTE_OPEN,PN_CONNECTION_LOCAL_CLOSE,PN_CONNECTION_REMOTE_CLOSE,PN_CONNECTION_FINAL,PN_SESSION_INIT,PN_SESSION_LOCAL_OPEN,PN_SESSION_REMOTE_OPEN,PN_SESSION_LOCAL_CLOSE,PN_SESSION_REMOTE_CLOSE,PN_SESSION_FINAL,PN_LINK_INIT,PN_LINK_LOCAL_OPEN,PN_LINK_REMOTE_OPEN,PN_LINK_LOCAL_CLOSE,PN_LINK_REMOTE_CLOSE,PN_LINK_LOCAL_DETACH,PN_LINK_REMOTE_DETACH,PN_LINK_FLOW,PN_LINK_FINAL,PN_DELIVERY,PN_TRANSPORT,PN_TRANSPORT_AUTHENTICATED,PN_TRANSPORT_ERROR,PN_TRANSPORT_HEAD_CLOSED,PN_TRANSPORT_TAIL_CLOSED,PN_TRANSPORT_CLOSED,PN_SELECTABLE_INIT,PN_SELECTABLE_UPDATED,PN_SELECTABLE_READABLE,PN_SELECTABLE_WRITABLE,PN_SELECTABLE_ERROR,PN_SELECTABLE_EXPIRED,PN_SELECTABLE_FINAL,PN_CONNECTION_WAKE,PN_LISTENER_ACCEPT,PN_LISTENER_CLOSE,PN_PROACTOR_INTERRUPT,PN_PROACTOR_TIMEOUT,PN_PROACTOR_INACTIVE,PN_LISTENER_OPEN,PN_RAW_CONNECTION_CONNECTED,PN_RAW_CONNECTION_CLOSED_READ,PN_RAW_CONNECTION_CLOSED_WRITE,PN_RAW_CONNECTION_DISCONNECTED,PN_RAW_CONNECTION_NEED_READ_BUFFERS,PN_RAW_CONNECTION_NEED_WRITE_BUFFERS,PN_RAW_CONNECTION_READ,PN_RAW_CONNECTION_WRITTEN,PN_RAW_CONNECTION_WAKE,PN_RAW_CONNECTION_DRAIN_BUFFERS" },
  { "$pn_expiry_policy_t", 260, _cffi_prim_int(sizeof(pn_expiry_policy_t), ((pn_expiry_policy_t)-1) <= 0),
    "PN_EXPIRE_WITH_LINK,PN_EXPIRE_WITH_SESSION,PN_EXPIRE_WITH_CONNECTION,PN_EXPIRE_NEVER" },
  { "$pn_rcv_settle_mode_t", 680, _cffi_prim_int(sizeof(pn_rcv_settle_mode_t), ((pn_rcv_settle_mode_t)-1) <= 0),
    "PN_RCV_FIRST,PN_RCV_SECOND" },
  { "$pn_sasl_outcome_t", 710, _cffi_prim_int(sizeof(pn_sasl_outcome_t), ((pn_sasl_outcome_t)-1) <= 0),
    "PN_SASL_NONE,PN_SASL_OK,PN_SASL_AUTH,PN_SASL_SYS,PN_SASL_PERM,PN_SASL_TEMP" },
  { "$pn_snd_settle_mode_t", 684, _cffi_prim_int(sizeof(pn_snd_settle_mode_t), ((pn_snd_settle_mode_t)-1) <= 0),
    "PN_SND_UNSETTLED,PN_SND_SETTLED,PN_SND_MIXED" },
  { "$pn_ssl_cert_subject_subfield", 73, _cffi_prim_int(sizeof(pn_ssl_cert_subject_subfield), ((pn_ssl_cert_subject_subfield)-1) <= 0),
    "PN_SSL_CERT_SUBJECT_COUNTRY_NAME,PN_SSL_CERT_SUBJECT_STATE_OR_PROVINCE,PN_SSL_CERT_SUBJECT_CITY_OR_LOCALITY,PN_SSL_CERT_SUBJECT_ORGANIZATION_NAME,PN_SSL_CERT_SUBJECT_ORGANIZATION_UNIT,PN_SSL_CERT_SUBJECT_COMMON_NAME" },
  { "$pn_ssl_hash_alg", 231, _cffi_prim_int(sizeof(pn_ssl_hash_alg), ((pn_ssl_hash_alg)-1) <= 0),
    "PN_SSL_SHA1,PN_SSL_SHA256,PN_SSL_SHA512,PN_SSL_MD5" },
  { "$pn_ssl_mode_t", 496, _cffi_prim_int(sizeof(pn_ssl_mode_t), ((pn_ssl_mode_t)-1) <= 0),
    "PN_SSL_MODE_CLIENT,PN_SSL_MODE_SERVER" },
  { "$pn_ssl_resume_status_t", 771, _cffi_prim_int(sizeof(pn_ssl_resume_status_t), ((pn_ssl_resume_status_t)-1) <= 0),
    "PN_SSL_RESUME_UNKNOWN,PN_SSL_RESUME_NEW,PN_SSL_RESUME_REUSED" },
  { "$pn_ssl_verify_mode_t", 219, _cffi_prim_int(sizeof(pn_ssl_verify_mode_t), ((pn_ssl_verify_mode_t)-1) <= 0),
    "PN_SSL_VERIFY_NULL,PN_SSL_VERIFY_PEER,PN_SSL_ANONYMOUS_PEER,PN_SSL_VERIFY_PEER_NAME" },
  { "$pn_terminus_type_t", 268, _cffi_prim_int(sizeof(pn_terminus_type_t), ((pn_terminus_type_t)-1) <= 0),
    "PN_UNSPECIFIED,PN_SOURCE,PN_TARGET,PN_COORDINATOR" },
  { "$pn_type_t", 104, _cffi_prim_int(sizeof(pn_type_t), ((pn_type_t)-1) <= 0),
    "PN_NULL,PN_BOOL,PN_UBYTE,PN_BYTE,PN_USHORT,PN_SHORT,PN_UINT,PN_INT,PN_CHAR,PN_ULONG,PN_LONG,PN_TIMESTAMP,PN_FLOAT,PN_DOUBLE,PN_DECIMAL32,PN_DECIMAL64,PN_DECIMAL128,PN_UUID,PN_BINARY,PN_STRING,PN_SYMBOL,PN_DESCRIBED,PN_ARRAY,PN_LIST,PN_MAP,PN_INVALID" },
};

static const struct _cffi_typename_s _cffi_typenames[] = {
  { "pn_atom_t", 187 },
  { "pn_bytes_t", 132 },
  { "pn_char_t", 152 },
  { "pn_collector_t", 757 },
  { "pn_condition_t", 758 },
  { "pn_connection_t", 759 },
  { "pn_data_t", 760 },
  { "pn_decimal128_t", 140 },
  { "pn_decimal32_t", 152 },
  { "pn_decimal64_t", 156 },
  { "pn_delivery_t", 761 },
  { "pn_delivery_tag_t", 132 },
  { "pn_disposition_t", 762 },
  { "pn_distribution_mode_t", 252 },
  { "pn_durability_t", 256 },
  { "pn_error_t", 763 },
  { "pn_event_t", 764 },
  { "pn_event_type_t", 57 },
  { "pn_expiry_policy_t", 260 },
  { "pn_link_t", 765 },
  { "pn_message_t", 766 },
  { "pn_millis_t", 152 },
  { "pn_msgid_t", 187 },
  { "pn_rcv_settle_mode_t", 680 },
  { "pn_record_t", 767 },
  { "pn_sasl_outcome_t", 710 },
  { "pn_sasl_t", 768 },
  { "pn_seconds_t", 152 },
  { "pn_sequence_t", 152 },
  { "pn_session_t", 769 },
  { "pn_snd_settle_mode_t", 684 },
  { "pn_ssl_cert_subject_subfield", 73 },
  { "pn_ssl_domain_t", 770 },
  { "pn_ssl_hash_alg", 231 },
  { "pn_ssl_mode_t", 496 },
  { "pn_ssl_resume_status_t", 771 },
  { "pn_ssl_t", 772 },
  { "pn_ssl_verify_mode_t", 219 },
  { "pn_state_t", 427 },
  { "pn_terminus_t", 773 },
  { "pn_terminus_type_t", 268 },
  { "pn_timestamp_t", 124 },
  { "pn_trace_t", 427 },
  { "pn_tracer_t", 747 },
  { "pn_transport_t", 774 },
  { "pn_type_t", 104 },
  { "pn_uuid_t", 144 },
};

static const struct _cffi_type_context_s _cffi_type_context = {
  _cffi_types,
  _cffi_globals,
  _cffi_fields,
  _cffi_struct_unions,
  _cffi_enums,
  _cffi_typenames,
  521,  /* num_globals */
  22,  /* num_struct_unions */
  14,  /* num_enums */
  47,  /* num_typenames */
  NULL,  /* no includes */
  779,  /* num_types */
  1,  /* flags */
};

#ifdef __GNUC__
#  pragma GCC visibility push(default)  /* for -fvisibility= */
#endif

#ifdef PYPY_VERSION
PyMODINIT_FUNC
_cffi_pypyinit_cproton_ffi(const void *p[])
{
    if (((intptr_t)p[0]) >= 0x0A03) {
        _cffi_call_python_org = (void(*)(struct _cffi_externpy_s *, char *))p[1];
    }
    p[0] = (const void *)0x2601;
    p[1] = &_cffi_type_context;
#if PY_MAJOR_VERSION >= 3
    return NULL;
#endif
}
#  ifdef _MSC_VER
     PyMODINIT_FUNC
#  if PY_MAJOR_VERSION >= 3
     PyInit_cproton_ffi(void) { return NULL; }
#  else
     initcproton_ffi(void) { }
#  endif
#  endif
#elif PY_MAJOR_VERSION >= 3
PyMODINIT_FUNC
PyInit_cproton_ffi(void)
{
  return _cffi_init("cproton_ffi", 0x2601, &_cffi_type_context);
}
#else
PyMODINIT_FUNC
initcproton_ffi(void)
{
  _cffi_init("cproton_ffi", 0x2601, &_cffi_type_context);
}
#endif

#ifdef __GNUC__
#  pragma GCC visibility pop
#endif
